{
    "scan": {
        "analyzer-version-clippy": "1.91.1",
        "analyzer-version-cppcheck": "2.18.3",
        "analyzer-version-gcc": "15.2.1",
        "analyzer-version-gcc-analyzer": "15.2.1",
        "analyzer-version-shellcheck": "0.11.0",
        "analyzer-version-unicontrol": "0.0.2",
        "enabled-plugins": "clippy, cppcheck, gcc, shellcheck, unicontrol",
        "exit-code": 0,
        "host": "ip-172-16-1-81.us-west-2.compute.internal",
        "known-false-positives": "/usr/share/csmock/known-false-positives.js",
        "known-false-positives-rpm": "known-false-positives-0.0.0.20250521.132812.g8eff701.main-1.el9.noarch",
        "mock-config": "fedora-rawhide-x86_64",
        "project-name": "util-linux-2.42.start-7.20251210111453534670.master.1025.ge0d602bab",
        "store-results-to": "/tmp/tmp3d1rs2wv/util-linux-2.42.start-7.20251210111453534670.master.1025.ge0d602bab.tar.xz",
        "time-created": "2025-12-10 23:03:28",
        "time-finished": "2025-12-10 23:12:25",
        "tool": "csmock",
        "tool-args": "'/usr/bin/csmock' '-r' 'fedora-rawhide-x86_64' '-t' 'cppcheck,unicontrol,gcc,shellcheck,clippy' '-o' '/tmp/tmp3d1rs2wv/util-linux-2.42.start-7.20251210111453534670.master.1025.ge0d602bab.tar.xz' '--gcc-analyze' '--unicontrol-notests' '--unicontrol-bidi-only' '--install' 'pam' '/tmp/tmp3d1rs2wv/util-linux-2.42.start-7.20251210111453534670.master.1025.ge0d602bab.src.rpm'",
        "tool-version": "csmock-3.8.3.20251124.152119.g92ed7a6-1.el9"
    },
    "defects": [
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2529 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2552 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2588 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2599 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2621 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2643 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2678 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2689 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "language": "c/c++",
            "tool": "cppcheck",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/conftest.cpp",
                    "line": 0,
                    "event": "internal warning",
                    "message": "child 2700 terminated by signal 15",
                    "verbosity_level": 0
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "8cde6e1bc4023a99f3d71f3a8eebfa294a7fbd54",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/umount.c",
                    "line": 598,
                    "event": "error[legacyUninitvar]",
                    "message": "Uninitialized variable: path",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  596|   \t\t\t\tsnprintf(path, sizeof(path), \"/proc/%i/ns/mnt\", pid);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  597|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  598|-> \t\t\tif (mnt_context_set_target_ns(cxt, pid ? path : optarg))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  599|   \t\t\t\terr(MNT_EX_SYSERR, _(\"failed to set target namespace to %s\"), pid ? path : optarg);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  600|   \t\t\tbreak;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "cd576d2dbf943a75c19031103bb0b9612d8fcbad",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘pager_close’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 305,
                    "column": 9,
                    "event": "warning[-Wanalyzer-fd-use-without-check]",
                    "message": "‘dup2’ on possibly invalid file descriptor ‘1’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 297,
                    "column": 6,
                    "event": "note",
                    "message": "(1) entry to ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 299,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 302,
                    "column": 9,
                    "event": "note",
                    "message": "(4) inlined call to ‘wait_for_pager’ from ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(5) calling ‘wait_for_pager’ from ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘pager_close’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 162,
                    "column": 13,
                    "event": "note",
                    "message": "(6) entry to ‘wait_for_pager’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 168,
                    "column": 9,
                    "event": "note",
                    "message": "(7) closed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 302,
                    "column": 9,
                    "event": "note",
                    "message": "(8) inlined call to ‘wait_for_pager’ from ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(9) returning to ‘pager_close’ from ‘wait_for_pager’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘pager_close’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 305,
                    "column": 9,
                    "event": "note",
                    "message": "(10) ‘1’ could be invalid",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  303|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  304|   \t/* restore original output */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  305|-> \tdup2(pager_process.org_out, STDOUT_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  306|   \tdup2(pager_process.org_err, STDERR_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  307|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0122e9f3a6ec92eed076c3f83cffac74b2ec884c",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 306,
                    "column": 9,
                    "event": "warning[-Wanalyzer-fd-use-without-check]",
                    "message": "‘dup2’ on possibly invalid file descriptor ‘2’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 297,
                    "column": 6,
                    "event": "note",
                    "message": "(1) entry to ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 299,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 302,
                    "column": 9,
                    "event": "note",
                    "message": "(4) inlined call to ‘wait_for_pager’ from ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(5) calling ‘wait_for_pager’ from ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘pager_close’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 162,
                    "column": 13,
                    "event": "note",
                    "message": "(6) entry to ‘wait_for_pager’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 169,
                    "column": 9,
                    "event": "note",
                    "message": "(7) closed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 302,
                    "column": 9,
                    "event": "note",
                    "message": "(8) inlined call to ‘wait_for_pager’ from ‘pager_close’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(9) returning to ‘pager_close’ from ‘wait_for_pager’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘pager_close’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pager.c",
                    "line": 306,
                    "column": 9,
                    "event": "note",
                    "message": "(10) ‘2’ could be invalid",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  304|   \t/* restore original output */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  305|   \tdup2(pager_process.org_out, STDOUT_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  306|-> \tdup2(pager_process.org_err, STDERR_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  307|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  308|   \tclose(pager_process.org_out);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "099c0a8912cdba0ced6195b458f15df8ab599e45",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘new_partition(__dev, & name)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘read_partitions’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 107,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_partitions’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 113,
                    "column": 16,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 116,
                    "column": 21,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 116,
                    "column": 20,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 118,
                    "column": 29,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 118,
                    "column": 29,
                    "event": "note",
                    "message": "(6) calling ‘new_partition’ from ‘read_partitions’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 89,
                    "column": 26,
                    "event": "note",
                    "message": "(7) entry to ‘new_partition’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 91,
                    "column": 39,
                    "event": "note",
                    "message": "(8) calling ‘xcalloc’ from ‘new_partition’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 41,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(9) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(10) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(11) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 91,
                    "column": 39,
                    "event": "note",
                    "message": "(14) returning to ‘new_partition’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 96,
                    "column": 27,
                    "event": "note",
                    "message": "(15) calling ‘xstrdup’ from ‘new_partition’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(16) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 40,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 35,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(17) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 96,
                    "column": 27,
                    "event": "note",
                    "message": "(21) returning to ‘new_partition’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 118,
                    "column": 29,
                    "event": "note",
                    "message": "(22) returning to ‘read_partitions’ from ‘new_partition’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/bdev.c",
                    "line": 119,
                    "column": 17,
                    "event": "note",
                    "message": "(23) inlined call to ‘list_add_tail’ from ‘read_partitions’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(24) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(25) ‘new_partition(__dev, & name)’ leaks here; was allocated at (10)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "7a388283a5ff3be8fa8c00600a57bf7d1da8d197",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'colors_add_scheme'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 392,
                    "column": 12,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'strdup(name)'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 683,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to 'color_scheme_get_sequence'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 690,
                    "column": 14,
                    "event": "note",
                    "message": "(2) calling 'colors_get_scheme' from 'color_scheme_get_sequence'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 444,
                    "column": 32,
                    "event": "note",
                    "message": "(3) entry to 'colors_get_scheme'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 449,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 452,
                    "column": 13,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 452,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 453,
                    "column": 26,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 453,
                    "column": 26,
                    "event": "note",
                    "message": "(8) calling 'colors_read_schemes' from 'colors_get_scheme'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 492,
                    "column": 12,
                    "event": "note",
                    "message": "(9) entry to 'colors_read_schemes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 504,
                    "column": 16,
                    "event": "note",
                    "message": "(10) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 38,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 60,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 507,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 510,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 515,
                    "column": 16,
                    "event": "note",
                    "message": "(14) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/assert.h",
                    "line": 35,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 8,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 516,
                    "column": 27,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 516,
                    "column": 27,
                    "event": "note",
                    "message": "(16) when 'strchr' returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 518,
                    "column": 20,
                    "event": "note",
                    "message": "(17) following 'false' branch (when 'p' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 526,
                    "column": 20,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 528,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 531,
                    "column": 22,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 532,
                    "column": 20,
                    "event": "note",
                    "message": "(21) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 533,
                    "column": 30,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 533,
                    "column": 30,
                    "event": "note",
                    "message": "(23) calling 'colors_add_scheme' from 'colors_read_schemes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 360,
                    "column": 12,
                    "event": "note",
                    "message": "(24) entry to 'colors_add_scheme'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 368,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 60,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 371,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 374,
                    "column": 12,
                    "event": "note",
                    "message": "(27) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 379,
                    "column": 15,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 379,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 389,
                    "column": 17,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 391,
                    "column": 20,
                    "event": "note",
                    "message": "(31) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/colors.c",
                    "line": 392,
                    "column": 12,
                    "event": "note",
                    "message": "(32) 'strdup(name)' leaks here; was allocated at (31)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  390|   \tcs->seq = seq;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  391|   \tcs->name = strdup(name);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  392|-> \tif (!cs->name)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  393|   \t\tgoto err;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  394|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ecd4199a793b45a8a1d4c9e13e4ea995a8a26e3d",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘new_miscdev(minor, & name)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘read_misc’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 141,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_misc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 147,
                    "column": 16,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 150,
                    "column": 21,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 150,
                    "column": 20,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 153,
                    "column": 27,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 153,
                    "column": 27,
                    "event": "note",
                    "message": "(6) calling ‘new_miscdev’ from ‘read_misc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 123,
                    "column": 24,
                    "event": "note",
                    "message": "(7) entry to ‘new_miscdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 125,
                    "column": 35,
                    "event": "note",
                    "message": "(8) calling ‘xcalloc’ from ‘new_miscdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 41,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(9) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(10) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(11) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 125,
                    "column": 35,
                    "event": "note",
                    "message": "(14) returning to ‘new_miscdev’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 130,
                    "column": 25,
                    "event": "note",
                    "message": "(15) calling ‘xstrdup’ from ‘new_miscdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(16) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 40,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 35,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(17) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 130,
                    "column": 25,
                    "event": "note",
                    "message": "(21) returning to ‘new_miscdev’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 153,
                    "column": 27,
                    "event": "note",
                    "message": "(22) returning to ‘read_misc’ from ‘new_miscdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 154,
                    "column": 17,
                    "event": "note",
                    "message": "(23) inlined call to ‘list_add_tail’ from ‘read_misc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(24) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(25) ‘new_miscdev(minor, & name)’ leaks here; was allocated at (10)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f02b5391b0e3f9679c6ee1ae295892bf3613d3b2",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘read_ttydrv(&line)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘read_tty_drivers’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 224,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_tty_drivers’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 228,
                    "column": 16,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 229,
                    "column": 41,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 229,
                    "column": 41,
                    "event": "note",
                    "message": "(4) calling ‘read_ttydrv’ from ‘read_tty_drivers’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 193,
                    "column": 23,
                    "event": "note",
                    "message": "(5) entry to ‘read_ttydrv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/sys/stat.h",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 200,
                    "column": 13,
                    "event": "note",
                    "message": "(6) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 201,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch (when ‘p’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 204,
                    "column": 13,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 204,
                    "column": 13,
                    "event": "note",
                    "message": "(9) when ‘strstr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 205,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when ‘p’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 207,
                    "column": 11,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 221,
                    "column": 16,
                    "event": "note",
                    "message": "(12) calling ‘new_ttydrv’ from ‘read_ttydrv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 160,
                    "column": 23,
                    "event": "note",
                    "message": "(13) entry to ‘new_ttydrv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 164,
                    "column": 33,
                    "event": "note",
                    "message": "(14) calling ‘xmalloc’ from ‘new_ttydrv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(15) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(16) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(17) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 164,
                    "column": 33,
                    "event": "note",
                    "message": "(20) returning to ‘new_ttydrv’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 171,
                    "column": 24,
                    "event": "note",
                    "message": "(21) calling ‘xstrdup’ from ‘new_ttydrv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(22) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(23) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 171,
                    "column": 24,
                    "event": "note",
                    "message": "(27) returning to ‘new_ttydrv’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 221,
                    "column": 16,
                    "event": "note",
                    "message": "(28) returning to ‘read_ttydrv’ from ‘new_ttydrv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 229,
                    "column": 41,
                    "event": "note",
                    "message": "(29) returning to ‘read_tty_drivers’ from ‘read_ttydrv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 230,
                    "column": 20,
                    "event": "note",
                    "message": "(30) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 231,
                    "column": 25,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/cdev.c",
                    "line": 231,
                    "column": 25,
                    "event": "note",
                    "message": "(32) inlined call to ‘list_add_tail’ from ‘read_tty_drivers’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(33) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(34) ‘read_ttydrv(&line)’ leaks here; was allocated at (16)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "6e6fb52992ca1e076536149d8c31d112f4e1f764",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc(32)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/unkn.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_inode’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/unkn.c",
                    "line": 872,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘add_inode’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/unkn.c",
                    "line": 874,
                    "column": 44,
                    "event": "note",
                    "message": "(2) calling ‘xmalloc’ from ‘add_inode’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 41,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(5) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/unkn.c",
                    "line": 874,
                    "column": 44,
                    "event": "note",
                    "message": "(8) returning to ‘add_inode’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/unkn.c",
                    "line": 880,
                    "column": 9,
                    "event": "note",
                    "message": "(9) inlined call to ‘list_add_tail’ from ‘add_inode’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(10) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(11) ‘xmalloc(32)’ leaks here; was allocated at (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "08b88119aaa76d93efd5d7d17477799b6911f342",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘setup’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 726,
                    "column": 9,
                    "event": "warning[-Wanalyzer-fd-use-without-check]",
                    "message": "‘dup2’ on possibly invalid file descriptor ‘0’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 696,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 698,
                    "column": 24,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 698,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 701,
                    "column": 19,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 707,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 708,
                    "column": 28,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 718,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘fd > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 718,
                    "column": 41,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 718,
                    "column": 41,
                    "event": "note",
                    "message": "(9) closed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 719,
                    "column": 20,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when ‘fd == 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 722,
                    "column": 17,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 726,
                    "column": 9,
                    "event": "note",
                    "message": "(12) ‘0’ could be invalid",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  724|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  725|   notty:",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  726|-> \tdup2(fd, STDIN_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  727|   \tdup2(fd, STDOUT_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  728|   \tdup2(fd, STDERR_FILENO);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "5d3e1e63228cb72756c48a951f47b815bad49664",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 727,
                    "column": 9,
                    "event": "warning[-Wanalyzer-fd-use-without-check]",
                    "message": "‘dup2’ on possibly invalid file descriptor ‘1’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 696,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 698,
                    "column": 24,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 698,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 701,
                    "column": 19,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 707,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 708,
                    "column": 28,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 718,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘fd > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 718,
                    "column": 41,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 719,
                    "column": 20,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘fd != 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 719,
                    "column": 41,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 719,
                    "column": 41,
                    "event": "note",
                    "message": "(11) closed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 720,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when ‘fd <= 2’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 722,
                    "column": 17,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 727,
                    "column": 9,
                    "event": "note",
                    "message": "(14) ‘1’ could be invalid",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  725|   notty:",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  726|   \tdup2(fd, STDIN_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  727|-> \tdup2(fd, STDOUT_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  728|   \tdup2(fd, STDERR_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  729|   \tcon->fd = STDIN_FILENO;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "6e805cb01623d547289c084bcb9e0e56ea98e504",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 728,
                    "column": 9,
                    "event": "warning[-Wanalyzer-fd-use-without-check]",
                    "message": "‘dup2’ on possibly invalid file descriptor ‘2’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 696,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 698,
                    "column": 24,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 698,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 701,
                    "column": 19,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 707,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 708,
                    "column": 28,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 718,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘fd > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 718,
                    "column": 41,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 719,
                    "column": 20,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘fd != 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 719,
                    "column": 41,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 720,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘true’ branch (when ‘fd > 2’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 720,
                    "column": 41,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 720,
                    "column": 41,
                    "event": "note",
                    "message": "(13) closed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/sulogin.c",
                    "line": 728,
                    "column": 9,
                    "event": "note",
                    "message": "(14) ‘2’ could be invalid",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  726|   \tdup2(fd, STDIN_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  727|   \tdup2(fd, STDOUT_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  728|-> \tdup2(fd, STDERR_FILENO);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  729|   \tcon->fd = STDIN_FILENO;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  730|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "4cdcbf5afd483c1c8d01ebfdf37a38863536b02b",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/blkpr.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘do_pr’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/blkpr.c",
                    "line": 166,
                    "column": 9,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(path, 2)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/blkpr.c",
                    "line": 162,
                    "column": 14,
                    "event": "note",
                    "message": "(1) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/blkpr.c",
                    "line": 163,
                    "column": 12,
                    "event": "note",
                    "message": "(2) assuming ‘open(path, 2)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/blkpr.c",
                    "line": 163,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/blkpr.c",
                    "line": 166,
                    "column": 9,
                    "event": "note",
                    "message": "(4) ...to here (5) ‘open(path, 2)’ leaks here; was opened at (1)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  164|   \t\terr(EXIT_FAILURE, _(\"cannot open %s\"), path);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  165|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  166|-> \tswitch (op) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  167|   \tcase IOC_PR_REGISTER:",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  168|   \t\tpr_reg.old_key = oldkey;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "7bb13978993ed2d74ebbb08f0d794cc3ff5d1659",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 94,
                    "event": "warning[uninitvar]",
                    "message": "Uninitialized variable: path",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   92|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   93|   \tmnt_free_iter(itr);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   94|-> \treturn path;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   95|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   96|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ba6ba779bfb35634b5543f3d4a7b7d9574ebba16",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 89,
                    "column": 20,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value ‘path’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 146,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘swapoff_by’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 155,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 156,
                    "column": 33,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 156,
                    "column": 33,
                    "event": "note",
                    "message": "(4) calling ‘resolve_swapfile_tag’ from ‘swapoff_by’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 57,
                    "column": 14,
                    "event": "note",
                    "message": "(5) entry to ‘resolve_swapfile_tag’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 59,
                    "column": 15,
                    "event": "note",
                    "message": "(6) region created on stack here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 59,
                    "column": 15,
                    "event": "note",
                    "message": "(7) capacity: 8 bytes",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 66,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 69,
                    "column": 15,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 70,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 73,
                    "column": 19,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 75,
                    "column": 35,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/swapoff.c",
                    "line": 89,
                    "column": 20,
                    "event": "note",
                    "message": "(14) use of uninitialized value ‘path’ here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   87|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   88|   \t\tblkid_free_probe(pr);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   89|-> \t\tif (path)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   90|   \t\t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   91|   \t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "7ef40ab0b983bdd7fd979ca61ceb83dbdc568bab",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 917,
                    "column": 33,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘new_zram(*<unknown>)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 787,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 886,
                    "column": 28,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 889,
                    "column": 18,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 889,
                    "column": 52,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 893,
                    "column": 9,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 896,
                    "column": 9,
                    "event": "note",
                    "message": "(6) following ‘default:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 897,
                    "column": 9,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 909,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘false’ branch (when ‘outarg’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 914,
                    "column": 28,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 914,
                    "column": 20,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 915,
                    "column": 52,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 915,
                    "column": 32,
                    "event": "note",
                    "message": "(12) calling ‘new_zram’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 343,
                    "column": 21,
                    "event": "note",
                    "message": "(13) entry to ‘new_zram’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 345,
                    "column": 26,
                    "event": "note",
                    "message": "(14) calling ‘xcalloc’ from ‘new_zram’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 40,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(15) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(16) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(17) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 345,
                    "column": 26,
                    "event": "note",
                    "message": "(20) returning to ‘new_zram’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 348,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following ‘false’ branch (when ‘devname’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 351,
                    "column": 20,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 915,
                    "column": 32,
                    "event": "note",
                    "message": "(23) returning to ‘main’ from ‘new_zram’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 916,
                    "column": 30,
                    "event": "note",
                    "message": "(24) calling ‘zram_exist’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 390,
                    "column": 19,
                    "event": "note",
                    "message": "(25) entry to ‘zram_exist’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 8,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 42,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 392,
                    "column": 9,
                    "event": "note",
                    "message": "(26) following ‘true’ branch (when ‘z’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/systemd/_sd-common.h",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/systemd/sd-device.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 32,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 394,
                    "column": 9,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 395,
                    "column": 13,
                    "event": "note",
                    "message": "(28) calling ‘zram_get_sysfs’ from ‘zram_exist’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 371,
                    "column": 25,
                    "event": "note",
                    "message": "(29) entry to ‘zram_get_sysfs’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 373,
                    "column": 9,
                    "event": "note",
                    "message": "(30) following ‘true’ branch (when ‘z’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 375,
                    "column": 15,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 375,
                    "column": 12,
                    "event": "note",
                    "message": "(32) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 376,
                    "column": 55,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 377,
                    "column": 20,
                    "event": "note",
                    "message": "(34) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 379,
                    "column": 28,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 380,
                    "column": 20,
                    "event": "note",
                    "message": "(36) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 395,
                    "column": 13,
                    "event": "note",
                    "message": "(38) returning to ‘zram_exist’ from ‘zram_get_sysfs’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 395,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 396,
                    "column": 23,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 916,
                    "column": 30,
                    "event": "note",
                    "message": "(41) returning to ‘main’ from ‘zram_exist’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 916,
                    "column": 28,
                    "event": "note",
                    "message": "(42) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 917,
                    "column": 61,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/zramctl.c",
                    "line": 917,
                    "column": 33,
                    "event": "note",
                    "message": "(44) ‘new_zram(*<unknown>)’ leaks here; was allocated at (16)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  915|   \t\t\tzram = new_zram(argv[optind++]);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  916|   \t\t\tif (!zram_exist(zram))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  917|-> \t\t\t\terr(EXIT_FAILURE, \"%s\", zram->devname);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  918|   \t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  919|   \t\tstatus(zram);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "a68c6def112e03645d64024556f98d35543734fb",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'ul_random_get_bytes'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 138,
                    "column": 20,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor 'random_get_fd()'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 100,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'ul_random_get_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 107,
                    "column": 18,
                    "event": "note",
                    "message": "(2) following 'false' branch (when 'n == 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 127,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 127,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 135,
                    "column": 26,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 135,
                    "column": 26,
                    "event": "note",
                    "message": "(6) calling 'random_get_fd' from 'ul_random_get_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 76,
                    "column": 5,
                    "event": "note",
                    "message": "(7) entry to 'random_get_fd'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 80,
                    "column": 14,
                    "event": "note",
                    "message": "(8) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 81,
                    "column": 12,
                    "event": "note",
                    "message": "(9) assuming 'open(\"/dev/urandom\", 524288)' is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 81,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 83,
                    "column": 9,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 135,
                    "column": 26,
                    "event": "note",
                    "message": "(12) returning to 'ul_random_get_bytes' from 'random_get_fd'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/randutils.c",
                    "line": 138,
                    "column": 20,
                    "event": "note",
                    "message": "(13) 'random_get_fd()' leaks here; was opened at (8)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  136|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  137|   \t\tlose_counter = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  138|-> \t\tif (fd >= 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  139|   \t\t\twhile (n > 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  140|   \t\t\t\tssize_t x = read(fd, cp, n);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "616122490dde8d0fd70ca92b37782d68c429b4be",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 889,
                    "column": 43,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘xcalloc((long unsigned int)(argc - optind), 8)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 689,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 862,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 866,
                    "column": 20,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 866,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 867,
                    "column": 40,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 867,
                    "column": 27,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 49,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(8) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(9) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 867,
                    "column": 27,
                    "event": "note",
                    "message": "(14) returning to ‘main’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 868,
                    "column": 31,
                    "event": "note",
                    "message": "(15) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 869,
                    "column": 48,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 872,
                    "column": 28,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 18,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 874,
                    "column": 44,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/blkid.c",
                    "line": 889,
                    "column": 43,
                    "event": "note",
                    "message": "(19) dereference of NULL ‘xcalloc((long unsigned int)(argc - optind), 8) + (long unsigned int)numdev * 8’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  887|   \t\t\t\tcontinue;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  888|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  889|-> \t\t\tdevices[numdev++] = dev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  890|   \t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  891|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "5d76fdad2184395ebe14127c7fc2afd757573fcd",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 50,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘check_blocks’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc((long unsigned int)*ctl.pagesize)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 551,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 697,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 699,
                    "column": 20,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 699,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 705,
                    "column": 11,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 705,
                    "column": 11,
                    "event": "note",
                    "message": "(6) following ‘false’ branch (when ‘opt_uuid’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 715,
                    "column": 17,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 719,
                    "column": 9,
                    "event": "note",
                    "message": "(8) calling ‘init_signature_page’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 125,
                    "column": 13,
                    "event": "note",
                    "message": "(9) entry to ‘init_signature_page’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 143,
                    "column": 31,
                    "event": "note",
                    "message": "(10) calling ‘xcalloc’ from ‘init_signature_page’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(11) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 143,
                    "column": 31,
                    "event": "note",
                    "message": "(14) returning to ‘init_signature_page’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 719,
                    "column": 9,
                    "event": "note",
                    "message": "(15) returning to ‘main’ from ‘init_signature_page’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 721,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 725,
                    "column": 12,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 725,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch (when ‘block_count’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 732,
                    "column": 14,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 732,
                    "column": 14,
                    "event": "note",
                    "message": "(20) calling ‘get_size’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 365,
                    "column": 27,
                    "event": "note",
                    "message": "(21) entry to ‘get_size’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 373,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 375,
                    "column": 21,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 375,
                    "column": 20,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 377,
                    "column": 45,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 377,
                    "column": 20,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 379,
                    "column": 17,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 732,
                    "column": 14,
                    "event": "note",
                    "message": "(28) returning to ‘main’ from ‘get_size’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 733,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 734,
                    "column": 28,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 741,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 745,
                    "column": 12,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 753,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 758,
                    "column": 9,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 758,
                    "column": 9,
                    "event": "note",
                    "message": "(35) calling ‘open_device’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 398,
                    "column": 13,
                    "event": "note",
                    "message": "(36) entry to ‘open_device’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 8,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 54,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 400,
                    "column": 9,
                    "event": "note",
                    "message": "(37) following ‘true’ branch (when ‘ctl’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 401,
                    "column": 19,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 401,
                    "column": 9,
                    "event": "note",
                    "message": "(39) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 403,
                    "column": 16,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 412,
                    "column": 20,
                    "event": "note",
                    "message": "(41) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 414,
                    "column": 65,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 416,
                    "column": 12,
                    "event": "note",
                    "message": "(43) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 419,
                    "column": 16,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 444,
                    "column": 12,
                    "event": "note",
                    "message": "(45) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 447,
                    "column": 16,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 447,
                    "column": 24,
                    "event": "note",
                    "message": "(47) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 453,
                    "column": 1,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 758,
                    "column": 9,
                    "event": "note",
                    "message": "(49) returning to ‘main’ from ‘open_device’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 764,
                    "column": 12,
                    "event": "note",
                    "message": "(50) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 770,
                    "column": 16,
                    "event": "note",
                    "message": "(51) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 770,
                    "column": 12,
                    "event": "note",
                    "message": "(52) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 771,
                    "column": 17,
                    "event": "note",
                    "message": "(53) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 771,
                    "column": 17,
                    "event": "note",
                    "message": "(54) calling ‘check_blocks’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 245,
                    "column": 13,
                    "event": "note",
                    "message": "(55) entry to ‘check_blocks’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 251,
                    "column": 9,
                    "event": "note",
                    "message": "(56) following ‘true’ branch (when ‘ctl’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 252,
                    "column": 19,
                    "event": "note",
                    "message": "(57) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 252,
                    "column": 9,
                    "event": "note",
                    "message": "(58) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 254,
                    "column": 29,
                    "event": "note",
                    "message": "(59) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 254,
                    "column": 18,
                    "event": "note",
                    "message": "(60) calling ‘xmalloc’ from ‘check_blocks’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(61) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(62) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(63) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(64) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 254,
                    "column": 18,
                    "event": "note",
                    "message": "(65) returning to ‘check_blocks’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 255,
                    "column": 29,
                    "event": "note",
                    "message": "(66) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 257,
                    "column": 32,
                    "event": "note",
                    "message": "(67) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 259,
                    "column": 20,
                    "event": "note",
                    "message": "(68) following ‘true’ branch (when ‘do_seek != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkswap.c",
                    "line": 259,
                    "column": 32,
                    "event": "note",
                    "message": "(69) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "note",
                    "message": "(70) ‘xmalloc((long unsigned int)*ctl.pagesize)’ leaks here; was allocated at (62)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   30|   \tvoid *ret = malloc(size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   31|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   32|-> \tif (!ret && size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   33|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   34|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 190,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "8d9e99da4a45225b82a05826f2f682a09f4e8fa5",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 376,
                    "event": "error[integerOverflow]",
                    "message": "Signed integer overflow for expression '-(1<<24)'.",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  374|   \t\t} else {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  375|   \t\t\tentry->size = st.st_rdev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  376|-> \t\t\tif (entry->size & -(1<<CRAMFS_SIZE_WIDTH))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  377|   \t\t\t\twarn_dev = 1;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  378|   \t\t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ea0bcc20b48ab1eef80637cd0c465558a2af1fe5",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘next_menu_entry’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 296,
                    "column": 22,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value ‘((unsigned char*)&*m)[8]’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 349,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘menu_detect_collisions’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 354,
                    "column": 21,
                    "event": "note",
                    "message": "(2) calling ‘next_menu_entry’ from ‘menu_detect_collisions’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 268,
                    "column": 33,
                    "event": "note",
                    "message": "(3) entry to ‘next_menu_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/pt-mbr.h",
                    "line": 8,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 21,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 276,
                    "column": 9,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘cxt’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 278,
                    "column": 12,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 278,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 279,
                    "column": 24,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 280,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 283,
                    "column": 29,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 284,
                    "column": 36,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 292,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 294,
                    "column": 23,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 292,
                    "column": 38,
                    "event": "note",
                    "message": "(14) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 294,
                    "column": 31,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 294,
                    "column": 31,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 296,
                    "column": 22,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk-menu.c",
                    "line": 296,
                    "column": 22,
                    "event": "note",
                    "message": "(18) use of uninitialized value ‘((unsigned char*)&*m)[8]’ here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  294|   \t\t    (m->label && (!lb || !(m->label & type))) ||",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  295|   \t\t/* unwanted for nested PT */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  296|-> \t\t    (m->nonested && parent) ||",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  297|   \t\t/* menu excluded for specified labels */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  298|   \t\t    (m->exclude && lb && (m->exclude & type))) {",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "9aa42db247114a027b0207d2d20b0779025c2079",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘skip_empty’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 954,
                    "column": 21,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘p0’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 990,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.h",
                    "line": 18,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 47,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 998,
                    "column": 9,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1000,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1000,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1003,
                    "column": 38,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1003,
                    "column": 38,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 35,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(8) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1003,
                    "column": 38,
                    "event": "note",
                    "message": "(11) returning to ‘dump_blkdev’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1005,
                    "column": 21,
                    "event": "note",
                    "message": "(12) calling ‘read_all’ from ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 36,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 61,
                    "column": 23,
                    "event": "note",
                    "message": "(13) entry to ‘read_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 68,
                    "column": 22,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘count != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 69,
                    "column": 23,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1005,
                    "column": 21,
                    "event": "note",
                    "message": "(16) returning to ‘dump_blkdev’ from ‘read_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1005,
                    "column": 20,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1008,
                    "column": 25,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1008,
                    "column": 25,
                    "event": "note",
                    "message": "(19) calling ‘dump_buffer’ from ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 961,
                    "column": 13,
                    "event": "note",
                    "message": "(20) entry to ‘dump_buffer’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 965,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following ‘false’ branch (when ‘buf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 967,
                    "column": 30,
                    "event": "note",
                    "message": "(23) following ‘true’ branch (when ‘i < sz’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 968,
                    "column": 20,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 968,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘l == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 969,
                    "column": 28,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 969,
                    "column": 28,
                    "event": "note",
                    "message": "(27) following ‘true’ branch (when ‘next == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 970,
                    "column": 40,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 970,
                    "column": 40,
                    "event": "note",
                    "message": "(29) calling ‘skip_empty’ from ‘dump_buffer’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 948,
                    "column": 15,
                    "event": "note",
                    "message": "(30) entry to ‘skip_empty’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 953,
                    "column": 34,
                    "event": "note",
                    "message": "(31) following ‘true’ branch (when ‘next < sz’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 954,
                    "column": 36,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 954,
                    "column": 21,
                    "event": "note",
                    "message": "(33) argument 1 (‘p0’) from (8) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 17,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/string.h",
                    "line": 75,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘memcmp’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  952|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  953|   \tfor (next = i + 16; next < sz; next += 16) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  954|-> \t\tif (memcmp(p0, buf + next, 16) != 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  955|   \t\t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  956|   \t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "d41ee1a88ea6d0ab4766a2a021045fbb21f97678",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘dump_buffer’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 973,
                    "column": 36,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘buf’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 990,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 998,
                    "column": 9,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1000,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1000,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1003,
                    "column": 38,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1003,
                    "column": 38,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(8) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1003,
                    "column": 38,
                    "event": "note",
                    "message": "(11) returning to ‘dump_blkdev’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1005,
                    "column": 21,
                    "event": "note",
                    "message": "(12) calling ‘read_all’ from ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 61,
                    "column": 23,
                    "event": "note",
                    "message": "(13) entry to ‘read_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 68,
                    "column": 22,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘count != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 69,
                    "column": 23,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1005,
                    "column": 21,
                    "event": "note",
                    "message": "(16) returning to ‘dump_blkdev’ from ‘read_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1005,
                    "column": 20,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1008,
                    "column": 25,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 1008,
                    "column": 25,
                    "event": "note",
                    "message": "(19) calling ‘dump_buffer’ from ‘dump_blkdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 961,
                    "column": 13,
                    "event": "note",
                    "message": "(20) entry to ‘dump_buffer’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 965,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following ‘false’ branch (when ‘buf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 967,
                    "column": 30,
                    "event": "note",
                    "message": "(23) following ‘true’ branch (when ‘i < sz’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 968,
                    "column": 20,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 968,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘l == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 969,
                    "column": 28,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 969,
                    "column": 28,
                    "event": "note",
                    "message": "(27) following ‘true’ branch (when ‘next == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 970,
                    "column": 40,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 970,
                    "column": 40,
                    "event": "note",
                    "message": "(29) calling ‘skip_empty’ from ‘dump_buffer’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 948,
                    "column": 15,
                    "event": "note",
                    "message": "(30) entry to ‘skip_empty’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 953,
                    "column": 34,
                    "event": "note",
                    "message": "(31) following ‘false’ branch (when ‘next >= sz’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 958,
                    "column": 35,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 958,
                    "column": 35,
                    "event": "note",
                    "message": "(33) following ‘true’ branch (when ‘next == next’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 958,
                    "column": 35,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 970,
                    "column": 40,
                    "event": "note",
                    "message": "(35) returning to ‘dump_buffer’ from ‘skip_empty’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdisk.c",
                    "line": 973,
                    "column": 36,
                    "event": "note",
                    "message": "(36) ‘buf + i’ could be NULL: unchecked value from (8)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  971|   \t\t\tprintf(\"%08jx \", (intmax_t)base + i);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  972|   \t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  973|-> \t\tprintf(\" %02x\", buf[i]);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  974|   \t\tif (l == 7)\t\t\t\t/* words separator */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  975|   \t\t\tfputs(\" \", stdout);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "dd2979bbeb3a280d14768fc1b3bd8ecd08474505",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 321,
                    "column": 17,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘argv’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 245,
                    "column": 16,
                    "event": "note",
                    "message": "(1) ‘stdin_lines’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 298,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘argc == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 302,
                    "column": 24,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 309,
                    "column": 24,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 309,
                    "column": 24,
                    "event": "note",
                    "message": "(6) ‘stdin_lines’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 310,
                    "column": 22,
                    "event": "note",
                    "message": "(7) ‘stdin_lines’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 314,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 318,
                    "column": 9,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 320,
                    "column": 21,
                    "event": "note",
                    "message": "(10) following ‘true’ branch (when ‘argc > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 321,
                    "column": 17,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/bits.c",
                    "line": 321,
                    "column": 17,
                    "event": "note",
                    "message": "(12) dereference of NULL ‘argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  319|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  320|   \tfor (; argc > 0; argc--, argv++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  321|-> \t\tparse_mask_or_list(*argv, bits, width);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  322|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  323|   \tul_strv_free(stdin_lines);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "cfca61738991674e7da363aa6d1d4bd1a57e8bcf",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘compile_fs_type’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 995,
                    "column": 28,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xstrdup(fs_type)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1620,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1650,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘parse_argv’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1435,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1457,
                    "column": 21,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘i < argc’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1458,
                    "column": 27,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1459,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch (when ‘arg’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 20,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘true’ branch (when ‘opts_for_fsck == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 40,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 36,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1465,
                    "column": 40,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1465,
                    "column": 36,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 25,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/sys/types.h",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 34,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 58,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 58,
                    "event": "note",
                    "message": "(16) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 55,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1500,
                    "column": 20,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1500,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1506,
                    "column": 27,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1507,
                    "column": 28,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1507,
                    "column": 28,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘opts_for_fsck == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1511,
                    "column": 25,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1511,
                    "column": 25,
                    "event": "note",
                    "message": "(25) following ‘case 116:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1568,
                    "column": 25,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1570,
                    "column": 36,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1573,
                    "column": 42,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1580,
                    "column": 42,
                    "event": "note",
                    "message": "(29) calling ‘xstrdup’ from ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 64,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(30) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 58,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(31) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1580,
                    "column": 42,
                    "event": "note",
                    "message": "(35) returning to ‘parse_argv’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1581,
                    "column": 33,
                    "event": "note",
                    "message": "(36) calling ‘compile_fs_type’ from ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 967,
                    "column": 13,
                    "event": "note",
                    "message": "(37) entry to ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 973,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘true’ branch (when ‘fs_type’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 974,
                    "column": 34,
                    "event": "note",
                    "message": "(40) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(42) calling ‘xcalloc’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(43) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(46) returning to ‘compile_fs_type’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 981,
                    "column": 21,
                    "event": "note",
                    "message": "(47) calling ‘xcalloc’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(48) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(49) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 981,
                    "column": 21,
                    "event": "note",
                    "message": "(51) returning to ‘compile_fs_type’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 984,
                    "column": 12,
                    "event": "note",
                    "message": "(52) following ‘false’ branch (when ‘fs_type’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(53) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(54) calling ‘xstrdup’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(55) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(56) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(57) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(58) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(59) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(60) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(61) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(62) returning to ‘compile_fs_type’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 989,
                    "column": 13,
                    "event": "note",
                    "message": "(63) when ‘strtok’ on non-NULL string returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 990,
                    "column": 15,
                    "event": "note",
                    "message": "(64) following ‘true’ branch (when ‘s’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 992,
                    "column": 21,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 999,
                    "column": 20,
                    "event": "note",
                    "message": "(66) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1002,
                    "column": 26,
                    "event": "note",
                    "message": "(67) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1002,
                    "column": 25,
                    "event": "note",
                    "message": "(68) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1007,
                    "column": 28,
                    "event": "note",
                    "message": "(69) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1007,
                    "column": 28,
                    "event": "note",
                    "message": "(70) following ‘true’ branch (when ‘first_negate != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1008,
                    "column": 45,
                    "event": "note",
                    "message": "(71) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1011,
                    "column": 28,
                    "event": "note",
                    "message": "(72) following ‘false’ branch (when ‘negate == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1012,
                    "column": 44,
                    "event": "note",
                    "message": "(73) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 995,
                    "column": 28,
                    "event": "note",
                    "message": "(74) ‘xstrdup(fs_type)’ leaks here; was allocated at (58)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  993|   \t\t\ts += 2;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  994|   \t\t\tnegate = 1;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  995|-> \t\t} else if (*s == '!') {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  996|   \t\t\ts++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  997|   \t\t\tnegate = 1;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "860fce6bcfa4e2c3b4dca0c45bf3372bc58609fe",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1005,
                    "column": 28,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xstrdup(fs_type)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1620,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1650,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘parse_argv’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1435,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1457,
                    "column": 21,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘i < argc’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1458,
                    "column": 27,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1459,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch (when ‘arg’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 20,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘true’ branch (when ‘opts_for_fsck == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 40,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 36,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1465,
                    "column": 40,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1465,
                    "column": 36,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 25,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 58,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 58,
                    "event": "note",
                    "message": "(16) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 55,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1500,
                    "column": 20,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1500,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1506,
                    "column": 27,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1507,
                    "column": 28,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1507,
                    "column": 28,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘opts_for_fsck == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1511,
                    "column": 25,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1511,
                    "column": 25,
                    "event": "note",
                    "message": "(25) following ‘case 116:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1568,
                    "column": 25,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1570,
                    "column": 36,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1573,
                    "column": 42,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1580,
                    "column": 42,
                    "event": "note",
                    "message": "(29) calling ‘xstrdup’ from ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(30) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(31) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1580,
                    "column": 42,
                    "event": "note",
                    "message": "(35) returning to ‘parse_argv’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1581,
                    "column": 33,
                    "event": "note",
                    "message": "(36) calling ‘compile_fs_type’ from ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 967,
                    "column": 13,
                    "event": "note",
                    "message": "(37) entry to ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 973,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘true’ branch (when ‘fs_type’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 974,
                    "column": 34,
                    "event": "note",
                    "message": "(40) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(42) calling ‘xcalloc’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(43) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(46) returning to ‘compile_fs_type’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 981,
                    "column": 21,
                    "event": "note",
                    "message": "(47) calling ‘xcalloc’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(48) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(49) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 981,
                    "column": 21,
                    "event": "note",
                    "message": "(51) returning to ‘compile_fs_type’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 984,
                    "column": 12,
                    "event": "note",
                    "message": "(52) following ‘false’ branch (when ‘fs_type’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(53) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(54) calling ‘xstrdup’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(55) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(56) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(57) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(58) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(59) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(60) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(61) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(62) returning to ‘compile_fs_type’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 989,
                    "column": 13,
                    "event": "note",
                    "message": "(63) when ‘strtok’ on non-NULL string returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 990,
                    "column": 15,
                    "event": "note",
                    "message": "(64) following ‘true’ branch (when ‘s’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 992,
                    "column": 21,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1019,
                    "column": 36,
                    "event": "note",
                    "message": "(66) calling ‘xstrdup’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(67) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(68) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(69) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(70) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(71) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1019,
                    "column": 36,
                    "event": "note",
                    "message": "(72) returning to ‘compile_fs_type’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1020,
                    "column": 21,
                    "event": "note",
                    "message": "(73) when ‘strtok’ with NULL string (using prior) returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 990,
                    "column": 15,
                    "event": "note",
                    "message": "(74) following ‘true’ branch (when ‘s’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 992,
                    "column": 21,
                    "event": "note",
                    "message": "(75) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 999,
                    "column": 20,
                    "event": "note",
                    "message": "(76) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1002,
                    "column": 26,
                    "event": "note",
                    "message": "(77) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1002,
                    "column": 25,
                    "event": "note",
                    "message": "(78) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1007,
                    "column": 28,
                    "event": "note",
                    "message": "(79) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1007,
                    "column": 28,
                    "event": "note",
                    "message": "(80) following ‘true’ branch (when ‘first_negate != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1008,
                    "column": 45,
                    "event": "note",
                    "message": "(81) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1011,
                    "column": 28,
                    "event": "note",
                    "message": "(82) following ‘true’ branch (when ‘negate != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1011,
                    "column": 44,
                    "event": "note",
                    "message": "(83) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1005,
                    "column": 28,
                    "event": "note",
                    "message": "(84) ‘xstrdup(fs_type)’ leaks here; was allocated at (58)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1003|   \t\t\ts += 5;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1004|   \t\tloop_special_case:",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1005|-> \t\t\tcmp->type[num] = negate ? FS_TYPE_NEGOPT : FS_TYPE_OPT;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1006|   \t\t} else {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1007|   \t\t\tif (first_negate) {",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "905c76ce57e4a08f25dc474d22889b66b61e7b3b",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1011,
                    "column": 44,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xstrdup(fs_type)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1620,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1650,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘parse_argv’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1435,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1457,
                    "column": 21,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘i < argc’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1458,
                    "column": 27,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1459,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch (when ‘arg’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 20,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘true’ branch (when ‘opts_for_fsck == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 40,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1463,
                    "column": 36,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1465,
                    "column": 40,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1465,
                    "column": 36,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 25,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 58,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 58,
                    "event": "note",
                    "message": "(16) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1468,
                    "column": 55,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1500,
                    "column": 20,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1500,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1506,
                    "column": 27,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1507,
                    "column": 28,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1507,
                    "column": 28,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘opts_for_fsck == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1511,
                    "column": 25,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1511,
                    "column": 25,
                    "event": "note",
                    "message": "(25) following ‘case 116:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1568,
                    "column": 25,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1570,
                    "column": 36,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1573,
                    "column": 42,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1580,
                    "column": 42,
                    "event": "note",
                    "message": "(29) calling ‘xstrdup’ from ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(30) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(31) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1580,
                    "column": 42,
                    "event": "note",
                    "message": "(35) returning to ‘parse_argv’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1581,
                    "column": 33,
                    "event": "note",
                    "message": "(36) calling ‘compile_fs_type’ from ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 967,
                    "column": 13,
                    "event": "note",
                    "message": "(37) entry to ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 973,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘true’ branch (when ‘fs_type’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 974,
                    "column": 34,
                    "event": "note",
                    "message": "(40) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(42) calling ‘xcalloc’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(43) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 980,
                    "column": 21,
                    "event": "note",
                    "message": "(46) returning to ‘compile_fs_type’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 981,
                    "column": 21,
                    "event": "note",
                    "message": "(47) calling ‘xcalloc’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(48) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(49) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 981,
                    "column": 21,
                    "event": "note",
                    "message": "(51) returning to ‘compile_fs_type’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 984,
                    "column": 12,
                    "event": "note",
                    "message": "(52) following ‘false’ branch (when ‘fs_type’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(53) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(54) calling ‘xstrdup’ from ‘compile_fs_type’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(55) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(56) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(57) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(58) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(59) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(60) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(61) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 987,
                    "column": 16,
                    "event": "note",
                    "message": "(62) returning to ‘compile_fs_type’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 989,
                    "column": 13,
                    "event": "note",
                    "message": "(63) when ‘strtok’ on non-NULL string returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 990,
                    "column": 15,
                    "event": "note",
                    "message": "(64) following ‘true’ branch (when ‘s’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 992,
                    "column": 21,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 999,
                    "column": 20,
                    "event": "note",
                    "message": "(66) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1002,
                    "column": 26,
                    "event": "note",
                    "message": "(67) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1002,
                    "column": 25,
                    "event": "note",
                    "message": "(68) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1007,
                    "column": 28,
                    "event": "note",
                    "message": "(69) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1007,
                    "column": 28,
                    "event": "note",
                    "message": "(70) following ‘true’ branch (when ‘first_negate != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1008,
                    "column": 45,
                    "event": "note",
                    "message": "(71) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1011,
                    "column": 28,
                    "event": "note",
                    "message": "(72) following ‘true’ branch (when ‘negate != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.c",
                    "line": 1011,
                    "column": 44,
                    "event": "note",
                    "message": "(73) ...to here (74) ‘xstrdup(fs_type)’ leaks here; was allocated at (58)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1009|   \t\t\t\tfirst_negate = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1010|   \t\t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1011|-> \t\t\tif ((negate && !cmp->negate) ||",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1012|   \t\t\t    (!negate && cmp->negate)) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1013|   \t\t\t\terrx(FSCK_EX_USAGE,",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "efc00a4789cf2c451df1459f7d9f8e427435e28b",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 60,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_directory’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc(len + 257)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 700,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 797,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 801,
                    "column": 23,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 807,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 809,
                    "column": 14,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 810,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 813,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 813,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 816,
                    "column": 22,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 816,
                    "column": 22,
                    "event": "note",
                    "message": "(10) calling ‘xcalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(11) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 816,
                    "column": 22,
                    "event": "note",
                    "message": "(14) returning to ‘main’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 821,
                    "column": 28,
                    "event": "note",
                    "message": "(15) calling ‘parse_directory’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 291,
                    "column": 21,
                    "event": "note",
                    "message": "(16) entry to ‘parse_directory’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 300,
                    "column": 16,
                    "event": "note",
                    "message": "(17) calling ‘xmalloc’ from ‘parse_directory’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(19) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 300,
                    "column": 16,
                    "event": "note",
                    "message": "(22) returning to ‘parse_directory’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "note",
                    "message": "(23) ‘xmalloc(len + 257)’ leaks here; was allocated at (19)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   30|   \tvoid *ret = malloc(size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   31|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   32|-> \tif (!ret && size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   33|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   34|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "e9d54e7caf02d4a68be83171e8d73633e1ec5238",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 339,
                    "column": 21,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘xmalloc(len + 257)’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 700,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 797,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 801,
                    "column": 23,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 807,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 809,
                    "column": 14,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 810,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 813,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 813,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 816,
                    "column": 22,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 816,
                    "column": 22,
                    "event": "note",
                    "message": "(10) calling ‘xcalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(11) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 816,
                    "column": 22,
                    "event": "note",
                    "message": "(14) returning to ‘main’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 821,
                    "column": 28,
                    "event": "note",
                    "message": "(15) calling ‘parse_directory’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 291,
                    "column": 21,
                    "event": "note",
                    "message": "(16) entry to ‘parse_directory’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 300,
                    "column": 16,
                    "event": "note",
                    "message": "(17) calling ‘xmalloc’ from ‘parse_directory’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(19) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 300,
                    "column": 16,
                    "event": "note",
                    "message": "(22) returning to ‘parse_directory’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 309,
                    "column": 12,
                    "event": "note",
                    "message": "(23) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 313,
                    "column": 37,
                    "event": "note",
                    "message": "(25) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 320,
                    "column": 33,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 339,
                    "column": 21,
                    "event": "note",
                    "message": "(27) argument 1 (‘xmalloc(len + 257)’) from (19) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/sys/types.h",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/mkfs.cramfs.c",
                    "line": 27,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/sys/stat.h",
                    "line": 327,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘lstat’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  337|   \t\tmemcpy(endpath, dirent->d_name, namelen + 1);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  338|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  339|-> \t\tif (lstat(path, &st) < 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  340|   \t\t\twarn(_(\"stat of %s failed\"), endpath);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  341|   \t\t\twarn_skip = 1;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "44a79788f297319b22cea06998e37af6ef451b53",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 69,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘test_crc’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc(4096)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 679,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 727,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 731,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 733,
                    "column": 9,
                    "event": "note",
                    "message": "(4) calling ‘test_super’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 152,
                    "column": 13,
                    "event": "note",
                    "message": "(5) entry to ‘test_super’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 158,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 162,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 162,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 57,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 165,
                    "column": 23,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 166,
                    "column": 20,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 175,
                    "column": 20,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 175,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 179,
                    "column": 13,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 179,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 181,
                    "column": 13,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 200,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 204,
                    "column": 18,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 204,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 208,
                    "column": 25,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 733,
                    "column": 9,
                    "event": "note",
                    "message": "(20) returning to ‘main’ from ‘test_super’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 734,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘test_crc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 219,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘test_crc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 224,
                    "column": 12,
                    "event": "note",
                    "message": "(23) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 229,
                    "column": 15,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 233,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘buf == 18446744073709551615’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 235,
                    "column": 37,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 237,
                    "column": 20,
                    "event": "note",
                    "message": "(27) following ‘false’ branch (when ‘buf == 18446744073709551615’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 258,
                    "column": 23,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 258,
                    "column": 23,
                    "event": "note",
                    "message": "(29) calling ‘xmalloc’ from ‘test_crc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(30) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(31) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(32) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fsck.cramfs.c",
                    "line": 258,
                    "column": 23,
                    "event": "note",
                    "message": "(35) returning to ‘test_crc’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "note",
                    "message": "(36) ‘xmalloc(4096)’ leaks here; was allocated at (31)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   30|   \tvoid *ret = malloc(size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   31|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   32|-> \tif (!ret && size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   33|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   34|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "db74eea101f8a85e04572e62243c5713994dbf1b",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘get’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 390,
                    "column": 29,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘curp’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 336,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to ‘get’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 343,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 344,
                    "column": 38,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 344,
                    "column": 24,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘get’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 44,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(6) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 344,
                    "column": 24,
                    "event": "note",
                    "message": "(9) returning to ‘get’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 345,
                    "column": 24,
                    "event": "note",
                    "message": "(10) calling ‘xcalloc’ from ‘get’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(11) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 345,
                    "column": 24,
                    "event": "note",
                    "message": "(14) returning to ‘get’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 359,
                    "column": 20,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 373,
                    "column": 21,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 373,
                    "column": 20,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 377,
                    "column": 21,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 379,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following ‘false’ branch (when ‘n != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 385,
                    "column": 23,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 388,
                    "column": 20,
                    "event": "note",
                    "message": "(21) following ‘true’ branch (when ‘need == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 389,
                    "column": 42,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 389,
                    "column": 28,
                    "event": "note",
                    "message": "(23) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 390,
                    "column": 51,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 390,
                    "column": 29,
                    "event": "note",
                    "message": "(25) argument 1 (‘curp’) from (6) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 42,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/string.h",
                    "line": 75,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘memcmp’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  388|   \t\tif (!(need -= n)) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  389|   \t\t\tif (vflag == ALL || vflag == FIRST ||",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  390|-> \t\t\t    memcmp(curp, savp, hex->blocksize) != 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  391|   \t\t\t\tif (vflag == DUP || vflag == FIRST)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  392|   \t\t\t\t\tvflag = WAIT;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "37b56b773dfbfa36850226a63ea796839efc344a",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 390,
                    "column": 29,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘savp’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 336,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to ‘get’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 343,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 344,
                    "column": 38,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 344,
                    "column": 24,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘get’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 344,
                    "column": 24,
                    "event": "note",
                    "message": "(8) returning to ‘get’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 345,
                    "column": 24,
                    "event": "note",
                    "message": "(9) calling ‘xcalloc’ from ‘get’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(11) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 345,
                    "column": 24,
                    "event": "note",
                    "message": "(14) returning to ‘get’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 359,
                    "column": 20,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 373,
                    "column": 21,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 373,
                    "column": 20,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 377,
                    "column": 21,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 379,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following ‘false’ branch (when ‘n != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 385,
                    "column": 23,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 388,
                    "column": 20,
                    "event": "note",
                    "message": "(21) following ‘true’ branch (when ‘need == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 389,
                    "column": 42,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 389,
                    "column": 28,
                    "event": "note",
                    "message": "(23) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 390,
                    "column": 51,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-display.c",
                    "line": 390,
                    "column": 29,
                    "event": "note",
                    "message": "(25) argument 2 (‘savp’) from (11) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/string.h",
                    "line": 75,
                    "column": 12,
                    "event": "note",
                    "message": "argument 2 of ‘memcmp’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  388|   \t\tif (!(need -= n)) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  389|   \t\t\tif (vflag == ALL || vflag == FIRST ||",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  390|-> \t\t\t    memcmp(curp, savp, hex->blocksize) != 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  391|   \t\t\t\tif (vflag == DUP || vflag == FIRST)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  392|   \t\t\t\t\tvflag = WAIT;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "3d7166f7cf675f06324ab8262bb3ee62e9f7c307",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/fgetwc_or_err.h",
                    "line": 12,
                    "event": "warning[nullPointerOutOfResources]",
                    "message": "If resource allocation fails, then there is a possible null pointer dereference: stream",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   10|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   11|   \terrno = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   12|-> \tret = fgetwc(stream);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   13|   \tif (ret == WEOF && errno != 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   14|   \t\terr(EXIT_FAILURE, _(\"fgetwc() failed\"));",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "8db6067aff6c2dc3e37584c405ecb1179d9d328e",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/ul.c",
                    "line": 640,
                    "event": "warning[nullPointerOutOfResources]",
                    "message": "If resource allocation fails, then there is a possible null pointer dereference: f",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  638|   \t\t\t\terr(EXIT_FAILURE, _(\"cannot open %s\"), argv[optind]);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  639|   \t\t\tfilter(&ctl, &tcs, f);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  640|-> \t\t\tfclose(f);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  641|   \t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  642|   \t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "30864ec941a5a789c43bce6ce08aab03b56c892f",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘reverse_str’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 95,
                    "column": 25,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘str’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 121,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(2) calling ‘xreallocarray’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 62,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(5) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(8) returning to ‘main’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 176,
                    "column": 24,
                    "event": "note",
                    "message": "(9) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 177,
                    "column": 31,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 177,
                    "column": 31,
                    "event": "note",
                    "message": "(11) calling ‘read_line’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 101,
                    "column": 15,
                    "event": "note",
                    "message": "(12) entry to ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 104,
                    "column": 18,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘r < n’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 105,
                    "column": 28,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 177,
                    "column": 31,
                    "event": "note",
                    "message": "(15) returning to ‘main’ from ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 180,
                    "column": 46,
                    "event": "note",
                    "message": "(16) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 183,
                    "column": 40,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(18) calling ‘xreallocarray’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(19) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(20) state of ‘CONJURED(ret_9 = reallocarray (ptr_5(D), nelems_6(D), size_7(D));, ret_9)’: ‘nonnull’ -> ‘unchecked’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(21) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(24) returning to ‘main’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 188,
                    "column": 40,
                    "event": "note",
                    "message": "(25) calling ‘read_line’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 101,
                    "column": 15,
                    "event": "note",
                    "message": "(26) entry to ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 104,
                    "column": 18,
                    "event": "note",
                    "message": "(27) following ‘true’ branch (when ‘r < n’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 105,
                    "column": 28,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 188,
                    "column": 40,
                    "event": "note",
                    "message": "(29) returning to ‘main’ from ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 180,
                    "column": 46,
                    "event": "note",
                    "message": "(30) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 183,
                    "column": 40,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(32) calling ‘xreallocarray’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(33) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(34) state of ‘CONJURED(ret_9 = reallocarray (ptr_5(D), nelems_6(D), size_7(D));, ret_9)’: ‘nonnull’ -> ‘unchecked’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(35) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 26,
                    "event": "note",
                    "message": "(36) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(38) returning to ‘main’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 190,
                    "column": 28,
                    "event": "note",
                    "message": "(39) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 195,
                    "column": 28,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 195,
                    "column": 28,
                    "event": "note",
                    "message": "(41) following ‘false’ branch (when ‘len != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 198,
                    "column": 50,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 198,
                    "column": 25,
                    "event": "note",
                    "message": "(43) calling ‘reverse_str’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 90,
                    "column": 13,
                    "event": "note",
                    "message": "(44) entry to ‘reverse_str’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 94,
                    "column": 23,
                    "event": "note",
                    "message": "(45) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 95,
                    "column": 34,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 95,
                    "column": 25,
                    "event": "note",
                    "message": "(47) dereference of NULL ‘str + i * 4’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   93|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   94|   \tfor (i = 0; i < n / 2; ++i) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   95|-> \t\twchar_t tmp = str[i];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   96|   \t\tstr[i] = str[n - 1 - i];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   97|   \t\tstr[n - 1 - i] = tmp;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "679e66b0e887fc4c07049cea527d72fd50d0a3f3",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘write_line’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 118,
                    "column": 17,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘str’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 121,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(2) calling ‘xreallocarray’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(5) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(8) returning to ‘main’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 176,
                    "column": 24,
                    "event": "note",
                    "message": "(9) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 177,
                    "column": 31,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 177,
                    "column": 31,
                    "event": "note",
                    "message": "(11) calling ‘read_line’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 101,
                    "column": 15,
                    "event": "note",
                    "message": "(12) entry to ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 104,
                    "column": 18,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘r < n’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 105,
                    "column": 28,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 177,
                    "column": 31,
                    "event": "note",
                    "message": "(15) returning to ‘main’ from ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 180,
                    "column": 46,
                    "event": "note",
                    "message": "(16) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 183,
                    "column": 40,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(18) calling ‘xreallocarray’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(19) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(20) state of ‘CONJURED(ret_9 = reallocarray (ptr_5(D), nelems_6(D), size_7(D));, ret_9)’: ‘nonnull’ -> ‘unchecked’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(21) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(24) returning to ‘main’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 188,
                    "column": 40,
                    "event": "note",
                    "message": "(25) calling ‘read_line’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 101,
                    "column": 15,
                    "event": "note",
                    "message": "(26) entry to ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 104,
                    "column": 18,
                    "event": "note",
                    "message": "(27) following ‘true’ branch (when ‘r < n’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 105,
                    "column": 28,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 188,
                    "column": 40,
                    "event": "note",
                    "message": "(29) returning to ‘main’ from ‘read_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 180,
                    "column": 46,
                    "event": "note",
                    "message": "(30) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 183,
                    "column": 40,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(32) calling ‘xreallocarray’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(33) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(34) state of ‘CONJURED(ret_9 = reallocarray (ptr_5(D), nelems_6(D), size_7(D));, ret_9)’: ‘nonnull’ -> ‘unchecked’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(35) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 26,
                    "event": "note",
                    "message": "(36) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 185,
                    "column": 39,
                    "event": "note",
                    "message": "(38) returning to ‘main’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 190,
                    "column": 28,
                    "event": "note",
                    "message": "(39) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 195,
                    "column": 28,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 195,
                    "column": 28,
                    "event": "note",
                    "message": "(41) following ‘false’ branch (when ‘len != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 198,
                    "column": 50,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 198,
                    "column": 25,
                    "event": "note",
                    "message": "(43) calling ‘reverse_str’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 90,
                    "column": 13,
                    "event": "note",
                    "message": "(44) entry to ‘reverse_str’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 94,
                    "column": 23,
                    "event": "note",
                    "message": "(45) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 99,
                    "column": 1,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 198,
                    "column": 25,
                    "event": "note",
                    "message": "(47) returning to ‘main’ from ‘reverse_str’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 199,
                    "column": 25,
                    "event": "note",
                    "message": "(48) calling ‘write_line’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 115,
                    "column": 13,
                    "event": "note",
                    "message": "(49) entry to ‘write_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 117,
                    "column": 30,
                    "event": "note",
                    "message": "(50) following ‘true’ branch (when ‘i < n’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 118,
                    "column": 27,
                    "event": "note",
                    "message": "(51) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/rev.c",
                    "line": 118,
                    "column": 17,
                    "event": "note",
                    "message": "(52) dereference of NULL ‘str + i * 4’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  116|   {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  117|   \tfor (size_t i = 0; i < n; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  118|-> \t\tfputwc(str[i], stream);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  119|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  120|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "7a1b5f5e75a33441476e850fe1cc64eedbc4db66",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 56)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘color_fmt’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 478,
                    "column": 26,
                    "event": "note",
                    "message": "(1) entry to ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 484,
                    "column": 20,
                    "event": "note",
                    "message": "(2) calling ‘xmalloc’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 46,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 484,
                    "column": 20,
                    "event": "note",
                    "message": "(6) returning to ‘color_fmt’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 485,
                    "column": 23,
                    "event": "note",
                    "message": "(7) calling ‘xcalloc’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(8) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 485,
                    "column": 23,
                    "event": "note",
                    "message": "(11) returning to ‘color_fmt’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 492,
                    "column": 21,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 495,
                    "column": 20,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 495,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 500,
                    "column": 23,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 500,
                    "column": 23,
                    "event": "note",
                    "message": "(16) calling ‘xstrndup’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 102,
                    "column": 7,
                    "event": "note",
                    "message": "(17) entry to ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump.h",
                    "line": 38,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 106,
                    "column": 9,
                    "event": "note",
                    "message": "(18) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 107,
                    "column": 15,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 108,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 110,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 500,
                    "column": 23,
                    "event": "note",
                    "message": "(22) returning to ‘color_fmt’ from ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 505,
                    "column": 20,
                    "event": "note",
                    "message": "(23) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 509,
                    "column": 21,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 509,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 551,
                    "column": 37,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 555,
                    "column": 20,
                    "event": "note",
                    "message": "(27) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 556,
                    "column": 25,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 558,
                    "column": 28,
                    "event": "note",
                    "message": "(29) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 562,
                    "column": 29,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 562,
                    "column": 28,
                    "event": "note",
                    "message": "(31) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 563,
                    "column": 33,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 568,
                    "column": 36,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 571,
                    "column": 36,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 571,
                    "column": 36,
                    "event": "note",
                    "message": "(35) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 575,
                    "column": 54,
                    "event": "note",
                    "message": "(37) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 576,
                    "column": 46,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 576,
                    "column": 46,
                    "event": "note",
                    "message": "(39) calling ‘xcalloc’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(40) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(41) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(42) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(43) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 576,
                    "column": 46,
                    "event": "note",
                    "message": "(45) returning to ‘color_fmt’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 582,
                    "column": 41,
                    "event": "note",
                    "message": "(46) inlined call to ‘list_add_tail’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(47) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(48) ‘xcalloc(1, 56)’ leaks here; was allocated at (41)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "934d7a3a42d5dea4d399324a276ef9b045df16d2",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘color_fmt’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xstrndup(a, (long unsigned int)(p2 - a))’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 228,
                    "column": 6,
                    "event": "note",
                    "message": "(1) entry to ‘rewrite_rules’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 238,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 245,
                    "column": 22,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 246,
                    "column": 24,
                    "event": "note",
                    "message": "(4) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 247,
                    "column": 30,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 247,
                    "column": 30,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘rewrite_rules’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 247,
                    "column": 30,
                    "event": "note",
                    "message": "(10) returning to ‘rewrite_rules’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 257,
                    "column": 28,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 267,
                    "column": 31,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/sys/types.h",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 38,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 270,
                    "column": 44,
                    "event": "note",
                    "message": "(13) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 270,
                    "column": 44,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 283,
                    "column": 28,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 294,
                    "column": 33,
                    "event": "note",
                    "message": "(16) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 295,
                    "column": 41,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 403,
                    "column": 28,
                    "event": "note",
                    "message": "(18) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 404,
                    "column": 37,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 404,
                    "column": 36,
                    "event": "note",
                    "message": "(20) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 408,
                    "column": 45,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 408,
                    "column": 45,
                    "event": "note",
                    "message": "(22) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 410,
                    "column": 44,
                    "event": "note",
                    "message": "(23) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 411,
                    "column": 65,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 411,
                    "column": 65,
                    "event": "note",
                    "message": "(25) calling ‘xstrndup’ from ‘rewrite_rules’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 102,
                    "column": 7,
                    "event": "note",
                    "message": "(26) entry to ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 106,
                    "column": 9,
                    "event": "note",
                    "message": "(27) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 107,
                    "column": 15,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 107,
                    "column": 15,
                    "event": "note",
                    "message": "(29) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 108,
                    "column": 12,
                    "event": "note",
                    "message": "(30) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 108,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 110,
                    "column": 16,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 411,
                    "column": 65,
                    "event": "note",
                    "message": "(33) returning to ‘rewrite_rules’ from ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 411,
                    "column": 65,
                    "event": "note",
                    "message": "(34) calling ‘color_fmt’ from ‘rewrite_rules’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 478,
                    "column": 26,
                    "event": "note",
                    "message": "(35) entry to ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 484,
                    "column": 20,
                    "event": "note",
                    "message": "(36) calling ‘xmalloc’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(37) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 484,
                    "column": 20,
                    "event": "note",
                    "message": "(40) returning to ‘color_fmt’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 485,
                    "column": 23,
                    "event": "note",
                    "message": "(41) calling ‘xcalloc’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(42) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(43) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 485,
                    "column": 23,
                    "event": "note",
                    "message": "(45) returning to ‘color_fmt’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 492,
                    "column": 21,
                    "event": "note",
                    "message": "(46) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 495,
                    "column": 20,
                    "event": "note",
                    "message": "(47) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 495,
                    "column": 20,
                    "event": "note",
                    "message": "(48) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 500,
                    "column": 23,
                    "event": "note",
                    "message": "(49) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 500,
                    "column": 23,
                    "event": "note",
                    "message": "(50) calling ‘xstrndup’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 102,
                    "column": 7,
                    "event": "note",
                    "message": "(51) entry to ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 106,
                    "column": 9,
                    "event": "note",
                    "message": "(52) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 107,
                    "column": 15,
                    "event": "note",
                    "message": "(53) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 108,
                    "column": 12,
                    "event": "note",
                    "message": "(54) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 110,
                    "column": 16,
                    "event": "note",
                    "message": "(55) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 500,
                    "column": 23,
                    "event": "note",
                    "message": "(56) returning to ‘color_fmt’ from ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 505,
                    "column": 20,
                    "event": "note",
                    "message": "(57) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/libintl.h",
                    "line": 100,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/nls.h",
                    "line": 27,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 45,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 506,
                    "column": 32,
                    "event": "note",
                    "message": "(58) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "note",
                    "message": "(59) ‘xstrndup(a, (long unsigned int)(p2 - a))’ leaks here; was allocated at (29)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   30|   \tvoid *ret = malloc(size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   31|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   32|-> \tif (!ret && size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   33|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   34|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "8141db0a2c68158a11d7e5840ce15400d9bb94f9",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘rewrite_rules’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 284,
                    "column": 33,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘p1’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 228,
                    "column": 6,
                    "event": "note",
                    "message": "(1) entry to ‘rewrite_rules’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 238,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 245,
                    "column": 22,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 246,
                    "column": 24,
                    "event": "note",
                    "message": "(4) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 247,
                    "column": 30,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 247,
                    "column": 30,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘rewrite_rules’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 247,
                    "column": 30,
                    "event": "note",
                    "message": "(10) returning to ‘rewrite_rules’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 257,
                    "column": 28,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 267,
                    "column": 31,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 267,
                    "column": 28,
                    "event": "note",
                    "message": "(13) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 274,
                    "column": 40,
                    "event": "note",
                    "message": "(15) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 274,
                    "column": 40,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 276,
                    "column": 36,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 276,
                    "column": 36,
                    "event": "note",
                    "message": "(18) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 278,
                    "column": 46,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 278,
                    "column": 46,
                    "event": "note",
                    "message": "(20) calling ‘next_number’ from ‘rewrite_rules’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 101,
                    "column": 14,
                    "event": "note",
                    "message": "(21) entry to ‘next_number’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 103,
                    "column": 15,
                    "event": "note",
                    "message": "(22) ‘end’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 278,
                    "column": 46,
                    "event": "note",
                    "message": "(23) returning to ‘rewrite_rules’ from ‘next_number’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 284,
                    "column": 33,
                    "event": "note",
                    "message": "(24) dereference of NULL ‘p1’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  282|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  283|   \t\t\tp2 = p1 + 1;\t\t/* Set end pointer. */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  284|-> \t\t\tcs[0] = *p1;\t\t/* Set conversion string. */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  285|   \t\t\tcs[1] = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  286|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "fe55d3ef0d6235bff7ad76cf03fbfe79170f8d0e",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘color_fmt’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 492,
                    "column": 21,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘hcnext’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 478,
                    "column": 26,
                    "event": "note",
                    "message": "(1) entry to ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 484,
                    "column": 20,
                    "event": "note",
                    "message": "(2) calling ‘xmalloc’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 484,
                    "column": 20,
                    "event": "note",
                    "message": "(6) returning to ‘color_fmt’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 485,
                    "column": 23,
                    "event": "note",
                    "message": "(7) calling ‘xcalloc’ from ‘color_fmt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(8) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(9) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(10) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 485,
                    "column": 23,
                    "event": "note",
                    "message": "(13) returning to ‘color_fmt’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/hexdump-parse.c",
                    "line": 492,
                    "column": 21,
                    "event": "note",
                    "message": "(14) ‘hcnext’ leaks here; was allocated at (9)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  490|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  491|   \tfmt = cfmt;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  492|-> \twhile (cfmt && *cfmt) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  493|   \t\tchar *end;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  494|   \t\t/* invert this condition */",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f5cc62f14338f99809d3141c82a6d695769ca116",
            "key_event_idx": 3,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 41,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 49,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 72)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 207,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘load_sock_xinfo_with_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 210,
                    "column": 17,
                    "event": "note",
                    "message": "(2) calling ‘load_sock_xinfo_no_nsswitch’ from ‘load_sock_xinfo_with_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 173,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘load_sock_xinfo_no_nsswitch’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 180,
                    "column": 9,
                    "event": "note",
                    "message": "(4) inlined call to ‘load_xinfo_from_proc_tcp’ from ‘load_sock_xinfo_no_nsswitch’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1311,
                    "column": 9,
                    "event": "note",
                    "message": "(5) calling ‘load_xinfo_from_proc_inet_L4’ from ‘load_sock_xinfo_no_nsswitch’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1282,
                    "column": 13,
                    "event": "note",
                    "message": "(6) entry to ‘load_xinfo_from_proc_inet_L4’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1290,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1293,
                    "column": 13,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1293,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1295,
                    "column": 14,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1295,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1299,
                    "column": 16,
                    "event": "note",
                    "message": "(13) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1300,
                    "column": 48,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1300,
                    "column": 43,
                    "event": "note",
                    "message": "(15) calling ‘tcp_xinfo_scan_line’ from ‘load_xinfo_from_proc_inet_L4’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1190,
                    "column": 27,
                    "event": "note",
                    "message": "(16) entry to ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1213,
                    "column": 15,
                    "event": "note",
                    "message": "(17) calling ‘xcalloc’ from ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(19) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(20) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1213,
                    "column": 15,
                    "event": "note",
                    "message": "(23) returning to ‘tcp_xinfo_scan_line’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1219,
                    "column": 35,
                    "event": "note",
                    "message": "(24) inlined call to ‘kernel32_to_cpu’ from ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 975,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘byteorder == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1219,
                    "column": 33,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1221,
                    "column": 36,
                    "event": "note",
                    "message": "(27) inlined call to ‘kernel32_to_cpu’ from ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 975,
                    "column": 12,
                    "event": "note",
                    "message": "(28) following ‘true’ branch (when ‘byteorder == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘tcp_xinfo_scan_line’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 1221,
                    "column": 34,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(30) ‘xcalloc(1, 72)’ leaks here; was allocated at (19)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f9a5b905e4c96f0ad7cfb8d20d651b7bcc25ae35",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘load_xinfo_from_proc_unix’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 789,
                    "column": 17,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 152)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 207,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘load_sock_xinfo_with_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 210,
                    "column": 17,
                    "event": "note",
                    "message": "(2) calling ‘load_sock_xinfo_no_nsswitch’ from ‘load_sock_xinfo_with_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 173,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘load_sock_xinfo_no_nsswitch’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 179,
                    "column": 9,
                    "event": "note",
                    "message": "(4) calling ‘load_xinfo_from_proc_unix’ from ‘load_sock_xinfo_no_nsswitch’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 739,
                    "column": 13,
                    "event": "note",
                    "message": "(5) entry to ‘load_xinfo_from_proc_unix’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 747,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 750,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 750,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 752,
                    "column": 19,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 752,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 756,
                    "column": 16,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 762,
                    "column": 22,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 771,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch (when ‘r > 3’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 35,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 52,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 774,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 775,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 778,
                    "column": 22,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 778,
                    "column": 22,
                    "event": "note",
                    "message": "(18) calling ‘xcalloc’ from ‘load_xinfo_from_proc_unix’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(19) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(20) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(21) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 778,
                    "column": 22,
                    "event": "note",
                    "message": "(24) returning to ‘load_xinfo_from_proc_unix’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 786,
                    "column": 17,
                    "event": "note",
                    "message": "(25) calling ‘xstrncpy’ from ‘load_xinfo_from_proc_unix’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 40,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 90,
                    "column": 19,
                    "event": "note",
                    "message": "(26) entry to ‘xstrncpy’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 92,
                    "column": 40,
                    "event": "note",
                    "message": "(27) following ‘true’ branch (when ‘src’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 92,
                    "column": 28,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘true’ branch (when ‘len == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 786,
                    "column": 17,
                    "event": "note",
                    "message": "(31) returning to ‘load_xinfo_from_proc_unix’ from ‘xstrncpy’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 789,
                    "column": 17,
                    "event": "note",
                    "message": "(32) ‘xcalloc(1, 152)’ leaks here; was allocated at (20)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  787|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  788|   \t\tDBG(ENDPOINTS, ul_debug(\"   path: %s\", ux->path));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  789|-> \t\tadd_sock_info(&ux->sock);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  790|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  791|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "a41bb70ef5a9f09fbeb39c5925a7967e3734b750",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘load_xinfo_from_proc_netlink’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2218,
                    "column": 17,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 40)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 207,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘load_sock_xinfo_with_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 210,
                    "column": 17,
                    "event": "note",
                    "message": "(2) calling ‘load_sock_xinfo_no_nsswitch’ from ‘load_sock_xinfo_with_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 173,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘load_sock_xinfo_no_nsswitch’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 190,
                    "column": 9,
                    "event": "note",
                    "message": "(4) calling ‘load_xinfo_from_proc_netlink’ from ‘load_sock_xinfo_no_nsswitch’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2180,
                    "column": 13,
                    "event": "note",
                    "message": "(5) entry to ‘load_xinfo_from_proc_netlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2186,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2189,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2189,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2191,
                    "column": 19,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2191,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2195,
                    "column": 16,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2202,
                    "column": 21,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2209,
                    "column": 22,
                    "event": "note",
                    "message": "(14) calling ‘xcalloc’ from ‘load_xinfo_from_proc_netlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(15) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(16) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(17) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2209,
                    "column": 22,
                    "event": "note",
                    "message": "(20) returning to ‘load_xinfo_from_proc_netlink’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2218,
                    "column": 17,
                    "event": "note",
                    "message": "(21) ‘xcalloc(1, 40)’ leaks here; was allocated at (16)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2216|   \t\tnl->groups = groups;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2217|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2218|-> \t\tadd_sock_info(&nl->sock);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2219|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2220|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "93945ac9a59a88bcd9efa9520d06f33197fb90c4",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘load_xinfo_from_proc_packet’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2622,
                    "column": 17,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 32)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2587,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘load_xinfo_from_proc_packet’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2593,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2596,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2596,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2598,
                    "column": 19,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2598,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2602,
                    "column": 16,
                    "event": "note",
                    "message": "(8) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2609,
                    "column": 21,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2609,
                    "column": 20,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2613,
                    "column": 23,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2613,
                    "column": 23,
                    "event": "note",
                    "message": "(12) calling ‘xcalloc’ from ‘load_xinfo_from_proc_packet’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(14) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(15) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2613,
                    "column": 23,
                    "event": "note",
                    "message": "(18) returning to ‘load_xinfo_from_proc_packet’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2622,
                    "column": 17,
                    "event": "note",
                    "message": "(19) ‘xcalloc(1, 32)’ leaks here; was allocated at (14)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2620|   \t\tpkt->iface = iface;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2621|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2622|-> \t\tadd_sock_info(&pkt->sock);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2623|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2624|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "8df7ae21be5c384043c4c63810dfd4180dd1c126",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘handle_diag_vsock’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2826,
                    "column": 9,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 48)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2785,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘handle_diag_vsock’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2793,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 52,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2795,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2799,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘nlmsg_len > 47’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2802,
                    "column": 28,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2806,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2810,
                    "column": 14,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2810,
                    "column": 14,
                    "event": "note",
                    "message": "(8) calling ‘xcalloc’ from ‘handle_diag_vsock’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(9) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(10) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(11) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2810,
                    "column": 14,
                    "event": "note",
                    "message": "(14) returning to ‘handle_diag_vsock’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/sock-xinfo.c",
                    "line": 2826,
                    "column": 9,
                    "event": "note",
                    "message": "(15) ‘xcalloc(1, 48)’ leaks here; was allocated at (10)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2824|   \tvx->remote.port = diag->vdiag_dst_port;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2825|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2826|-> \tadd_sock_info(xinfo);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2827|   \treturn true;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2828|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f3c87b76535674cc5346620e8faac5c48b3c15a6",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 70,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘xgethostname’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 186,
                    "column": 13,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘xmalloc(sz)’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 345,
                    "column": 14,
                    "event": "note",
                    "message": "(1) entry to ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 351,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘xmalloc’ from ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 351,
                    "column": 16,
                    "event": "note",
                    "message": "(6) returning to ‘makemsg’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 353,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘print_banner == 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 354,
                    "column": 34,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 354,
                    "column": 34,
                    "event": "note",
                    "message": "(9) calling ‘xgethostname’ from ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 180,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xgethostname’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 185,
                    "column": 16,
                    "event": "note",
                    "message": "(11) calling ‘xmalloc’ from ‘xgethostname’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(12) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(13) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 185,
                    "column": 16,
                    "event": "note",
                    "message": "(16) returning to ‘xgethostname’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 186,
                    "column": 13,
                    "event": "note",
                    "message": "(17) argument 1 (‘xmalloc(sz)’) from (13) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/bits/sigstksz.h",
                    "line": 24,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/signal.h",
                    "line": 328,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/sys/param.h",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 45,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/unistd.h",
                    "line": 911,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘gethostname’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  184|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  185|   \tname = xmalloc(sizeof(char) * sz);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  186|-> \tif (gethostname(name, sz) != 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  187|   \t\tfree(name);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  188|   \t\treturn NULL;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "bf5f4255b1b602ecf7be13626218cf32c7ae8e8e",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘makemsg’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 382,
                    "column": 17,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘fs’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 345,
                    "column": 14,
                    "event": "note",
                    "message": "(1) entry to ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 349,
                    "column": 21,
                    "event": "note",
                    "message": "(2) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 351,
                    "column": 16,
                    "event": "note",
                    "message": "(3) calling ‘xmalloc’ from ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(4) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 351,
                    "column": 16,
                    "event": "note",
                    "message": "(7) returning to ‘makemsg’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 353,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘true’ branch (when ‘print_banner == 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 354,
                    "column": 34,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 354,
                    "column": 34,
                    "event": "note",
                    "message": "(10) calling ‘xgethostname’ from ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 180,
                    "column": 7,
                    "event": "note",
                    "message": "(11) entry to ‘xgethostname’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 185,
                    "column": 16,
                    "event": "note",
                    "message": "(12) calling ‘xmalloc’ from ‘xgethostname’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 185,
                    "column": 16,
                    "event": "note",
                    "message": "(16) returning to ‘xgethostname’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 186,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 187,
                    "column": 17,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 354,
                    "column": 34,
                    "event": "note",
                    "message": "(19) returning to ‘makemsg’ from ‘xgethostname’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 382,
                    "column": 17,
                    "event": "note",
                    "message": "(20) argument 1 (‘fs’) from (2) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 54,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘fprintf’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  380|   \t\t/* snprintf is not always available, but the sprintf's here",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  381|   \t\t   will not overflow as long as %d takes at most 100 chars */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  382|-> \t\tfprintf(fs, \"\\r%*s\\r\\n\", TERM_WIDTH, \" \");",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  383|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  384|   \t\tsnprintf(lbuf, lbuflen,",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ea9ec5924cba9f291b283ef7caa2e28ea7a7bf59",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 391,
                    "column": 9,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘fs’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 345,
                    "column": 14,
                    "event": "note",
                    "message": "(1) entry to ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 349,
                    "column": 21,
                    "event": "note",
                    "message": "(2) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 351,
                    "column": 16,
                    "event": "note",
                    "message": "(3) calling ‘xmalloc’ from ‘makemsg’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(4) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 351,
                    "column": 16,
                    "event": "note",
                    "message": "(7) returning to ‘makemsg’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 353,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch (when ‘print_banner != 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 391,
                    "column": 9,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/wall.c",
                    "line": 391,
                    "column": 9,
                    "event": "note",
                    "message": "(10) argument 1 (‘fs’) from (2) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘fprintf’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  389|   \t\tfree(whombuf);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  390|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  391|-> \tfprintf(fs, \"%*s\\r\\n\", TERM_WIDTH, \" \");",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  392|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  393|   \t if (mvec) {",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "96f504edb65766677fe7ddb0d7afa7fab9e6c3ba",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_passwd’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 216,
                    "column": 1,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘gecos’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 396,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 414,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘parse_argv’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 133,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 147,
                    "column": 42,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘c == -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 184,
                    "column": 12,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 184,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch (when ‘status == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 187,
                    "column": 20,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 414,
                    "column": 9,
                    "event": "note",
                    "message": "(8) returning to ‘main’ from ‘parse_argv’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 415,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 416,
                    "column": 26,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 417,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 420,
                    "column": 38,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 427,
                    "column": 9,
                    "event": "note",
                    "message": "(13) calling ‘parse_passwd’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 200,
                    "column": 13,
                    "event": "note",
                    "message": "(14) entry to ‘parse_passwd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 204,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 207,
                    "column": 32,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 207,
                    "column": 17,
                    "event": "note",
                    "message": "(17) calling ‘xstrdup’ from ‘parse_passwd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 43,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 35,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(19) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(21) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(22) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 207,
                    "column": 17,
                    "event": "note",
                    "message": "(25) returning to ‘parse_passwd’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/chfn.c",
                    "line": 216,
                    "column": 1,
                    "event": "note",
                    "message": "(26) ‘gecos’ leaks here; was allocated at (21)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  214|   \t *  not be changed by this version of chfn.  */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  215|   \tctl->oldf.other = strsep(&gecos, \",\");",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  216|-> }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  217|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  218|   /*",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "41dc0057c3f4f201a0cc0b5705906b42e650fee2",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘process_wtmp_file’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 195,
                    "column": 18,
                    "event": "warning[-Wanalyzer-file-leak]",
                    "message": "leak of FILE ‘fopen(filename, \"r\")’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 967,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1019,
                    "column": 78,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘c == -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1092,
                    "column": 20,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1095,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘files’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1096,
                    "column": 25,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1096,
                    "column": 25,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 48,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1096,
                    "column": 25,
                    "event": "note",
                    "message": "(10) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1097,
                    "column": 35,
                    "event": "note",
                    "message": "(11) calling ‘xstrdup’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(12) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 8,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 46,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1097,
                    "column": 35,
                    "event": "note",
                    "message": "(17) returning to ‘main’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1100,
                    "column": 23,
                    "event": "note",
                    "message": "(18) following ‘true’ branch (when ‘i < nfiles’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1101,
                    "column": 17,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1102,
                    "column": 17,
                    "event": "note",
                    "message": "(20) calling ‘process_wtmp_file’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 659,
                    "column": 13,
                    "event": "note",
                    "message": "(21) entry to ‘process_wtmp_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 701,
                    "column": 19,
                    "event": "note",
                    "message": "(22) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 701,
                    "column": 12,
                    "event": "note",
                    "message": "(23) assuming ‘fopen(filename, \"r\")’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 701,
                    "column": 12,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 707,
                    "column": 9,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 712,
                    "column": 13,
                    "event": "note",
                    "message": "(26) calling ‘uread’ from ‘process_wtmp_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 186,
                    "column": 12,
                    "event": "note",
                    "message": "(27) entry to ‘uread’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 195,
                    "column": 12,
                    "event": "note",
                    "message": "(28) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 199,
                    "column": 24,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 712,
                    "column": 13,
                    "event": "note",
                    "message": "(30) returning to ‘process_wtmp_file’ from ‘uread’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 712,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 715,
                    "column": 21,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 195,
                    "column": 18,
                    "event": "note",
                    "message": "(33) ‘fopen(filename, \"r\")’ leaks here; was opened at (22)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  193|   \toff_t o;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  194|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  195|-> \tif (quit == NULL && u != NULL) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  196|   \t\t/*",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  197|   \t\t *\tNormal read.",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b57806d3f1deacfc111a27c2ef02ae5945f1a109",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 195,
                    "column": 18,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘fopen(filename, \"r\")’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 967,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1019,
                    "column": 78,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘c == -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1092,
                    "column": 20,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1095,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘files’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1096,
                    "column": 25,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1096,
                    "column": 25,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1096,
                    "column": 25,
                    "event": "note",
                    "message": "(10) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1097,
                    "column": 35,
                    "event": "note",
                    "message": "(11) calling ‘xstrdup’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(12) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1097,
                    "column": 35,
                    "event": "note",
                    "message": "(17) returning to ‘main’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1100,
                    "column": 23,
                    "event": "note",
                    "message": "(18) following ‘true’ branch (when ‘i < nfiles’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1101,
                    "column": 17,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1102,
                    "column": 17,
                    "event": "note",
                    "message": "(20) calling ‘process_wtmp_file’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 659,
                    "column": 13,
                    "event": "note",
                    "message": "(21) entry to ‘process_wtmp_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 701,
                    "column": 19,
                    "event": "note",
                    "message": "(22) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 701,
                    "column": 12,
                    "event": "note",
                    "message": "(23) assuming ‘fopen(filename, \"r\")’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 701,
                    "column": 12,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 707,
                    "column": 9,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 712,
                    "column": 13,
                    "event": "note",
                    "message": "(26) calling ‘uread’ from ‘process_wtmp_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 186,
                    "column": 12,
                    "event": "note",
                    "message": "(27) entry to ‘uread’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 195,
                    "column": 12,
                    "event": "note",
                    "message": "(28) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 199,
                    "column": 24,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 712,
                    "column": 13,
                    "event": "note",
                    "message": "(30) returning to ‘process_wtmp_file’ from ‘uread’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 712,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 715,
                    "column": 21,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 195,
                    "column": 18,
                    "event": "note",
                    "message": "(33) ‘fopen(filename, \"r\")’ leaks here; was allocated at (22)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  193|   \toff_t o;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  194|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  195|-> \tif (quit == NULL && u != NULL) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  196|   \t\t/*",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  197|   \t\t *\tNormal read.",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "041d4e8cf3bdb3bdd568f780fd848ca796336157",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1041,
                    "column": 41,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘files’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 967,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1019,
                    "column": 78,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1021,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1021,
                    "column": 17,
                    "event": "note",
                    "message": "(4) calling ‘err_exclusive_options’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(5) entry to ‘err_exclusive_options’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 95,
                    "column": 32,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 95,
                    "column": 32,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 98,
                    "column": 28,
                    "event": "note",
                    "message": "(8) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 99,
                    "column": 28,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1021,
                    "column": 17,
                    "event": "note",
                    "message": "(10) returning to ‘main’ from ‘err_exclusive_options’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1023,
                    "column": 17,
                    "event": "note",
                    "message": "(11) following ‘case 102:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1038,
                    "column": 17,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1039,
                    "column": 28,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘files’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1040,
                    "column": 41,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1040,
                    "column": 41,
                    "event": "note",
                    "message": "(15) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(16) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(17) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1040,
                    "column": 41,
                    "event": "note",
                    "message": "(20) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1041,
                    "column": 43,
                    "event": "note",
                    "message": "(21) calling ‘xstrdup’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(22) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(23) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1041,
                    "column": 43,
                    "event": "note",
                    "message": "(27) returning to ‘main’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/last.c",
                    "line": 1041,
                    "column": 41,
                    "event": "note",
                    "message": "(28) ‘files + nfiles * 8’ could be NULL: unchecked value from (17)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1039|   \t\t\tif (!files)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1040|   \t\t\t\tfiles = xmalloc(sizeof(char *) * argc);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1041|-> \t\t\tfiles[nfiles++] = xstrdup(optarg);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1042|   \t\t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1043|   \t\tcase 'd':",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "6079779ed69abd0e0e0a79411e207384e1f7b37d",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 76,
                    "column": 28,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(\"/dev/tty\", 524288)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 53,
                    "column": 17,
                    "event": "note",
                    "message": "(1) following ‘case 102:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 65,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 70,
                    "column": 13,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 70,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 73,
                    "column": 12,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 73,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘foreground != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 74,
                    "column": 22,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 74,
                    "column": 22,
                    "event": "note",
                    "message": "(9) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 75,
                    "column": 20,
                    "event": "note",
                    "message": "(10) assuming ‘open(\"/dev/tty\", 524288)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 75,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 76,
                    "column": 29,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 76,
                    "column": 28,
                    "event": "note",
                    "message": "(13) ‘open(\"/dev/tty\", 524288)’ leaks here; was opened at (9)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   74|   \t\tfd = open(\"/dev/tty\", O_RDONLY|O_CLOEXEC);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   75|   \t\tif (fd >= 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   76|-> \t\t\tif (sigemptyset(&s) < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   77|   \t\t\t\terr(EXIT_FAILURE, _(\"sigemptyset failed\"));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   78|   \t\t\tif (sigaddset(&s, SIGTTOU) < 0)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "76fc3dfb9f32d5bdac2a78433863d6cad34459b2",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 78,
                    "column": 28,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(\"/dev/tty\", 524288)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 53,
                    "column": 17,
                    "event": "note",
                    "message": "(1) following ‘case 102:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 65,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 70,
                    "column": 13,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 70,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 73,
                    "column": 12,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 73,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘foreground != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 74,
                    "column": 22,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 74,
                    "column": 22,
                    "event": "note",
                    "message": "(9) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 75,
                    "column": 20,
                    "event": "note",
                    "message": "(10) assuming ‘open(\"/dev/tty\", 524288)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 75,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 76,
                    "column": 29,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 76,
                    "column": 28,
                    "event": "note",
                    "message": "(13) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 78,
                    "column": 29,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 78,
                    "column": 28,
                    "event": "note",
                    "message": "(15) ‘open(\"/dev/tty\", 524288)’ leaks here; was opened at (9)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   76|   \t\t\tif (sigemptyset(&s) < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   77|   \t\t\t\terr(EXIT_FAILURE, _(\"sigemptyset failed\"));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   78|-> \t\t\tif (sigaddset(&s, SIGTTOU) < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   79|   \t\t\t\terr(EXIT_FAILURE, _(\"sigaddset failed\"));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   80|   \t\t\tif (sigprocmask(SIG_BLOCK, &s, &old) < 0)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "405d2073eeb9aed302bd634f47e2d8d8b453ebcc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 80,
                    "column": 28,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(\"/dev/tty\", 524288)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 53,
                    "column": 17,
                    "event": "note",
                    "message": "(1) following ‘case 102:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 65,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 70,
                    "column": 13,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 70,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 73,
                    "column": 12,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 73,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘foreground != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 74,
                    "column": 22,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 74,
                    "column": 22,
                    "event": "note",
                    "message": "(9) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 75,
                    "column": 20,
                    "event": "note",
                    "message": "(10) assuming ‘open(\"/dev/tty\", 524288)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 75,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 76,
                    "column": 29,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 76,
                    "column": 28,
                    "event": "note",
                    "message": "(13) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 78,
                    "column": 29,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 78,
                    "column": 28,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 80,
                    "column": 29,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpgid.c",
                    "line": 80,
                    "column": 28,
                    "event": "note",
                    "message": "(17) ‘open(\"/dev/tty\", 524288)’ leaks here; was opened at (9)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   78|   \t\t\tif (sigaddset(&s, SIGTTOU) < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   79|   \t\t\t\terr(EXIT_FAILURE, _(\"sigaddset failed\"));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   80|-> \t\t\tif (sigprocmask(SIG_BLOCK, &s, &old) < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   81|   \t\t\t\terr(EXIT_FAILURE, _(\"sigprocmask failed\"));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   82|   \t\t\tif (tcsetpgrp(fd, getpgid(0)) < 0)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "001b8765c0a0f67de9c34aa398fe7fcd9b7fa084",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 32,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘xreallocarray’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘<unknown>’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 529,
                    "column": 24,
                    "event": "note",
                    "message": "(1) entry to ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 545,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘get_irqinfo’ from ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 237,
                    "column": 25,
                    "event": "note",
                    "message": "(3) entry to ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 247,
                    "column": 16,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 247,
                    "column": 16,
                    "event": "note",
                    "message": "(8) returning to ‘get_irqinfo’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 249,
                    "column": 26,
                    "event": "note",
                    "message": "(9) calling ‘xmalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 249,
                    "column": 26,
                    "event": "note",
                    "message": "(13) returning to ‘get_irqinfo’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 253,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 259,
                    "column": 13,
                    "event": "note",
                    "message": "(15) inlined call to ‘getline’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/bits/stdio.h",
                    "line": 120,
                    "column": 10,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘xreallocarray’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 259,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 264,
                    "column": 13,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/ctype.h",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 14,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 23,
                    "event": "note",
                    "message": "(19) when ‘strstr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 43,
                    "event": "note",
                    "message": "(20) following ‘false’ branch (when ‘tmp’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 270,
                    "column": 35,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 273,
                    "column": 46,
                    "event": "note",
                    "message": "(22) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 278,
                    "column": 23,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 278,
                    "column": 23,
                    "event": "note",
                    "message": "(24) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 279,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following ‘false’ branch (when ‘tmp’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 282,
                    "column": 26,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 287,
                    "column": 29,
                    "event": "note",
                    "message": "(27) calling ‘xstrdup’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(28) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 27,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(29) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 287,
                    "column": 29,
                    "event": "note",
                    "message": "(33) returning to ‘get_irqinfo’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 288,
                    "column": 17,
                    "event": "note",
                    "message": "(34) calling ‘ltrim_whitespace’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 31,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 369,
                    "column": 22,
                    "event": "note",
                    "message": "(35) entry to ‘ltrim_whitespace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 374,
                    "column": 12,
                    "event": "note",
                    "message": "(36) following ‘false’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 380,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch (when ‘p <= str’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 288,
                    "column": 17,
                    "event": "note",
                    "message": "(40) returning to ‘get_irqinfo’ from ‘ltrim_whitespace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 291,
                    "column": 63,
                    "event": "note",
                    "message": "(41) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 306,
                    "column": 20,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 309,
                    "column": 28,
                    "event": "note",
                    "message": "(43) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 317,
                    "column": 46,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 317,
                    "column": 46,
                    "event": "note",
                    "message": "(45) calling ‘xstrdup’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(46) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(47) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(49) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(50) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(51) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 317,
                    "column": 46,
                    "event": "note",
                    "message": "(53) returning to ‘get_irqinfo’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 320,
                    "column": 20,
                    "event": "note",
                    "message": "(54) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 321,
                    "column": 43,
                    "event": "note",
                    "message": "(55) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 322,
                    "column": 42,
                    "event": "note",
                    "message": "(56) calling ‘xreallocarray’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(57) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(58) ‘<unknown>’ leaks here; was allocated at (49)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   52|   void *xreallocarray(void *ptr, const size_t nelems, const size_t size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|-> \tvoid *ret = reallocarray(ptr, nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "25462582c19d65affb57148537785756831b90a7",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘sort_result’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 403,
                    "column": 9,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘result’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 529,
                    "column": 24,
                    "event": "note",
                    "message": "(1) entry to ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 545,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘get_irqinfo’ from ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 237,
                    "column": 25,
                    "event": "note",
                    "message": "(3) entry to ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 247,
                    "column": 16,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 247,
                    "column": 16,
                    "event": "note",
                    "message": "(8) returning to ‘get_irqinfo’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 249,
                    "column": 26,
                    "event": "note",
                    "message": "(9) calling ‘xmalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 249,
                    "column": 26,
                    "event": "note",
                    "message": "(13) returning to ‘get_irqinfo’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 253,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 259,
                    "column": 13,
                    "event": "note",
                    "message": "(15) inlined call to ‘getline’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/bits/stdio.h",
                    "line": 120,
                    "column": 10,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘sort_result’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 259,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 264,
                    "column": 13,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 23,
                    "event": "note",
                    "message": "(19) when ‘strstr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 43,
                    "event": "note",
                    "message": "(20) following ‘false’ branch (when ‘tmp’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 270,
                    "column": 35,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 270,
                    "column": 23,
                    "event": "note",
                    "message": "(22) calling ‘xcalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(23) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 270,
                    "column": 23,
                    "event": "note",
                    "message": "(26) returning to ‘get_irqinfo’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 273,
                    "column": 46,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 326,
                    "column": 9,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 545,
                    "column": 16,
                    "event": "note",
                    "message": "(29) returning to ‘get_scols_table’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 546,
                    "column": 12,
                    "event": "note",
                    "message": "(30) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 549,
                    "column": 46,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 550,
                    "column": 18,
                    "event": "note",
                    "message": "(32) calling ‘xmalloc’ from ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(33) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(34) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(35) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 550,
                    "column": 18,
                    "event": "note",
                    "message": "(37) returning to ‘get_scols_table’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 553,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch (when ‘prev’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 563,
                    "column": 38,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 563,
                    "column": 9,
                    "event": "note",
                    "message": "(40) calling ‘sort_result’ from ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 394,
                    "column": 13,
                    "event": "note",
                    "message": "(41) entry to ‘sort_result’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 403,
                    "column": 9,
                    "event": "note",
                    "message": "(42) argument 1 (‘result’) from (34) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/stdlib.h",
                    "line": 998,
                    "column": 13,
                    "event": "note",
                    "message": "argument 1 of ‘qsort’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  401|   \t\tfunc = out->sort_cmp_func;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  402|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  403|-> \tqsort(result, nmemb, sizeof(*result),",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  404|   \t\t\t(int (*)(const void *, const void *)) func);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  405|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ea48a354344a04ad93c602c0f6a1e3ff65b648bb",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘get_scols_table’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 559,
                    "column": 41,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘cur’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 529,
                    "column": 24,
                    "event": "note",
                    "message": "(1) entry to ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 545,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘get_irqinfo’ from ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 237,
                    "column": 25,
                    "event": "note",
                    "message": "(3) entry to ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 247,
                    "column": 16,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 247,
                    "column": 16,
                    "event": "note",
                    "message": "(8) returning to ‘get_irqinfo’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 249,
                    "column": 26,
                    "event": "note",
                    "message": "(9) calling ‘xmalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 249,
                    "column": 26,
                    "event": "note",
                    "message": "(13) returning to ‘get_irqinfo’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 253,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 259,
                    "column": 13,
                    "event": "note",
                    "message": "(15) inlined call to ‘getline’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/bits/stdio.h",
                    "line": 120,
                    "column": 10,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘get_scols_table’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 259,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 264,
                    "column": 13,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 23,
                    "event": "note",
                    "message": "(19) when ‘strstr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 43,
                    "event": "note",
                    "message": "(20) following ‘true’ branch (when ‘tmp’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 266,
                    "column": 21,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 23,
                    "event": "note",
                    "message": "(22) when ‘strstr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 265,
                    "column": 43,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘tmp’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 270,
                    "column": 35,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 270,
                    "column": 23,
                    "event": "note",
                    "message": "(25) calling ‘xcalloc’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(26) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 270,
                    "column": 23,
                    "event": "note",
                    "message": "(29) returning to ‘get_irqinfo’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 273,
                    "column": 46,
                    "event": "note",
                    "message": "(30) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 278,
                    "column": 23,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 278,
                    "column": 23,
                    "event": "note",
                    "message": "(32) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 279,
                    "column": 20,
                    "event": "note",
                    "message": "(33) following ‘false’ branch (when ‘tmp’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 282,
                    "column": 26,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 287,
                    "column": 29,
                    "event": "note",
                    "message": "(35) calling ‘xstrdup’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(36) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(37) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 287,
                    "column": 29,
                    "event": "note",
                    "message": "(41) returning to ‘get_irqinfo’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 288,
                    "column": 17,
                    "event": "note",
                    "message": "(42) calling ‘ltrim_whitespace’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 369,
                    "column": 22,
                    "event": "note",
                    "message": "(43) entry to ‘ltrim_whitespace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 374,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 380,
                    "column": 12,
                    "event": "note",
                    "message": "(46) following ‘false’ branch (when ‘p <= str’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(47) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 288,
                    "column": 17,
                    "event": "note",
                    "message": "(48) returning to ‘get_irqinfo’ from ‘ltrim_whitespace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 291,
                    "column": 63,
                    "event": "note",
                    "message": "(49) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 292,
                    "column": 58,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 309,
                    "column": 28,
                    "event": "note",
                    "message": "(51) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 317,
                    "column": 46,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 317,
                    "column": 46,
                    "event": "note",
                    "message": "(53) calling ‘xstrdup’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(54) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(55) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(56) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(57) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(58) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 317,
                    "column": 46,
                    "event": "note",
                    "message": "(59) returning to ‘get_irqinfo’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 320,
                    "column": 20,
                    "event": "note",
                    "message": "(60) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(61) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 273,
                    "column": 46,
                    "event": "note",
                    "message": "(62) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 326,
                    "column": 9,
                    "event": "note",
                    "message": "(63) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 545,
                    "column": 16,
                    "event": "note",
                    "message": "(64) returning to ‘get_scols_table’ from ‘get_irqinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 546,
                    "column": 12,
                    "event": "note",
                    "message": "(65) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 549,
                    "column": 46,
                    "event": "note",
                    "message": "(66) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 550,
                    "column": 18,
                    "event": "note",
                    "message": "(67) calling ‘xmalloc’ from ‘get_scols_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(68) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(69) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(70) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(71) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 550,
                    "column": 18,
                    "event": "note",
                    "message": "(72) returning to ‘get_scols_table’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 553,
                    "column": 12,
                    "event": "note",
                    "message": "(73) following ‘true’ branch (when ‘prev’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 554,
                    "column": 33,
                    "event": "note",
                    "message": "(74) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 555,
                    "column": 31,
                    "event": "note",
                    "message": "(75) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 556,
                    "column": 55,
                    "event": "note",
                    "message": "(76) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/irq-common.c",
                    "line": 559,
                    "column": 41,
                    "event": "note",
                    "message": "(77) ‘cur’ could be NULL: unchecked value from (69)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  557|   \t\t\tstruct irq_info *pre = &prev->irq_info[i];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  558|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  559|-> \t\t\tcur->delta = cur->total - pre->total;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  560|   \t\t\tstat->delta_irq += cur->delta;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  561|   \t\t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "557c2f929eaa730aff82a2fc870ff05348d0a486",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 57,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 120)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 1621,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 1626,
                    "column": 40,
                    "event": "note",
                    "message": "(2) calling ‘xcalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(5) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 1626,
                    "column": 40,
                    "event": "note",
                    "message": "(8) returning to ‘main’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 327,
                    "column": 25,
                    "event": "note",
                    "message": "(9) inlined call to ‘err_columns_index’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 1699,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘add_column’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 319,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 327,
                    "column": 67,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 1699,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘add_column’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 327,
                    "column": 25,
                    "event": "note",
                    "message": "(12) inlined call to ‘err_columns_index’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 1700,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘add_column’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 319,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 327,
                    "column": 67,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 1700,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘add_column’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(15) ‘xcalloc(1, 120)’ leaks here; was allocated at (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "2846cd98ef8755f2e2b0d8ff9d615752a70ca556",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_utmpx.part.0’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 530,
                    "column": 24,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘ary’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 496,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘parse_utmpx’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 510,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 511,
                    "column": 32,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 511,
                    "column": 20,
                    "event": "note",
                    "message": "(4) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 512,
                    "column": 30,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 513,
                    "column": 31,
                    "event": "note",
                    "message": "(6) calling ‘xreallocarray’ from ‘parse_utmpx’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(8) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(9) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 513,
                    "column": 31,
                    "event": "note",
                    "message": "(10) returning to ‘parse_utmpx’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 523,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 528,
                    "column": 20,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 528,
                    "column": 20,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘i == imax’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 529,
                    "column": 55,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 529,
                    "column": 31,
                    "event": "note",
                    "message": "(15) calling ‘xreallocarray’ from ‘parse_utmpx’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(16) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(17) state of ‘CONJURED(ret_9 = reallocarray (ptr_5(D), nelems_6(D), size_7(D));, ret_9)’: ‘nonnull’ -> ‘unchecked’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(18) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 26,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 26,
                    "event": "note",
                    "message": "(21) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 529,
                    "column": 31,
                    "event": "note",
                    "message": "(23) returning to ‘parse_utmpx’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/lslogins.c",
                    "line": 530,
                    "column": 24,
                    "event": "note",
                    "message": "(24) dereference of NULL ‘ary + i * 384’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  528|   \t\tif (i == imax)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  529|   \t\t\tary = xreallocarray(ary, imax *= 2, sizeof(struct utmpx));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  530|-> \t\tary[i] = *u;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  531|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  532|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "64192b263a16df85e937bc78ab245b3f51edd363",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘menu_update_ignore’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 875,
                    "column": 28,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘*m.ignore’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2742,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2811,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘cfdisk_init_debug’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 269,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘cfdisk_init_debug’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 65,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 106,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_STRING’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 271,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_ENV’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 89,
                    "column": 25,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 106,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_STRING’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 271,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_ENV’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2811,
                    "column": 9,
                    "event": "note",
                    "message": "(6) returning to ‘main’ from ‘cfdisk_init_debug’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2813,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2815,
                    "column": 12,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2837,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch (when ‘rc == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2840,
                    "column": 14,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2850,
                    "column": 9,
                    "event": "note",
                    "message": "(11) calling ‘ui_run’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2581,
                    "column": 12,
                    "event": "note",
                    "message": "(12) entry to ‘ui_run’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2604,
                    "column": 22,
                    "event": "note",
                    "message": "(13) calling ‘ui_create_label’ from ‘ui_run’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2161,
                    "column": 12,
                    "event": "note",
                    "message": "(14) entry to ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 55,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2168,
                    "column": 9,
                    "event": "note",
                    "message": "(15) following ‘true’ branch (when ‘cf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2170,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2175,
                    "column": 14,
                    "event": "note",
                    "message": "(17) calling ‘xcalloc’ from ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 61,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2175,
                    "column": 14,
                    "event": "note",
                    "message": "(21) returning to ‘ui_create_label’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2188,
                    "column": 9,
                    "event": "note",
                    "message": "(22) calling ‘menu_push’ from ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 894,
                    "column": 28,
                    "event": "note",
                    "message": "(23) entry to ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 898,
                    "column": 33,
                    "event": "note",
                    "message": "(24) calling ‘xcalloc’ from ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(25) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 898,
                    "column": 33,
                    "event": "note",
                    "message": "(28) returning to ‘menu_push’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 901,
                    "column": 9,
                    "event": "note",
                    "message": "(29) following ‘true’ branch (when ‘cf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 903,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 918,
                    "column": 9,
                    "event": "note",
                    "message": "(31) calling ‘menu_refresh_size’ from ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 838,
                    "column": 13,
                    "event": "note",
                    "message": "(32) entry to ‘menu_refresh_size’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 840,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 840,
                    "column": 33,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(35) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 842,
                    "column": 1,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 918,
                    "column": 9,
                    "event": "note",
                    "message": "(37) returning to ‘menu_push’ from ‘menu_refresh_size’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2188,
                    "column": 9,
                    "event": "note",
                    "message": "(38) returning to ‘ui_create_label’ from ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2192,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2196,
                    "column": 16,
                    "event": "note",
                    "message": "(41) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2199,
                    "column": 20,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2199,
                    "column": 20,
                    "event": "note",
                    "message": "(43) following ‘true’ branch (when ‘refresh_menu != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2200,
                    "column": 25,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2200,
                    "column": 25,
                    "event": "note",
                    "message": "(45) calling ‘ui_draw_menu’ from ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1171,
                    "column": 13,
                    "event": "note",
                    "message": "(46) entry to ‘ui_draw_menu’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1179,
                    "column": 9,
                    "event": "note",
                    "message": "(47) following ‘true’ branch (when ‘cf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1180,
                    "column": 18,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1180,
                    "column": 9,
                    "event": "note",
                    "message": "(49) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1182,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 20,
                    "event": "note",
                    "message": "(51) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1182,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 65,
                    "column": 25,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1182,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1192,
                    "column": 12,
                    "event": "note",
                    "message": "(53) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1193,
                    "column": 17,
                    "event": "note",
                    "message": "(54) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 1193,
                    "column": 17,
                    "event": "note",
                    "message": "(55) calling ‘menu_update_ignore’ from ‘ui_draw_menu’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 844,
                    "column": 13,
                    "event": "note",
                    "message": "(56) entry to ‘menu_update_ignore’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 852,
                    "column": 9,
                    "event": "note",
                    "message": "(57) following ‘true’ branch (when ‘cf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 853,
                    "column": 18,
                    "event": "note",
                    "message": "(58) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 853,
                    "column": 9,
                    "event": "note",
                    "message": "(59) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 854,
                    "column": 24,
                    "event": "note",
                    "message": "(60) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 854,
                    "column": 9,
                    "event": "note",
                    "message": "(61) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(62) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 857,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 872,
                    "column": 21,
                    "event": "note",
                    "message": "(63) calling ‘xstrdup’ from ‘menu_update_ignore’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(64) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(65) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(66) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(67) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(68) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(69) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(70) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 872,
                    "column": 21,
                    "event": "note",
                    "message": "(71) returning to ‘menu_update_ignore’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 875,
                    "column": 28,
                    "event": "note",
                    "message": "(72) ‘*m.ignore’ leaks here; was allocated at (67)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  873|   \tm->nitems = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  874|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  875|-> \tfor (d = m->items; d->name; d++) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  876|   \t\tif (m->ignore && strchr(m->ignore, d->key))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  877|   \t\t\tcontinue;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "72f00f63f06a6e97992e39c4542458f021dfcbf1",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘menu_set_title’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 952,
                    "column": 1,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘str’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2742,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2811,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘cfdisk_init_debug’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 269,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘cfdisk_init_debug’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 106,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_STRING’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 271,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_ENV’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 89,
                    "column": 25,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 106,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_STRING’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 271,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_ENV’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2811,
                    "column": 9,
                    "event": "note",
                    "message": "(6) returning to ‘main’ from ‘cfdisk_init_debug’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2813,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2815,
                    "column": 12,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2837,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch (when ‘rc == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2840,
                    "column": 14,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2850,
                    "column": 9,
                    "event": "note",
                    "message": "(11) calling ‘ui_run’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2581,
                    "column": 12,
                    "event": "note",
                    "message": "(12) entry to ‘ui_run’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2604,
                    "column": 22,
                    "event": "note",
                    "message": "(13) calling ‘ui_create_label’ from ‘ui_run’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2161,
                    "column": 12,
                    "event": "note",
                    "message": "(14) entry to ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2168,
                    "column": 9,
                    "event": "note",
                    "message": "(15) following ‘true’ branch (when ‘cf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2170,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2175,
                    "column": 14,
                    "event": "note",
                    "message": "(17) calling ‘xcalloc’ from ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2175,
                    "column": 14,
                    "event": "note",
                    "message": "(21) returning to ‘ui_create_label’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2188,
                    "column": 9,
                    "event": "note",
                    "message": "(22) calling ‘menu_push’ from ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 894,
                    "column": 28,
                    "event": "note",
                    "message": "(23) entry to ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 898,
                    "column": 33,
                    "event": "note",
                    "message": "(24) calling ‘xcalloc’ from ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(25) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 898,
                    "column": 33,
                    "event": "note",
                    "message": "(28) returning to ‘menu_push’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 901,
                    "column": 9,
                    "event": "note",
                    "message": "(29) following ‘true’ branch (when ‘cf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 903,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 918,
                    "column": 9,
                    "event": "note",
                    "message": "(31) calling ‘menu_refresh_size’ from ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 838,
                    "column": 13,
                    "event": "note",
                    "message": "(32) entry to ‘menu_refresh_size’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 840,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 840,
                    "column": 33,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(35) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 842,
                    "column": 1,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 918,
                    "column": 9,
                    "event": "note",
                    "message": "(37) returning to ‘menu_push’ from ‘menu_refresh_size’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2188,
                    "column": 9,
                    "event": "note",
                    "message": "(38) returning to ‘ui_create_label’ from ‘menu_push’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2190,
                    "column": 9,
                    "event": "note",
                    "message": "(39) calling ‘menu_set_title’ from ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 940,
                    "column": 13,
                    "event": "note",
                    "message": "(40) entry to ‘menu_set_title’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 944,
                    "column": 12,
                    "event": "note",
                    "message": "(41) following ‘true’ branch (when ‘title’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 945,
                    "column": 31,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 946,
                    "column": 20,
                    "event": "note",
                    "message": "(43) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 947,
                    "column": 34,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 948,
                    "column": 23,
                    "event": "note",
                    "message": "(45) calling ‘xstrdup’ from ‘menu_set_title’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(46) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(47) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(49) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(50) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(51) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 948,
                    "column": 23,
                    "event": "note",
                    "message": "(53) returning to ‘menu_set_title’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 952,
                    "column": 1,
                    "event": "note",
                    "message": "(54) ‘str’ leaks here; was allocated at (49)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  950|   \tfree(m->title);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  951|   \tm->title = str;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  952|-> }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  953|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  954|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "acf03ea9aeeaf4cff35d0e384cc069c1ba98690d",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘ui_create_label’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2182,
                    "column": 30,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘xcalloc(fdisk_get_nlabels(*cf.cxt) + 1, 32) + i * 32’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2742,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2811,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘cfdisk_init_debug’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 269,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘cfdisk_init_debug’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 106,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_STRING’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 271,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_ENV’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 89,
                    "column": 25,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 106,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_STRING’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 271,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_INIT_DEBUG_FROM_ENV’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2811,
                    "column": 9,
                    "event": "note",
                    "message": "(6) returning to ‘main’ from ‘cfdisk_init_debug’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2813,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2815,
                    "column": 12,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2837,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch (when ‘rc == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2840,
                    "column": 14,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2850,
                    "column": 9,
                    "event": "note",
                    "message": "(11) calling ‘ui_run’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2581,
                    "column": 12,
                    "event": "note",
                    "message": "(12) entry to ‘ui_run’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2604,
                    "column": 22,
                    "event": "note",
                    "message": "(13) calling ‘ui_create_label’ from ‘ui_run’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2161,
                    "column": 12,
                    "event": "note",
                    "message": "(14) entry to ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2168,
                    "column": 9,
                    "event": "note",
                    "message": "(15) following ‘true’ branch (when ‘cf’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 267,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2170,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2175,
                    "column": 14,
                    "event": "note",
                    "message": "(17) calling ‘xcalloc’ from ‘ui_create_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(19) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(20) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2175,
                    "column": 14,
                    "event": "note",
                    "message": "(25) returning to ‘ui_create_label’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2177,
                    "column": 52,
                    "event": "note",
                    "message": "(26) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2179,
                    "column": 21,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2179,
                    "column": 20,
                    "event": "note",
                    "message": "(28) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2180,
                    "column": 21,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2179,
                    "column": 49,
                    "event": "note",
                    "message": "(30) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2182,
                    "column": 32,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/cfdisk.c",
                    "line": 2182,
                    "column": 30,
                    "event": "note",
                    "message": "(32) dereference of NULL ‘xcalloc(fdisk_get_nlabels(*cf.cxt) + 1, 32) + i * 32’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2180|   \t\t    fdisk_label_get_type(lb) == FDISK_DISKLABEL_BSD)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2181|   \t\t\tcontinue;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2182|-> \t\tcm[i++].name = fdisk_label_get_name(lb);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2183|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2184|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b286adfde32b8541cac8c47f65937db2286e1e76",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lsipc.c",
                    "line": 42,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 8)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lsipc.c",
                    "line": 1439,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lsipc.c",
                    "line": 1445,
                    "column": 37,
                    "event": "note",
                    "message": "(2) calling ‘xcalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(5) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lsipc.c",
                    "line": 1445,
                    "column": 37,
                    "event": "note",
                    "message": "(8) returning to ‘main’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lsipc.c",
                    "line": 1641,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lsipc.c",
                    "line": 1643,
                    "column": 31,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(11) ‘xcalloc(1, 8)’ leaks here; was allocated at (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "8f413453237a60db4f975da913a3681c6ccff91d",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘lscpu_create_cpus’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 68,
                    "column": 40,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘*cxt.cpus’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 57,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘lscpu_create_cpus’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.h",
                    "line": 17,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 11,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 61,
                    "column": 9,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/sched.h",
                    "line": 44,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/cpuset.h",
                    "line": 10,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 63,
                    "column": 27,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 64,
                    "column": 21,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘lscpu_create_cpus’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.h",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(6) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 64,
                    "column": 21,
                    "event": "note",
                    "message": "(9) returning to ‘lscpu_create_cpus’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 66,
                    "column": 54,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 67,
                    "column": 21,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 67,
                    "column": 21,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 68,
                    "column": 42,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 68,
                    "column": 42,
                    "event": "note",
                    "message": "(14) calling ‘lscpu_new_cpu’ from ‘lscpu_create_cpus’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 13,
                    "column": 19,
                    "event": "note",
                    "message": "(15) entry to ‘lscpu_new_cpu’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 17,
                    "column": 15,
                    "event": "note",
                    "message": "(16) calling ‘xcalloc’ from ‘lscpu_new_cpu’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(17) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 17,
                    "column": 15,
                    "event": "note",
                    "message": "(20) returning to ‘lscpu_new_cpu’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.h",
                    "line": 26,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 20,
                    "event": "note",
                    "message": "(21) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.h",
                    "line": 37,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 27,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 28,
                    "column": 16,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 68,
                    "column": 42,
                    "event": "note",
                    "message": "(23) returning to ‘lscpu_create_cpus’ from ‘lscpu_new_cpu’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu-cpu.c",
                    "line": 68,
                    "column": 40,
                    "event": "note",
                    "message": "(24) ‘*cxt.cpus + i * 8’ could be NULL: unchecked value from (6)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tfor (n = 0, i = 0; n < (size_t) cxt->maxcpus && i < cxt->npossibles; n++) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   \t\tif (CPU_ISSET_S(n, setsize, cpuset))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \t\t\tcxt->cpus[i++] = lscpu_new_cpu(n);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "12bb06e880071bceb3b5a71a1f3c2c7e91357f35",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 48)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_prlim’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 492,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 545,
                    "column": 51,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘opt != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 546,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 546,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 99:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 547,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 548,
                    "column": 25,
                    "event": "note",
                    "message": "(6) calling ‘add_prlim’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 478,
                    "column": 12,
                    "event": "note",
                    "message": "(7) entry to ‘add_prlim’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 480,
                    "column": 31,
                    "event": "note",
                    "message": "(8) calling ‘xcalloc’ from ‘add_prlim’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 29,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(9) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(10) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(11) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 480,
                    "column": 31,
                    "event": "note",
                    "message": "(14) returning to ‘add_prlim’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 485,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch (when ‘ops’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/prlimit.c",
                    "line": 488,
                    "column": 9,
                    "event": "note",
                    "message": "(16) inlined call to ‘list_add_tail’ from ‘add_prlim’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_prlim’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(18) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(19) ‘xcalloc(1, 48)’ leaks here; was allocated at (10)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "a871a319350c84675edea861fae9bc61814de3c8",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv-landlock.c",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_landlock_rule’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc(32)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv-landlock.c",
                    "line": 132,
                    "column": 6,
                    "event": "note",
                    "message": "(1) entry to ‘parse_landlock_rule’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv-landlock.c",
                    "line": 134,
                    "column": 44,
                    "event": "note",
                    "message": "(2) calling ‘xmalloc’ from ‘parse_landlock_rule’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(5) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv-landlock.c",
                    "line": 134,
                    "column": 44,
                    "event": "note",
                    "message": "(8) returning to ‘parse_landlock_rule’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv-landlock.c",
                    "line": 139,
                    "column": 20,
                    "event": "note",
                    "message": "(9) calling ‘ul_startswith’ from ‘parse_landlock_rule’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv-landlock.c",
                    "line": 18,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 273,
                    "column": 27,
                    "event": "note",
                    "message": "(10) entry to ‘ul_startswith’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 45,
                    "event": "note",
                    "message": "(11) following ‘true’ branch (when ‘prefix’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 30,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 277,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv-landlock.c",
                    "line": 139,
                    "column": 20,
                    "event": "note",
                    "message": "(15) returning to ‘parse_landlock_rule’ from ‘ul_startswith’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "note",
                    "message": "(16) ‘xmalloc(32)’ leaks here; was allocated at (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   30|   \tvoid *ret = malloc(size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   31|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   32|-> \tif (!ret && size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   33|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   34|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "aced14d2021c35d4023540e0643e1d9ab36e2dea",
            "key_event_idx": 3,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.h",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 39,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 224)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 1247,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 1292,
                    "column": 15,
                    "event": "note",
                    "message": "(2) inlined call to ‘lscpu_new_context’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 246,
                    "column": 16,
                    "event": "note",
                    "message": "(3) calling ‘xcalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(4) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(5) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 1292,
                    "column": 15,
                    "event": "note",
                    "message": "(9) inlined call to ‘lscpu_new_context’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 246,
                    "column": 16,
                    "event": "note",
                    "message": "(10) returning to ‘main’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 1375,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch (when ‘collist == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 1378,
                    "column": 13,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 1387,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following ‘false’ branch (when ‘cpu_modifier_specified == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/lscpu.c",
                    "line": 1395,
                    "column": 18,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(15) ‘xcalloc(1, 224)’ leaks here; was allocated at (5)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "e8bac8c7f4b8267d5fad6de210b21f294a55299f",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘monthly’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1099,
                    "column": 28,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘xcalloc((long unsigned int)*ctl.months_in_row, 208) + (sizetype)i * 208’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1130,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘yearly’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1144,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘monthly’ from ‘yearly’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1076,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘monthly’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1096,
                    "column": 14,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘monthly’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 79,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(6) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(7) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1096,
                    "column": 14,
                    "event": "note",
                    "message": "(12) returning to ‘monthly’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1098,
                    "column": 23,
                    "event": "note",
                    "message": "(13) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1099,
                    "column": 36,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/cal.c",
                    "line": 1099,
                    "column": 28,
                    "event": "note",
                    "message": "(15) dereference of NULL ‘xcalloc((long unsigned int)*ctl.months_in_row, 208) + (sizetype)i * 208’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1097|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1098|   \tfor (i = 0; i < ctl->months_in_row - 1; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1099|-> \t\tms[i].next = &ms[i + 1];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1100|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1101|   \trows = (ctl->num_months - 1) / ctl->months_in_row;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "dfa06ac6293b83ee5016273a214e614587178fb9",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/unshare.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘setgroups_control.part.0’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/unshare.c",
                    "line": 117,
                    "column": 12,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(\"/proc/self/setgroups\", 1)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/unshare.c",
                    "line": 110,
                    "column": 14,
                    "event": "note",
                    "message": "(1) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/unshare.c",
                    "line": 111,
                    "column": 12,
                    "event": "note",
                    "message": "(2) assuming ‘open(\"/proc/self/setgroups\", 1)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/unshare.c",
                    "line": 111,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/unshare.c",
                    "line": 117,
                    "column": 13,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/unshare.c",
                    "line": 117,
                    "column": 12,
                    "event": "note",
                    "message": "(5) ‘open(\"/proc/self/setgroups\", 1)’ leaks here; was opened at (1)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  115|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  116|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  117|-> \tif (write_all(fd, cmd, strlen(cmd)))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  118|   \t\terr(EXIT_FAILURE, _(\"write failed %s\"), file);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  119|   \tclose(fd);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "85f02364502406213952a5d68ff47fabf084ce74",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 177,
                    "column": 1,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 493,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 558,
                    "column": 46,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(4) calling ‘err_exclusive_options’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 46,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(5) entry to ‘err_exclusive_options’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 95,
                    "column": 32,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 95,
                    "column": 32,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 98,
                    "column": 28,
                    "event": "note",
                    "message": "(8) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 99,
                    "column": 28,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(10) returning to ‘main’ from ‘err_exclusive_options’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 619,
                    "column": 28,
                    "event": "note",
                    "message": "(11) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 620,
                    "column": 33,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 620,
                    "column": 33,
                    "event": "note",
                    "message": "(13) calling ‘open_target_fd’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 157,
                    "column": 13,
                    "event": "note",
                    "message": "(14) entry to ‘open_target_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 161,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch (when ‘path’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 171,
                    "column": 13,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 171,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 174,
                    "column": 15,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 174,
                    "column": 15,
                    "event": "note",
                    "message": "(19) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 175,
                    "column": 12,
                    "event": "note",
                    "message": "(20) assuming ‘root_fd’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 175,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 177,
                    "column": 1,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 620,
                    "column": 33,
                    "event": "note",
                    "message": "(23) returning to ‘main’ from ‘open_target_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 177,
                    "column": 1,
                    "event": "note",
                    "message": "(24) leaks here; was opened at (19)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  175|   \tif (*fd < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  176|   \t\terr(EXIT_FAILURE, _(\"cannot open %s\"), path);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  177|-> }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  178|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  179|   static void enable_nsfile(struct namespace_file *n, const char *path)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "3a68d4c362df74a2ee81b1cff759752a6cf36d66",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘open_target_fd’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 177,
                    "column": 1,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘*((struct namespace_file (*)[9])n)[preserve_cred].fd’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 493,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 558,
                    "column": 46,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(4) calling ‘err_exclusive_options’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(5) entry to ‘err_exclusive_options’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 95,
                    "column": 32,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 95,
                    "column": 32,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(8) returning to ‘main’ from ‘err_exclusive_options’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 562,
                    "column": 17,
                    "event": "note",
                    "message": "(9) following ‘case 67:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 589,
                    "column": 17,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 590,
                    "column": 25,
                    "event": "note",
                    "message": "(11) calling ‘enable_namespace’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 195,
                    "column": 13,
                    "event": "note",
                    "message": "(12) entry to ‘enable_namespace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 154,
                    "column": 41,
                    "event": "note",
                    "message": "(13) calling ‘__next_nsfile’ from ‘enable_namespace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 197,
                    "column": 41,
                    "event": "note",
                    "message": "in expansion of macro ‘get_nsfile’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 133,
                    "column": 38,
                    "event": "note",
                    "message": "(14) entry to ‘__next_nsfile’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 135,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘true’ branch (when ‘n’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 140,
                    "column": 19,
                    "event": "note",
                    "message": "(17) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 141,
                    "column": 20,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 141,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 141,
                    "column": 32,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 140,
                    "column": 19,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 141,
                    "column": 20,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 141,
                    "column": 20,
                    "event": "note",
                    "message": "(23) following ‘true’ branch (when ‘namespaces != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 141,
                    "column": 47,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 143,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following ‘false’ branch (when ‘enabled == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 154,
                    "column": 41,
                    "event": "note",
                    "message": "(27) returning to ‘enable_namespace’ from ‘__next_nsfile’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 197,
                    "column": 41,
                    "event": "note",
                    "message": "in expansion of macro ‘get_nsfile’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 199,
                    "column": 12,
                    "event": "note",
                    "message": "(28) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 200,
                    "column": 20,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 200,
                    "column": 20,
                    "event": "note",
                    "message": "(30) following ‘true’ branch (when ‘path’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 200,
                    "column": 29,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 202,
                    "column": 17,
                    "event": "note",
                    "message": "(32) calling ‘enable_nsfile’ from ‘enable_namespace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 179,
                    "column": 13,
                    "event": "note",
                    "message": "(33) entry to ‘enable_nsfile’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 181,
                    "column": 12,
                    "event": "note",
                    "message": "(34) following ‘true’ branch (when ‘path’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 182,
                    "column": 17,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 182,
                    "column": 17,
                    "event": "note",
                    "message": "(36) calling ‘open_target_fd’ from ‘enable_nsfile’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 157,
                    "column": 13,
                    "event": "note",
                    "message": "(37) entry to ‘open_target_fd’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 161,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch (when ‘path’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 171,
                    "column": 13,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 174,
                    "column": 15,
                    "event": "note",
                    "message": "(40) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 175,
                    "column": 12,
                    "event": "note",
                    "message": "(41) assuming ‘*((struct namespace_file (*)[9])n)[preserve_cred].fd’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 175,
                    "column": 12,
                    "event": "note",
                    "message": "(42) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/nsenter.c",
                    "line": 177,
                    "column": 1,
                    "event": "note",
                    "message": "(43) ...to here (44) ‘*((struct namespace_file (*)[9])n)[preserve_cred].fd’ leaks here; was opened at (40)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  175|   \tif (*fd < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  176|   \t\terr(EXIT_FAILURE, _(\"cannot open %s\"), path);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  177|-> }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  178|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  179|   static void enable_nsfile(struct namespace_file *n, const char *path)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ee1f668054cfc7aa106a59c9bbcb7ceeefa46afe",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘isdigit_strend’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 33,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘p’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 230,
                    "column": 31,
                    "event": "note",
                    "message": "(1) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 230,
                    "column": 64,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 232,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch (when ‘end’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 29,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 29,
                    "event": "note",
                    "message": "(5) following ‘true’ branch (when ‘p > str’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 33,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 33,
                    "event": "note",
                    "message": "(7) dereference of NULL ‘p’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  232|   \tif (end)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  233|   \t\t*end = p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  234|-> \treturn p && p > str && !*p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  235|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  236|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ee1f668054cfc7aa106a59c9bbcb7ceeefa46afe",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘isxdigit_strend’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 33,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘p’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 241,
                    "column": 31,
                    "event": "note",
                    "message": "(1) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 241,
                    "column": 65,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 243,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘false’ branch (when ‘end’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 29,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 29,
                    "event": "note",
                    "message": "(5) following ‘true’ branch (when ‘p > str’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 33,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 33,
                    "event": "note",
                    "message": "(7) dereference of NULL ‘p’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  244|   \t\t*end = p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  245|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  246|-> \treturn p && p > str && !*p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  247|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  248|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "df85fa7811734e85c384dbb054f0e062677b97a5",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 35,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘do_seccomp_filter’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 97,
                    "column": 23,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(file, 0)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 800,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1042,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘dumplevel == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1050,
                    "column": 12,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1050,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘list_caps == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1058,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1058,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1061,
                    "column": 18,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1077,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1087,
                    "column": 17,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1087,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1090,
                    "column": 17,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1090,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1092,
                    "column": 17,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1092,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1094,
                    "column": 17,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1094,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1095,
                    "column": 17,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1095,
                    "column": 17,
                    "event": "note",
                    "message": "(18) calling ‘do_seccomp_filter’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 681,
                    "column": 13,
                    "event": "note",
                    "message": "(19) entry to ‘do_seccomp_filter’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 688,
                    "column": 14,
                    "event": "note",
                    "message": "(20) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 689,
                    "column": 12,
                    "event": "note",
                    "message": "(21) assuming ‘open(file, 0)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 689,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 693,
                    "column": 13,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 693,
                    "column": 13,
                    "event": "note",
                    "message": "(24) calling ‘read_all_alloc’ from ‘do_seccomp_filter’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 87,
                    "column": 23,
                    "event": "note",
                    "message": "(25) entry to ‘read_all_alloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 93,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 97,
                    "column": 23,
                    "event": "note",
                    "message": "(28) calling ‘read_all’ from ‘read_all_alloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 61,
                    "column": 23,
                    "event": "note",
                    "message": "(29) entry to ‘read_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 68,
                    "column": 22,
                    "event": "note",
                    "message": "(30) following ‘true’ branch (when ‘count != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 69,
                    "column": 23,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 97,
                    "column": 23,
                    "event": "note",
                    "message": "(32) returning to ‘read_all_alloc’ from ‘read_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 98,
                    "column": 20,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 104,
                    "column": 20,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 104,
                    "column": 20,
                    "event": "note",
                    "message": "(35) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 105,
                    "column": 32,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 693,
                    "column": 13,
                    "event": "note",
                    "message": "(37) returning to ‘do_seccomp_filter’ from ‘read_all_alloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 694,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 698,
                    "column": 12,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 698,
                    "column": 12,
                    "event": "note",
                    "message": "(40) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 701,
                    "column": 22,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 707,
                    "column": 12,
                    "event": "note",
                    "message": "(42) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 21,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 707,
                    "column": 44,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 97,
                    "column": 23,
                    "event": "note",
                    "message": "(44) ‘open(file, 0)’ leaks here; was opened at (20)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   95|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   96|   \twhile (1) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   97|-> \t\tret = read_all(fd, *buf + c, size - c);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   98|   \t\tif (ret < 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   99|   \t\t\tfree(*buf);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "2736b0310ef87796bd7167e764a7efd2f7103e32",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘do_selinux_label’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 653,
                    "column": 12,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(\"/proc/self/attr/exec\", 2)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 800,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1042,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘dumplevel == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1050,
                    "column": 12,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1050,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘list_caps == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1058,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1058,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1061,
                    "column": 18,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1077,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1087,
                    "column": 17,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1087,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1090,
                    "column": 17,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1090,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1091,
                    "column": 17,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1091,
                    "column": 17,
                    "event": "note",
                    "message": "(14) calling ‘do_selinux_label’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 638,
                    "column": 13,
                    "event": "note",
                    "message": "(15) entry to ‘do_selinux_label’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 643,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 646,
                    "column": 14,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 646,
                    "column": 14,
                    "event": "note",
                    "message": "(18) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 647,
                    "column": 12,
                    "event": "note",
                    "message": "(19) assuming ‘open(\"/proc/self/attr/exec\", 2)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 647,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 651,
                    "column": 15,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 653,
                    "column": 12,
                    "event": "note",
                    "message": "(22) ‘open(\"/proc/self/attr/exec\", 2)’ leaks here; was opened at (18)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  651|   \tlen = strlen(label);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  652|   \terrno = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  653|-> \tif (write(fd, label, len) != (ssize_t) len)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  654|   \t\terr(SETPRIV_EXIT_PRIVERR,",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  655|   \t\t    _(\"write failed: %s\"), _PATH_PROC_ATTR_EXEC);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "8cfd1a8c7d754c673a6b321edc6a35af048a5064",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘do_seccomp_filter’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 694,
                    "column": 12,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(file, 0)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 800,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1042,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘dumplevel == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1050,
                    "column": 12,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1050,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘list_caps == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1058,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1058,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1061,
                    "column": 18,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1077,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1087,
                    "column": 17,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1087,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1090,
                    "column": 17,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1090,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1092,
                    "column": 17,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1092,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1094,
                    "column": 17,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1094,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1095,
                    "column": 17,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 1095,
                    "column": 17,
                    "event": "note",
                    "message": "(18) calling ‘do_seccomp_filter’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 681,
                    "column": 13,
                    "event": "note",
                    "message": "(19) entry to ‘do_seccomp_filter’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 688,
                    "column": 14,
                    "event": "note",
                    "message": "(20) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 689,
                    "column": 12,
                    "event": "note",
                    "message": "(21) assuming ‘open(file, 0)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 689,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 693,
                    "column": 13,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 693,
                    "column": 13,
                    "event": "note",
                    "message": "(24) calling ‘read_all_alloc’ from ‘do_seccomp_filter’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 87,
                    "column": 23,
                    "event": "note",
                    "message": "(25) entry to ‘read_all_alloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 93,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 693,
                    "column": 13,
                    "event": "note",
                    "message": "(28) returning to ‘do_seccomp_filter’ from ‘read_all_alloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/setpriv.c",
                    "line": 694,
                    "column": 12,
                    "event": "note",
                    "message": "(29) ‘open(file, 0)’ leaks here; was opened at (20)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  692|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  693|   \ts = read_all_alloc(fd, &filter);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  694|-> \tif (s < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  695|   \t\terr(SETPRIV_EXIT_PRIVERR,",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  696|   \t\t    _(\"cannot read %s\"), file);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "27afd3ba0aa14f871a191dd104b8ad90567e2b31",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘compare’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 337,
                    "column": 30,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘p’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 170,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to ‘look’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 176,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 177,
                    "column": 37,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 186,
                    "column": 21,
                    "event": "note",
                    "message": "(4) calling ‘xmalloc’ from ‘look’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 61,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(6) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 186,
                    "column": 21,
                    "event": "note",
                    "message": "(9) returning to ‘look’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 188,
                    "column": 17,
                    "event": "note",
                    "message": "(10) calling ‘binary_search’ from ‘look’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 238,
                    "column": 1,
                    "event": "note",
                    "message": "(11) entry to ‘binary_search’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 249,
                    "column": 25,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 250,
                    "column": 21,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 250,
                    "column": 21,
                    "event": "note",
                    "message": "(14) calling ‘compare’ from ‘binary_search’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 327,
                    "column": 1,
                    "event": "note",
                    "message": "(15) entry to ‘compare’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 334,
                    "column": 41,
                    "event": "note",
                    "message": "(16) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 335,
                    "column": 21,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 335,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 57,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 335,
                    "column": 31,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 337,
                    "column": 30,
                    "event": "note",
                    "message": "(20) ‘p’ could be NULL: unchecked value from (6)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  335|   \t\tif (!dflag || isalnum(*s2) || isblank(*s2))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  336|   \t\t{",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  337|-> \t\t\t*p++ = *s2;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  338|   \t\t\ti--;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  339|   \t\t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "9afdd4e8ab896d7ff77c7eacc2ad2e6029fa35ae",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 342,
                    "column": 12,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘p’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 170,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to ‘look’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 176,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 177,
                    "column": 37,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 186,
                    "column": 21,
                    "event": "note",
                    "message": "(4) calling ‘xmalloc’ from ‘look’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(6) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 186,
                    "column": 21,
                    "event": "note",
                    "message": "(9) returning to ‘look’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 188,
                    "column": 17,
                    "event": "note",
                    "message": "(10) calling ‘binary_search’ from ‘look’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 238,
                    "column": 1,
                    "event": "note",
                    "message": "(11) entry to ‘binary_search’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 249,
                    "column": 25,
                    "event": "note",
                    "message": "(12) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 250,
                    "column": 21,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 250,
                    "column": 21,
                    "event": "note",
                    "message": "(14) calling ‘compare’ from ‘binary_search’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 327,
                    "column": 1,
                    "event": "note",
                    "message": "(15) entry to ‘compare’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/look.c",
                    "line": 342,
                    "column": 12,
                    "event": "note",
                    "message": "(16) ‘p’ could be NULL: unchecked value from (6)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  340|   \t\ts2++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  341|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  342|-> \t*p = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  343|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  344|   \t/* and compare */",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b18bf29fe169eb728947e25febe9804d407a72c6",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘randomness_from_files’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 118,
                    "column": 35,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘fd’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 139,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 189,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘randomness_from_files’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 109,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘randomness_from_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 113,
                    "column": 23,
                    "event": "note",
                    "message": "(4) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 114,
                    "column": 40,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 121,
                    "column": 30,
                    "event": "note",
                    "message": "(6) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 123,
                    "column": 20,
                    "event": "note",
                    "message": "(7) assuming ‘open(fname, 0)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 123,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 126,
                    "column": 33,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 126,
                    "column": 33,
                    "event": "note",
                    "message": "(10) calling ‘hash_file’ from ‘randomness_from_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 58,
                    "column": 17,
                    "event": "note",
                    "message": "(11) entry to ‘hash_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 65,
                    "column": 31,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when ‘wanted <= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 79,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 126,
                    "column": 33,
                    "event": "note",
                    "message": "(14) returning to ‘randomness_from_files’ from ‘hash_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 127,
                    "column": 28,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 133,
                    "column": 28,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 133,
                    "column": 28,
                    "event": "note",
                    "message": "(17) following ‘false’ branch (when ‘fd == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 113,
                    "column": 39,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 113,
                    "column": 23,
                    "event": "note",
                    "message": "(19) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 114,
                    "column": 40,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 118,
                    "column": 20,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 126,
                    "column": 33,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 118,
                    "column": 35,
                    "event": "note",
                    "message": "(23) ‘fd’ leaks here; was opened at (6)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  116|   \t\tint fd;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  117|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  118|-> \t\tif (*fname == '-' && !*(fname + 1))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  119|   \t\t\tfd = STDIN_FILENO;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  120|   \t\telse",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "68ca3d57b8fa15547bca09a2808e7a21bc0561f8",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 137,
                    "column": 1,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘fd’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 139,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 189,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘randomness_from_files’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 109,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to ‘randomness_from_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 113,
                    "column": 23,
                    "event": "note",
                    "message": "(4) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 114,
                    "column": 40,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 121,
                    "column": 30,
                    "event": "note",
                    "message": "(6) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 123,
                    "column": 20,
                    "event": "note",
                    "message": "(7) assuming ‘open(fname, 0)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 123,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 126,
                    "column": 33,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 126,
                    "column": 33,
                    "event": "note",
                    "message": "(10) calling ‘hash_file’ from ‘randomness_from_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 58,
                    "column": 17,
                    "event": "note",
                    "message": "(11) entry to ‘hash_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 65,
                    "column": 31,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when ‘wanted <= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 79,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 126,
                    "column": 33,
                    "event": "note",
                    "message": "(14) returning to ‘randomness_from_files’ from ‘hash_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 127,
                    "column": 28,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 133,
                    "column": 28,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 133,
                    "column": 28,
                    "event": "note",
                    "message": "(17) following ‘false’ branch (when ‘fd == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 113,
                    "column": 39,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 113,
                    "column": 23,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 137,
                    "column": 1,
                    "event": "note",
                    "message": "(20) ...to here (21) ‘fd’ leaks here; was opened at (6)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  135|   \t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  136|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  137|-> }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  138|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  139|   int main(int argc, char **argv)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ee3e21f99378c9b4a536dacfb43e3259e2404f46",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 169,
                    "column": 49,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘ctl.files’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 139,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 161,
                    "column": 73,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 162,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 162,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 102:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 166,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 167,
                    "column": 28,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 168,
                    "column": 45,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 168,
                    "column": 45,
                    "event": "note",
                    "message": "(8) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 31,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(9) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(10) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 168,
                    "column": 45,
                    "event": "note",
                    "message": "(13) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/mcookie.c",
                    "line": 169,
                    "column": 49,
                    "event": "note",
                    "message": "(14) ‘ctl.files + ctl.nfiles * 8’ could be NULL: unchecked value from (10)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  167|   \t\t\tif (!ctl.files)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  168|   \t\t\t\tctl.files = xmalloc(sizeof(char *) * argc);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  169|-> \t\t\tctl.files[ctl.nfiles++] = optarg;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  170|   \t\t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  171|   \t\tcase 'm':",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b4556338688a3db2dd72694c5743f17cc41830d7",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 32)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_structured_data_id’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1126,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1192,
                    "column": 62,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘ch != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1193,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1193,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 136:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1279,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1280,
                    "column": 30,
                    "event": "note",
                    "message": "(6) calling ‘valid_structured_data_id’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 740,
                    "column": 12,
                    "event": "note",
                    "message": "(7) entry to ‘valid_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/errno.h",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 39,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 742,
                    "column": 26,
                    "event": "note",
                    "message": "(8) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 746,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘at’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 746,
                    "column": 21,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1280,
                    "column": 30,
                    "event": "note",
                    "message": "(11) returning to ‘main’ from ‘valid_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1280,
                    "column": 28,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1282,
                    "column": 25,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 1282,
                    "column": 25,
                    "event": "note",
                    "message": "(14) calling ‘add_structured_data_id’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 598,
                    "column": 13,
                    "event": "note",
                    "message": "(15) entry to ‘add_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/all-io.h",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 58,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 602,
                    "column": 9,
                    "event": "note",
                    "message": "(16) following ‘true’ branch (when ‘id’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 604,
                    "column": 13,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 604,
                    "column": 13,
                    "event": "note",
                    "message": "(18) calling ‘has_structured_data_id’ from ‘add_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 582,
                    "column": 12,
                    "event": "note",
                    "message": "(19) entry to ‘has_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 586,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch (when ‘ls’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 586,
                    "column": 20,
                    "event": "note",
                    "message": "(21) inlined call to ‘list_empty’ from ‘has_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 126,
                    "column": 20,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_structured_data_id’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 586,
                    "column": 17,
                    "event": "note",
                    "message": "(23) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 604,
                    "column": 13,
                    "event": "note",
                    "message": "(25) returning to ‘add_structured_data_id’ from ‘has_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 604,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 607,
                    "column": 14,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 607,
                    "column": 14,
                    "event": "note",
                    "message": "(28) calling ‘xcalloc’ from ‘add_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 65,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(29) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(30) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(31) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(32) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 607,
                    "column": 14,
                    "event": "note",
                    "message": "(34) returning to ‘add_structured_data_id’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 609,
                    "column": 18,
                    "event": "note",
                    "message": "(35) calling ‘xstrdup’ from ‘add_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(36) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(37) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 609,
                    "column": 18,
                    "event": "note",
                    "message": "(41) returning to ‘add_structured_data_id’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/logger.c",
                    "line": 611,
                    "column": 9,
                    "event": "note",
                    "message": "(42) inlined call to ‘list_add_tail’ from ‘add_structured_data_id’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(43) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(44) ‘xcalloc(1, 32)’ leaks here; was allocated at (30)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "118fdd6a11eafb9c7a5ce4ece2b5e6a52926a00b",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 22,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘unhex’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc((*valuelen >> 1) + 1)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 52,
                    "column": 14,
                    "event": "note",
                    "message": "(1) entry to ‘unhex’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 57,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 63,
                    "column": 36,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 63,
                    "column": 18,
                    "event": "note",
                    "message": "(4) calling ‘xmalloc’ from ‘unhex’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(6) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 63,
                    "column": 18,
                    "event": "note",
                    "message": "(9) returning to ‘unhex’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 65,
                    "column": 27,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 66,
                    "column": 26,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 67,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/uuidgen.c",
                    "line": 69,
                    "column": 36,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "note",
                    "message": "(14) ‘xmalloc((*valuelen >> 1) + 1)’ leaks here; was allocated at (6)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   30|   \tvoid *ret = malloc(size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   31|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   32|-> \tif (!ret && size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   33|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   34|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "19c129c4e634f784e29f09c8f6b631fc8cb1ff53",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 467,
                    "event": "error[memleak]",
                    "message": "Memory leak: ctl.name",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  465|   \t\t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  466|   \t\tcase 'T':",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  467|-> \t\t\treturn TEST_EXIT_CODE;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  468|   \t\tcase 'u':",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  469|   \t\t\tctl.quote = 0;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "1717ff2dae328a84d1b8f029a2d0b229292b28f0",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘dotdot_stat’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 145,
                    "column": 13,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘xmalloc(len + 4)’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 399,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 448,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 453,
                    "column": 18,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 454,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 456,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 457,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 460,
                    "column": 22,
                    "event": "note",
                    "message": "(8) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 461,
                    "column": 34,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 468,
                    "column": 22,
                    "event": "note",
                    "message": "(10) calling ‘add_namei’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 199,
                    "column": 1,
                    "event": "note",
                    "message": "(11) entry to ‘add_namei’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 205,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when ‘orgpath’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 207,
                    "column": 12,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 207,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch (when ‘parent’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 211,
                    "column": 16,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 211,
                    "column": 16,
                    "event": "note",
                    "message": "(16) calling ‘xstrdup’ from ‘add_namei’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 39,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(17) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 38,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(18) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 211,
                    "column": 16,
                    "event": "note",
                    "message": "(22) returning to ‘add_namei’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 215,
                    "column": 12,
                    "event": "note",
                    "message": "(23) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 221,
                    "column": 33,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘fname’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 223,
                    "column": 21,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 223,
                    "column": 20,
                    "event": "note",
                    "message": "(27) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/bits/libc-header-start.h",
                    "line": 33,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 22,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 224,
                    "column": 31,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 224,
                    "column": 31,
                    "event": "note",
                    "message": "(29) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 225,
                    "column": 28,
                    "event": "note",
                    "message": "(30) following ‘false’ branch (when ‘end’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 229,
                    "column": 30,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 229,
                    "column": 30,
                    "event": "note",
                    "message": "(32) calling ‘new_namei’ from ‘add_namei’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 152,
                    "column": 1,
                    "event": "note",
                    "message": "(33) entry to ‘new_namei’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 156,
                    "column": 12,
                    "event": "note",
                    "message": "(34) following ‘false’ branch (when ‘fname’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 158,
                    "column": 14,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 158,
                    "column": 14,
                    "event": "note",
                    "message": "(36) calling ‘xcalloc’ from ‘new_namei’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(37) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 158,
                    "column": 14,
                    "event": "note",
                    "message": "(40) returning to ‘new_namei’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 159,
                    "column": 12,
                    "event": "note",
                    "message": "(41) following ‘false’ branch (when ‘parent’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 162,
                    "column": 19,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 163,
                    "column": 20,
                    "event": "note",
                    "message": "(43) calling ‘xstrdup’ from ‘new_namei’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(44) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(45) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(47) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 163,
                    "column": 20,
                    "event": "note",
                    "message": "(49) returning to ‘new_namei’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 170,
                    "column": 12,
                    "event": "note",
                    "message": "(50) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 29,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 175,
                    "column": 27,
                    "event": "note",
                    "message": "(51) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 175,
                    "column": 12,
                    "event": "note",
                    "message": "(52) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 177,
                    "column": 19,
                    "event": "note",
                    "message": "(53) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 177,
                    "column": 12,
                    "event": "note",
                    "message": "(54) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 182,
                    "column": 20,
                    "event": "note",
                    "message": "(55) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 182,
                    "column": 12,
                    "event": "note",
                    "message": "(56) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 185,
                    "column": 20,
                    "event": "note",
                    "message": "(57) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 185,
                    "column": 20,
                    "event": "note",
                    "message": "(58) following ‘false’ branch (when ‘parent’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 188,
                    "column": 30,
                    "event": "note",
                    "message": "(59) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 188,
                    "column": 30,
                    "event": "note",
                    "message": "(60) calling ‘dotdot_stat’ from ‘new_namei’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 129,
                    "column": 1,
                    "event": "note",
                    "message": "(61) entry to ‘dotdot_stat’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 136,
                    "column": 12,
                    "event": "note",
                    "message": "(62) following ‘false’ branch (when ‘dirname’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 139,
                    "column": 15,
                    "event": "note",
                    "message": "(63) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 140,
                    "column": 16,
                    "event": "note",
                    "message": "(64) calling ‘xmalloc’ from ‘dotdot_stat’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(65) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(66) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(67) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(68) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 140,
                    "column": 16,
                    "event": "note",
                    "message": "(69) returning to ‘dotdot_stat’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/namei.c",
                    "line": 145,
                    "column": 13,
                    "event": "note",
                    "message": "(70) argument 1 (‘xmalloc(len + 4)’) from (66) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/sys/stat.h",
                    "line": 227,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘stat’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  143|   \tmemcpy(path + len, DOTDOTDIR, sizeof(DOTDOTDIR));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  144|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  145|-> \tif (stat(path, st))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  146|   \t\terr(EXIT_FAILURE, _(\"stat of %s failed\"), path);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  147|   \tfree(path);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "22bd7240088bd0033f2a1acbaca46c3a1bf74c56",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘string_replace’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 91,
                    "column": 30,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘q’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(2) calling ‘find_initial_replace’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 54,
                    "column": 14,
                    "event": "note",
                    "message": "(3) entry to ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/bits/libc-header-start.h",
                    "line": 33,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 16,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(4) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 65,
                    "column": 16,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 65,
                    "column": 16,
                    "event": "note",
                    "message": "(7) when ‘strstr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(8) returning to ‘string_replace’ from ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 74,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(11) calling ‘xmalloc’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 37,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(12) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(13) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(16) returning to ‘string_replace’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(17) following ‘true’ branch (when ‘count != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 90,
                    "column": 26,
                    "event": "note",
                    "message": "(19) following ‘true’ branch (when ‘p < where’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 91,
                    "column": 34,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 91,
                    "column": 30,
                    "event": "note",
                    "message": "(21) ‘q’ could be NULL: unchecked value from (13)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   89|   \twhile (count--) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   90|   \t\twhile (p < where)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   91|-> \t\t\t*q++ = *p++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   92|   \t\tp = to;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   93|   \t\twhile (*p)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "22bd7240088bd0033f2a1acbaca46c3a1bf74c56",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 94,
                    "column": 30,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘q’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(2) calling ‘find_initial_replace’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 54,
                    "column": 14,
                    "event": "note",
                    "message": "(3) entry to ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(4) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 65,
                    "column": 16,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 65,
                    "column": 16,
                    "event": "note",
                    "message": "(7) when ‘strstr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(8) returning to ‘string_replace’ from ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 74,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(11) calling ‘xmalloc’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(12) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(13) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(16) returning to ‘string_replace’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(17) following ‘true’ branch (when ‘count != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 90,
                    "column": 26,
                    "event": "note",
                    "message": "(19) following ‘false’ branch (when ‘p >= where’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 93,
                    "column": 24,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 94,
                    "column": 34,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 94,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ‘q’ could be NULL: unchecked value from (13)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   92|   \t\tp = to;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   93|   \t\twhile (*p)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   94|-> \t\t\t*q++ = *p++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   95|   \t\tif (fromlen > 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   96|   \t\t\tp = where + fromlen;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "22bd7240088bd0033f2a1acbaca46c3a1bf74c56",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 104,
                    "column": 22,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘q’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 142,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 159,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 34,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 163,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 163,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 28,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 18,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 18,
                    "event": "note",
                    "message": "(10) returning to ‘do_symlink’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 170,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch (when ‘ssz >= 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 175,
                    "column": 15,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 177,
                    "column": 13,
                    "event": "note",
                    "message": "(13) calling ‘string_replace’ from ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(14) entry to ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(15) calling ‘find_initial_replace’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 54,
                    "column": 14,
                    "event": "note",
                    "message": "(16) entry to ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(17) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 42,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 42,
                    "event": "note",
                    "message": "(20) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 39,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 62,
                    "column": 32,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 65,
                    "column": 16,
                    "event": "note",
                    "message": "(23) when ‘strstr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(24) returning to ‘string_replace’ from ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 74,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 77,
                    "column": 21,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 28,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(29) calling ‘xmalloc’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(30) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(31) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(32) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(34) returning to ‘string_replace’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 90,
                    "column": 26,
                    "event": "note",
                    "message": "(35) following ‘false’ branch (when ‘p >= where’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 93,
                    "column": 24,
                    "event": "note",
                    "message": "(37) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 95,
                    "column": 20,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(39) following ‘false’ branch (when ‘count == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 103,
                    "column": 16,
                    "event": "note",
                    "message": "(41) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 104,
                    "column": 26,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 104,
                    "column": 22,
                    "event": "note",
                    "message": "(43) ‘q’ could be NULL: unchecked value from (31)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  102|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  103|   \twhile (*p)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  104|-> \t\t*q++ = *p++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  105|   \t*q = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  106|   \treturn 0;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b0a991cbb4a5048c4247fb87bef7705d3511ae69",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 105,
                    "column": 12,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘q’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 142,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 159,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 163,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 163,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 28,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 18,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 18,
                    "event": "note",
                    "message": "(10) returning to ‘do_symlink’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 170,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch (when ‘ssz >= 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 175,
                    "column": 15,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 177,
                    "column": 13,
                    "event": "note",
                    "message": "(13) calling ‘string_replace’ from ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(14) entry to ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(15) calling ‘find_initial_replace’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 54,
                    "column": 14,
                    "event": "note",
                    "message": "(16) entry to ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(17) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 42,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 42,
                    "event": "note",
                    "message": "(20) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 58,
                    "column": 39,
                    "event": "note",
                    "message": "(21) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 62,
                    "column": 32,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 65,
                    "column": 16,
                    "event": "note",
                    "message": "(23) when ‘strstr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 73,
                    "column": 21,
                    "event": "note",
                    "message": "(24) returning to ‘string_replace’ from ‘find_initial_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 74,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 77,
                    "column": 21,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 28,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(29) calling ‘xmalloc’ from ‘string_replace’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(30) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(31) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(32) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 87,
                    "column": 20,
                    "event": "note",
                    "message": "(34) returning to ‘string_replace’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 90,
                    "column": 26,
                    "event": "note",
                    "message": "(35) following ‘false’ branch (when ‘p >= where’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 93,
                    "column": 24,
                    "event": "note",
                    "message": "(37) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 95,
                    "column": 20,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(39) following ‘false’ branch (when ‘count == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 103,
                    "column": 16,
                    "event": "note",
                    "message": "(41) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 105,
                    "column": 12,
                    "event": "note",
                    "message": "(42) ...to here (43) ‘q’ could be NULL: unchecked value from (31)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  103|   \twhile (*p)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  104|   \t\t*q++ = *p++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  105|-> \t*q = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  106|   \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  107|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f777a10ad5e5d3e67be208d5c7b6ba34aa52c4c1",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘do_symlink’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 169,
                    "column": 15,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘xmalloc((long unsigned int)(sb.st_size + 1))’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 142,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 159,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 163,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 163,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 28,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 18,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘do_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(8) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 167,
                    "column": 18,
                    "event": "note",
                    "message": "(11) returning to ‘do_symlink’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 169,
                    "column": 15,
                    "event": "note",
                    "message": "(12) argument 2 (‘xmalloc((long unsigned int)(sb.st_size + 1))’) from (8) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/rename.c",
                    "line": 31,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/unistd.h",
                    "line": 838,
                    "column": 16,
                    "event": "note",
                    "message": "argument 2 of ‘readlink’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  167|   \ttarget = xmalloc(sb.st_size + 1);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  168|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  169|-> \tssz = readlink(s, target, sb.st_size + 1);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  170|   \tif (ssz < 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  171|   \t\twarn(_(\"%s: readlink failed\"), s);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "9b9d6d893bceeafce05c75e8184f0508814ea553",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘print_normalized.part.0’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 136,
                    "column": 24,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xmalloc(strlen(arg) * 4 + 3)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 116,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘print_normalized’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 133,
                    "column": 15,
                    "event": "note",
                    "message": "(2) calling ‘xmalloc’ from ‘print_normalized’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 73,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(4) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 133,
                    "column": 15,
                    "event": "note",
                    "message": "(7) returning to ‘print_normalized’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 136,
                    "column": 24,
                    "event": "note",
                    "message": "(8) ‘xmalloc(strlen(arg) * 4 + 3)’ could be NULL: unchecked value from (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  134|   \tbufptr = buf;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  135|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  136|-> \tfor (*bufptr++ = '\\''; *argptr; argptr++) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  137|   \t\tif (ctl->shell == TCSH) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  138|   \t\t\tswitch (*argptr) {",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "d75447f4eabf8ec025ed1c208c590a2f1c951405",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 436,
                    "column": 17,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘ctl.optstr’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 382,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 418,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘argc != 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 430,
                    "column": 9,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 430,
                    "column": 9,
                    "event": "note",
                    "message": "(4) calling ‘add_longopt’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 266,
                    "column": 13,
                    "event": "note",
                    "message": "(5) entry to ‘add_longopt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 277,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch (when ‘name’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 285,
                    "column": 20,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 430,
                    "column": 9,
                    "event": "note",
                    "message": "(8) returning to ‘main’ from ‘add_longopt’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 435,
                    "column": 30,
                    "event": "note",
                    "message": "(9) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(11) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 435,
                    "column": 30,
                    "event": "note",
                    "message": "(14) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/getopt.c",
                    "line": 436,
                    "column": 17,
                    "event": "note",
                    "message": "(15) argument 1 (‘xmalloc(strlen(argv[1]) + 1)’) from (11) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "<built-in>",
                    "line": 0,
                    "event": "note",
                    "message": "argument 1 of ‘__builtin_strcpy’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  434|   \t\tctl.quote = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  435|   \t\tctl.optstr = xmalloc(strlen(argv[1]) + 1);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  436|-> \t\tstrcpy(ctl.optstr, argv[1] + strspn(argv[1], \"-+\"));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  437|   \t\targv[1] = argv[0];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  438|   \t\treturn generate_output(&ctl, argv + 1, argc - 1);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "15857652debec58b8909221ea2fc39a49cddbcfe",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘is_holder’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 305,
                    "column": 17,
                    "event": "warning[-Wanalyzer-null-argument]",
                    "message": "use of NULL where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 853,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 937,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘collist == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 47,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 39,
                    "column": 21,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 940,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘INIT_LIST_HEAD’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 955,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘outarg’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 956,
                    "column": 26,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 967,
                    "column": 9,
                    "event": "note",
                    "message": "(6) calling ‘get_pids_locks’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 492,
                    "column": 13,
                    "event": "note",
                    "message": "(7) entry to ‘get_pids_locks’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 499,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 502,
                    "column": 15,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 503,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 967,
                    "column": 9,
                    "event": "note",
                    "message": "(12) returning to ‘main’ from ‘get_pids_locks’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 968,
                    "column": 14,
                    "event": "note",
                    "message": "(13) calling ‘get_proc_locks’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 530,
                    "column": 12,
                    "event": "note",
                    "message": "(14) entry to ‘get_proc_locks’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 535,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 538,
                    "column": 16,
                    "event": "note",
                    "message": "(17) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 539,
                    "column": 34,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 539,
                    "column": 34,
                    "event": "note",
                    "message": "(19) calling ‘get_lock’ from ‘get_proc_locks’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 334,
                    "column": 21,
                    "event": "note",
                    "message": "(20) entry to ‘get_lock’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 339,
                    "column": 26,
                    "event": "note",
                    "message": "(21) calling ‘xcalloc’ from ‘get_lock’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 43,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(22) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(23) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 339,
                    "column": 26,
                    "event": "note",
                    "message": "(25) returning to ‘get_lock’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 345,
                    "column": 20,
                    "event": "note",
                    "message": "(26) when ‘strtok’ on non-NULL string returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 345,
                    "column": 45,
                    "event": "note",
                    "message": "(27) following ‘false’ branch (when ‘tok’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 416,
                    "column": 16,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 416,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 416,
                    "column": 27,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 416,
                    "column": 27,
                    "event": "note",
                    "message": "(31) following ‘true’ branch (when ‘fallback’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 416,
                    "column": 44,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 416,
                    "column": 44,
                    "event": "note",
                    "message": "(33) ‘0’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 416,
                    "column": 39,
                    "event": "note",
                    "message": "(34) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 417,
                    "column": 17,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 417,
                    "column": 17,
                    "event": "note",
                    "message": "(36) calling ‘patch_lock’ from ‘get_lock’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 309,
                    "column": 13,
                    "event": "note",
                    "message": "(37) entry to ‘patch_lock’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 315,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 318,
                    "column": 28,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 21,
                    "event": "note",
                    "message": "in definition of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(40) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 318,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 320,
                    "column": 21,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 320,
                    "column": 21,
                    "event": "note",
                    "message": "(42) calling ‘is_holder’ from ‘patch_lock’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 297,
                    "column": 13,
                    "event": "note",
                    "message": "(43) entry to ‘is_holder’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 305,
                    "column": 47,
                    "event": "note",
                    "message": "(44) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 300,
                    "column": 18,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 299,
                    "column": 38,
                    "event": "note",
                    "message": "(46) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 301,
                    "column": 18,
                    "event": "note",
                    "message": "(47) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 300,
                    "column": 34,
                    "event": "note",
                    "message": "(48) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 302,
                    "column": 18,
                    "event": "note",
                    "message": "(49) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 301,
                    "column": 38,
                    "event": "note",
                    "message": "(50) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 303,
                    "column": 18,
                    "event": "note",
                    "message": "(51) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 302,
                    "column": 34,
                    "event": "note",
                    "message": "(52) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 304,
                    "column": 18,
                    "event": "note",
                    "message": "(53) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 303,
                    "column": 46,
                    "event": "note",
                    "message": "(54) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 305,
                    "column": 34,
                    "event": "note",
                    "message": "(55) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 305,
                    "column": 25,
                    "event": "note",
                    "message": "(56) ‘0’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 305,
                    "column": 17,
                    "event": "note",
                    "message": "(57) argument 1 (‘*l.type’) NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lslocks.c",
                    "line": 26,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/string.h",
                    "line": 171,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘strcmp’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  303|   \t\tl->mandatory == m->mandatory &&",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  304|   \t\tl->blocked == m->blocked &&",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  305|-> \t\tstrcmp(l->type, m->type) == 0 &&",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  306|   \t\tstrcmp(l->mode, m->mode) == 0);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  307|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "d763c7f552840f48ea7ddce34d4f5091546fb2b9",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 33,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘open_pidfds’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(n_pids, 4)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 221,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 232,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘n_pids != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 235,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(4) calling ‘parse_pids’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 48,
                    "column": 15,
                    "event": "note",
                    "message": "(5) entry to ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(10) returning to ‘parse_pids’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 52,
                    "column": 30,
                    "event": "note",
                    "message": "(11) following ‘true’ branch (when ‘i < n_strings’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/nls.h",
                    "line": 36,
                    "column": 19,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 55,
                    "column": 64,
                    "event": "note",
                    "message": "in definition of macro ‘strtopid_or_err’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 53,
                    "column": 55,
                    "event": "note",
                    "message": "in expansion of macro ‘_’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(13) returning to ‘main’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 241,
                    "column": 18,
                    "event": "note",
                    "message": "(14) calling ‘open_pidfds’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(15) entry to ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(16) calling ‘xcalloc’ from ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(17) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(18) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(19) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(22) returning to ‘open_pidfds’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 62,
                    "column": 30,
                    "event": "note",
                    "message": "(23) following ‘true’ branch (when ‘i < n_pids’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 63,
                    "column": 44,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 64,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 65,
                    "column": 29,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(27) ‘xcalloc(n_pids, 4)’ leaks here; was allocated at (18)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "e95ebc32c48aacd2459757c4b43737e2374ef5b4",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘open_pidfds(n_pids,  parse_pids(n_pids,  argv + (long unsigned int)parse_options(argc,  argv) * 8))’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 221,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 232,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘n_pids != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 235,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(4) calling ‘parse_pids’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 48,
                    "column": 15,
                    "event": "note",
                    "message": "(5) entry to ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(10) returning to ‘parse_pids’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 52,
                    "column": 30,
                    "event": "note",
                    "message": "(11) following ‘false’ branch (when ‘i >= n_strings’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 55,
                    "column": 16,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(13) returning to ‘main’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 241,
                    "column": 18,
                    "event": "note",
                    "message": "(14) calling ‘open_pidfds’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(15) entry to ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(16) calling ‘xcalloc’ from ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(17) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(18) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(19) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(22) returning to ‘open_pidfds’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 62,
                    "column": 30,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘i >= n_pids’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 74,
                    "column": 16,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 241,
                    "column": 18,
                    "event": "note",
                    "message": "(25) returning to ‘main’ from ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(26) ‘open_pidfds(n_pids,  parse_pids(n_pids,  argv + (long unsigned int)parse_options(argc,  argv) * 8))’ leaks here; was allocated at (18)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "75a25ee409bfdecb266acd48e52bc114235a99c1",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘parse_pids(n_pids,  argv + (long unsigned int)parse_options(argc,  argv) * 8)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 221,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 232,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘n_pids != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 235,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(4) calling ‘parse_pids’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 48,
                    "column": 15,
                    "event": "note",
                    "message": "(5) entry to ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(8) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(9) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(12) returning to ‘parse_pids’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 52,
                    "column": 30,
                    "event": "note",
                    "message": "(13) following ‘false’ branch (when ‘i >= n_strings’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 55,
                    "column": 16,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(15) returning to ‘main’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 241,
                    "column": 18,
                    "event": "note",
                    "message": "(16) calling ‘open_pidfds’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(17) entry to ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(18) calling ‘xcalloc’ from ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(19) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(22) returning to ‘open_pidfds’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 62,
                    "column": 30,
                    "event": "note",
                    "message": "(23) following ‘false’ branch (when ‘i >= n_pids’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 74,
                    "column": 16,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 241,
                    "column": 18,
                    "event": "note",
                    "message": "(25) returning to ‘main’ from ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(26) ‘parse_pids(n_pids,  argv + (long unsigned int)parse_options(argc,  argv) * 8)’ leaks here; was allocated at (8)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0e7ad6d6110a7f4575c72aadf632f142c6190b62",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_pids’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 53,
                    "column": 25,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘xcalloc(n_strings, 4)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 221,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 232,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘n_pids != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 235,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(4) calling ‘parse_pids’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 48,
                    "column": 15,
                    "event": "note",
                    "message": "(5) entry to ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(8) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(9) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(12) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(14) returning to ‘parse_pids’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 52,
                    "column": 30,
                    "event": "note",
                    "message": "(15) following ‘true’ branch (when ‘i < n_strings’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/nls.h",
                    "line": 36,
                    "column": 19,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 55,
                    "column": 64,
                    "event": "note",
                    "message": "in definition of macro ‘strtopid_or_err’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 53,
                    "column": 55,
                    "event": "note",
                    "message": "in expansion of macro ‘_’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 53,
                    "column": 25,
                    "event": "note",
                    "message": "(17) dereference of NULL ‘xcalloc(n_strings, 4) + i * 4’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   51|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   52|   \tfor (size_t i = 0; i < n_strings; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|-> \t\tpids[i] = strtopid_or_err(strings[i], _(\"invalid PID argument\"));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|   \treturn pids;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "8051ae505030adeed3663fbd9378650463d60e05",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘open_pidfds’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 63,
                    "column": 27,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘xcalloc(n_pids, 4)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 221,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 232,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘n_pids != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 235,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(4) calling ‘parse_pids’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 48,
                    "column": 15,
                    "event": "note",
                    "message": "(5) entry to ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(6) calling ‘xcalloc’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 50,
                    "column": 23,
                    "event": "note",
                    "message": "(10) returning to ‘parse_pids’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 52,
                    "column": 30,
                    "event": "note",
                    "message": "(11) following ‘true’ branch (when ‘i < n_strings’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/nls.h",
                    "line": 36,
                    "column": 19,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 55,
                    "column": 64,
                    "event": "note",
                    "message": "in definition of macro ‘strtopid_or_err’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 53,
                    "column": 55,
                    "event": "note",
                    "message": "in expansion of macro ‘_’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 239,
                    "column": 23,
                    "event": "note",
                    "message": "(13) returning to ‘main’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 241,
                    "column": 18,
                    "event": "note",
                    "message": "(14) calling ‘open_pidfds’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 58,
                    "column": 13,
                    "event": "note",
                    "message": "(15) entry to ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(16) calling ‘xcalloc’ from ‘open_pidfds’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(17) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(18) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(19) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(22) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 60,
                    "column": 23,
                    "event": "note",
                    "message": "(24) returning to ‘open_pidfds’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 62,
                    "column": 30,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < n_pids’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 63,
                    "column": 44,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/waitpid.c",
                    "line": 63,
                    "column": 27,
                    "event": "note",
                    "message": "(27) dereference of NULL ‘xcalloc(n_pids, 4) + i * 4’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   61|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   62|   \tfor (size_t i = 0; i < n_pids; i++) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   63|-> \t\tpidfds[i] = pidfd_open(pids[i], 0);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   64|   \t\tif (pidfds[i] == -1) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   65|   \t\t\tif (allow_exited && errno == ESRCH) {",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "a85f7999ff60af43ec37aaf16df1042e12403461",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 398,
                    "column": 12,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(dev, 258)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 281,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 322,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch (when ‘argc != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 372,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 377,
                    "column": 44,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 377,
                    "column": 17,
                    "event": "note",
                    "message": "(6) calling ‘lookup_table’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 151,
                    "column": 12,
                    "event": "note",
                    "message": "(7) entry to ‘lookup_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 155,
                    "column": 25,
                    "event": "note",
                    "message": "(8) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 156,
                    "column": 22,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 377,
                    "column": 17,
                    "event": "note",
                    "message": "(10) returning to ‘main’ from ‘lookup_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 378,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 382,
                    "column": 19,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 396,
                    "column": 23,
                    "event": "note",
                    "message": "(13) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 396,
                    "column": 12,
                    "event": "note",
                    "message": "(14) assuming ‘open(dev, 258)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 396,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 398,
                    "column": 14,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 398,
                    "column": 14,
                    "event": "note",
                    "message": "(17) when ‘isatty’ fails",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/ldattach.c",
                    "line": 398,
                    "column": 12,
                    "event": "note",
                    "message": "(18) ‘open(dev, 258)’ leaks here; was opened at (13)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  396|   \tif ((tty_fd = open(dev, O_RDWR | O_NOCTTY)) < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  397|   \t\terr(EXIT_FAILURE, _(\"cannot open %s\"), dev);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  398|-> \tif (!isatty(tty_fd))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  399|   \t\terrx(EXIT_FAILURE, _(\"%s is not a serial line\"), dev);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  400|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0c7f383c44cdccd16713dab2714de81ef7f42f28",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc(24)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 545,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 598,
                    "column": 81,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 599,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 599,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 100:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 619,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 620,
                    "column": 38,
                    "event": "note",
                    "message": "(6) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 38,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(8) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(9) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 620,
                    "column": 38,
                    "event": "note",
                    "message": "(12) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsclocks.c",
                    "line": 622,
                    "column": 25,
                    "event": "note",
                    "message": "(13) inlined call to ‘list_add’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 68,
                    "column": 9,
                    "event": "note",
                    "message": "(14) inlined call to ‘__list_add’ from ‘list_add’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(15) ‘xmalloc(24)’ leaks here; was allocated at (8)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "5bbe943270e028dfcb3c6cfb6d76bb95cd39e890",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘get_sorted_xattr_name_table’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 528,
                    "column": 26,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘xcalloc((long unsigned int)n, 8)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘visitor’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1082,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1085,
                    "column": 23,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘master’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1089,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1090,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1094,
                    "column": 26,
                    "event": "note",
                    "message": "(8) inlined call to ‘count_nodes’ from ‘visitor’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1058,
                    "column": 19,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘x’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1059,
                    "column": 19,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘get_sorted_xattr_name_table’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1095,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘false’ branch (when ‘ct != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1099,
                    "column": 30,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1111,
                    "column": 50,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘other’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1114,
                    "column": 25,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/optutils.h",
                    "line": 8,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 58,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1116,
                    "column": 25,
                    "event": "note",
                    "message": "(15) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1117,
                    "column": 41,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1117,
                    "column": 25,
                    "event": "note",
                    "message": "(17) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1119,
                    "column": 35,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1119,
                    "column": 28,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1123,
                    "column": 30,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1123,
                    "column": 30,
                    "event": "note",
                    "message": "(21) calling ‘file_may_link_to’ from ‘visitor’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 652,
                    "column": 19,
                    "event": "note",
                    "message": "(22) entry to ‘file_may_link_to’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 663,
                    "column": 66,
                    "event": "note",
                    "message": "(23) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 18,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 654,
                    "column": 48,
                    "event": "note",
                    "message": "(25) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 38,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 34,
                    "event": "note",
                    "message": "(27) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 656,
                    "column": 22,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 54,
                    "event": "note",
                    "message": "(29) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 657,
                    "column": 22,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 656,
                    "column": 46,
                    "event": "note",
                    "message": "(31) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 658,
                    "column": 23,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 657,
                    "column": 46,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 659,
                    "column": 23,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 658,
                    "column": 72,
                    "event": "note",
                    "message": "(35) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 659,
                    "column": 71,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 659,
                    "column": 71,
                    "event": "note",
                    "message": "(37) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 661,
                    "column": 23,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 660,
                    "column": 71,
                    "event": "note",
                    "message": "(39) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 662,
                    "column": 23,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 661,
                    "column": 74,
                    "event": "note",
                    "message": "(41) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 663,
                    "column": 23,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 662,
                    "column": 68,
                    "event": "note",
                    "message": "(43) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 664,
                    "column": 23,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 663,
                    "column": 66,
                    "event": "note",
                    "message": "(45) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 664,
                    "column": 42,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 664,
                    "column": 42,
                    "event": "note",
                    "message": "(47) calling ‘file_xattrs_equal’ from ‘file_may_link_to’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 544,
                    "column": 12,
                    "event": "note",
                    "message": "(48) entry to ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 559,
                    "column": 9,
                    "event": "note",
                    "message": "(49) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 560,
                    "column": 9,
                    "event": "note",
                    "message": "(51) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 242,
                    "column": 37,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 251,
                    "column": 21,
                    "event": "note",
                    "message": "in expansion of macro ‘is_log_enabled’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 562,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘jlog’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 570,
                    "column": 12,
                    "event": "note",
                    "message": "(53) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 573,
                    "column": 12,
                    "event": "note",
                    "message": "(54) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 573,
                    "column": 12,
                    "event": "note",
                    "message": "(55) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 576,
                    "column": 19,
                    "event": "note",
                    "message": "(56) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 576,
                    "column": 19,
                    "event": "note",
                    "message": "(57) calling ‘xmalloc’ from ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 55,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(58) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(59) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(60) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 576,
                    "column": 19,
                    "event": "note",
                    "message": "(61) returning to ‘file_xattrs_equal’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 577,
                    "column": 19,
                    "event": "note",
                    "message": "(62) calling ‘xmalloc’ from ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(63) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(64) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 577,
                    "column": 19,
                    "event": "note",
                    "message": "(66) returning to ‘file_xattrs_equal’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 581,
                    "column": 9,
                    "event": "note",
                    "message": "(67) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 583,
                    "column": 15,
                    "event": "note",
                    "message": "(68) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 586,
                    "column": 12,
                    "event": "note",
                    "message": "(69) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 589,
                    "column": 23,
                    "event": "note",
                    "message": "(70) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 589,
                    "column": 23,
                    "event": "note",
                    "message": "(71) calling ‘get_sorted_xattr_name_table’ from ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 522,
                    "column": 21,
                    "event": "note",
                    "message": "(72) entry to ‘get_sorted_xattr_name_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 524,
                    "column": 30,
                    "event": "note",
                    "message": "(73) calling ‘xcalloc’ from ‘get_sorted_xattr_name_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(74) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(75) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(76) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(77) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(78) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(79) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(80) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 524,
                    "column": 30,
                    "event": "note",
                    "message": "(81) returning to ‘get_sorted_xattr_name_table’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 527,
                    "column": 23,
                    "event": "note",
                    "message": "(82) following ‘true’ branch (when ‘i < n’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 528,
                    "column": 22,
                    "event": "note",
                    "message": "(83) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 528,
                    "column": 26,
                    "event": "note",
                    "message": "(84) dereference of NULL ‘xcalloc((long unsigned int)n, 8) + (long unsigned int)i * 8’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  526|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  527|   \tfor (i = 0; i < n; i++) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  528|-> \t\ttable[i] = names;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  529|   \t\tnames += strlen(names) + 1;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  530|   \t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0fb6f0596e603d4f65e0dda4ca8a06fc48586662",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 532,
                    "column": 9,
                    "event": "warning[-Wanalyzer-null-argument]",
                    "message": "use of NULL ‘xcalloc((long unsigned int)n, 8)’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘visitor’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1082,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1085,
                    "column": 23,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘master’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1089,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1090,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1094,
                    "column": 26,
                    "event": "note",
                    "message": "(8) inlined call to ‘count_nodes’ from ‘visitor’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1058,
                    "column": 19,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘x’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1059,
                    "column": 19,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘get_sorted_xattr_name_table’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1095,
                    "column": 20,
                    "event": "note",
                    "message": "(11) following ‘false’ branch (when ‘ct != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1099,
                    "column": 30,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1111,
                    "column": 50,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘other’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1114,
                    "column": 25,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1116,
                    "column": 25,
                    "event": "note",
                    "message": "(15) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1117,
                    "column": 41,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1117,
                    "column": 25,
                    "event": "note",
                    "message": "(17) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1119,
                    "column": 35,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1119,
                    "column": 28,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1123,
                    "column": 30,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 1123,
                    "column": 30,
                    "event": "note",
                    "message": "(21) calling ‘file_may_link_to’ from ‘visitor’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 652,
                    "column": 19,
                    "event": "note",
                    "message": "(22) entry to ‘file_may_link_to’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 663,
                    "column": 66,
                    "event": "note",
                    "message": "(23) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 18,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 654,
                    "column": 48,
                    "event": "note",
                    "message": "(25) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 38,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 34,
                    "event": "note",
                    "message": "(27) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 656,
                    "column": 22,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 655,
                    "column": 54,
                    "event": "note",
                    "message": "(29) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 657,
                    "column": 22,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 656,
                    "column": 46,
                    "event": "note",
                    "message": "(31) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 658,
                    "column": 23,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 657,
                    "column": 46,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 659,
                    "column": 23,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 658,
                    "column": 72,
                    "event": "note",
                    "message": "(35) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 659,
                    "column": 71,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 659,
                    "column": 71,
                    "event": "note",
                    "message": "(37) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 661,
                    "column": 23,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 660,
                    "column": 71,
                    "event": "note",
                    "message": "(39) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 662,
                    "column": 23,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 661,
                    "column": 74,
                    "event": "note",
                    "message": "(41) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 663,
                    "column": 23,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 662,
                    "column": 68,
                    "event": "note",
                    "message": "(43) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 664,
                    "column": 23,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 663,
                    "column": 66,
                    "event": "note",
                    "message": "(45) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 664,
                    "column": 42,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 664,
                    "column": 42,
                    "event": "note",
                    "message": "(47) calling ‘file_xattrs_equal’ from ‘file_may_link_to’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 544,
                    "column": 12,
                    "event": "note",
                    "message": "(48) entry to ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 559,
                    "column": 9,
                    "event": "note",
                    "message": "(49) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 560,
                    "column": 17,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 560,
                    "column": 9,
                    "event": "note",
                    "message": "(51) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 242,
                    "column": 37,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 251,
                    "column": 21,
                    "event": "note",
                    "message": "in expansion of macro ‘is_log_enabled’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 562,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘jlog’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 570,
                    "column": 12,
                    "event": "note",
                    "message": "(53) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 573,
                    "column": 12,
                    "event": "note",
                    "message": "(54) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 573,
                    "column": 12,
                    "event": "note",
                    "message": "(55) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 576,
                    "column": 19,
                    "event": "note",
                    "message": "(56) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 576,
                    "column": 19,
                    "event": "note",
                    "message": "(57) calling ‘xmalloc’ from ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(58) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(59) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(60) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 576,
                    "column": 19,
                    "event": "note",
                    "message": "(61) returning to ‘file_xattrs_equal’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 577,
                    "column": 19,
                    "event": "note",
                    "message": "(62) calling ‘xmalloc’ from ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(63) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(64) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 577,
                    "column": 19,
                    "event": "note",
                    "message": "(66) returning to ‘file_xattrs_equal’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 581,
                    "column": 9,
                    "event": "note",
                    "message": "(67) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 583,
                    "column": 15,
                    "event": "note",
                    "message": "(68) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 586,
                    "column": 12,
                    "event": "note",
                    "message": "(69) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 589,
                    "column": 23,
                    "event": "note",
                    "message": "(70) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 589,
                    "column": 23,
                    "event": "note",
                    "message": "(71) calling ‘get_sorted_xattr_name_table’ from ‘file_xattrs_equal’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 522,
                    "column": 21,
                    "event": "note",
                    "message": "(72) entry to ‘get_sorted_xattr_name_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 524,
                    "column": 30,
                    "event": "note",
                    "message": "(73) calling ‘xcalloc’ from ‘get_sorted_xattr_name_table’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(74) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(75) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(76) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(77) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(78) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 26,
                    "event": "note",
                    "message": "(79) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(80) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 524,
                    "column": 30,
                    "event": "note",
                    "message": "(81) returning to ‘get_sorted_xattr_name_table’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 527,
                    "column": 23,
                    "event": "note",
                    "message": "(82) following ‘false’ branch (when ‘i >= n’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 532,
                    "column": 9,
                    "event": "note",
                    "message": "(83) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 532,
                    "column": 9,
                    "event": "note",
                    "message": "(84) argument 1 (‘xcalloc((long unsigned int)n, 8)’) NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 17,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/hardlink.c",
                    "line": 54,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/stdlib.h",
                    "line": 998,
                    "column": 13,
                    "event": "note",
                    "message": "argument 1 of ‘qsort’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  530|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  531|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  532|-> \tqsort(table, n, sizeof(char *), cmp_xattr_name_ptrs);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  533|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  534|   \treturn table;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "796cd6790c4929254786f5b0ebb34d3a03c21a2e",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 50,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xmalloc(len)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 120,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 211,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 236,
                    "column": 23,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 236,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 237,
                    "column": 29,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 237,
                    "column": 13,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 238,
                    "column": 17,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 238,
                    "column": 13,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 240,
                    "column": 12,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 240,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when ‘len != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 243,
                    "column": 15,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 243,
                    "column": 15,
                    "event": "note",
                    "message": "(12) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(14) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 243,
                    "column": 15,
                    "event": "note",
                    "message": "(17) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 13,
                    "event": "note",
                    "message": "(18) ‘xmalloc(len)’ leaks here; was allocated at (14)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   30|   \tvoid *ret = malloc(size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   31|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   32|-> \tif (!ret && size)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   33|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   34|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0e8fd2878d7ad9fc6e601387073b864f76ea0e09",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 229,
                    "column": 21,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor ‘open(&defaultpro, 1)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 168,
                    "column": 81,
                    "event": "note",
                    "message": "(1) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 169,
                    "column": 17,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 211,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 217,
                    "column": 20,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 217,
                    "column": 20,
                    "event": "note",
                    "message": "(5) following ‘true’ branch (when ‘has_mult != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 47,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 225,
                    "column": 32,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 67,
                    "column": 62,
                    "event": "note",
                    "message": "in definition of macro ‘ignore_result’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 226,
                    "column": 22,
                    "event": "note",
                    "message": "(7) opened here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 227,
                    "column": 20,
                    "event": "note",
                    "message": "(8) assuming ‘open(&defaultpro, 1)’ is a valid file descriptor (>= 0)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 227,
                    "column": 20,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 229,
                    "column": 21,
                    "event": "note",
                    "message": "(10) ...to here (11) ‘open(&defaultpro, 1)’ leaks here; was opened at (7)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  227|   \t\tif (fd < 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  228|   \t\t\terr(EXIT_FAILURE, \"%s\", defaultpro);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  229|-> \t\tif (write(fd, &multiplier, to_write) != to_write)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  230|   \t\t\terr(EXIT_FAILURE, _(\"error writing %s\"), defaultpro);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  231|   \t\tclose(fd);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "a365fceb613be9db5370cd4a8bc582373b431cbb",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 276,
                    "column": 14,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xmalloc(len)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 120,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 211,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 236,
                    "column": 23,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 236,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 237,
                    "column": 29,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 237,
                    "column": 13,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 238,
                    "column": 17,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 238,
                    "column": 13,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 240,
                    "column": 12,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 240,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when ‘len != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 243,
                    "column": 15,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 243,
                    "column": 15,
                    "event": "note",
                    "message": "(12) calling ‘xmalloc’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(14) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 243,
                    "column": 15,
                    "event": "note",
                    "message": "(17) returning to ‘main’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 246,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 248,
                    "column": 9,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/readprofile.c",
                    "line": 276,
                    "column": 14,
                    "event": "note",
                    "message": "(20) ‘xmalloc(len)’ could be NULL: unchecked value from (14)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  274|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  275|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  276|-> \tstep = buf[0];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  277|   \tif (optInfo) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  278|   \t\tprintf(_(\"Sampling_step: %u\\n\"), step);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "312e4bef9a997ed9d0d9aef3a01e297794429c5a",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 68,
                    "event": "error[uninitvar]",
                    "message": "Uninitialized variable: current",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tformat_begin(ctrl);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tfor (current.track = track_from; current.track <= track_to; current.track++) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\tfor (current.head = 0; current.head < param.head; current.head++) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \t\t\tprintf(\"%3u/%u\\b\\b\\b\\b\\b\", current.track, current.head);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0cc22f0530f0b6ca996fd81107c5e3336bc0cbc2",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘verify_disk’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 129,
                    "column": 49,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xmalloc(track_size) + count’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 177,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 203,
                    "column": 76,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘ch != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 204,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 229,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘argc > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 233,
                    "column": 13,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 233,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 235,
                    "column": 24,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 235,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 238,
                    "column": 16,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 239,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 241,
                    "column": 13,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 241,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 246,
                    "column": 47,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 248,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch (when ‘has_user_defined_track_to != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 251,
                    "column": 32,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 251,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 253,
                    "column": 12,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 253,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 255,
                    "column": 12,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 255,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch (when ‘track_to >= track_from’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 258,
                    "column": 9,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 258,
                    "column": 9,
                    "event": "note",
                    "message": "(22) calling ‘format_disk’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 59,
                    "column": 13,
                    "event": "note",
                    "message": "(23) entry to ‘format_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 66,
                    "column": 9,
                    "event": "note",
                    "message": "(24) calling ‘format_begin’ from ‘format_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 35,
                    "column": 13,
                    "event": "note",
                    "message": "(25) entry to ‘format_begin’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 37,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 39,
                    "column": 1,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 66,
                    "column": 9,
                    "event": "note",
                    "message": "(28) returning to ‘format_disk’ from ‘format_begin’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 68,
                    "column": 56,
                    "event": "note",
                    "message": "(29) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 69,
                    "column": 35,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 76,
                    "column": 9,
                    "event": "note",
                    "message": "(31) calling ‘format_end’ from ‘format_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 41,
                    "column": 13,
                    "event": "note",
                    "message": "(32) entry to ‘format_end’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 43,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 45,
                    "column": 1,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 76,
                    "column": 9,
                    "event": "note",
                    "message": "(35) returning to ‘format_disk’ from ‘format_end’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 258,
                    "column": 9,
                    "event": "note",
                    "message": "(36) returning to ‘main’ from ‘format_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 260,
                    "column": 12,
                    "event": "note",
                    "message": "(37) following ‘true’ branch (when ‘verify != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 261,
                    "column": 17,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 261,
                    "column": 17,
                    "event": "note",
                    "message": "(39) calling ‘verify_disk’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 81,
                    "column": 13,
                    "event": "note",
                    "message": "(40) entry to ‘verify_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(41) calling ‘xmalloc’ from ‘verify_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(42) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(43) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(46) returning to ‘verify_disk’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 97,
                    "column": 56,
                    "event": "note",
                    "message": "(47) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 98,
                    "column": 35,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 98,
                    "column": 53,
                    "event": "note",
                    "message": "(49) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 100,
                    "column": 25,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 109,
                    "column": 36,
                    "event": "note",
                    "message": "(51) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 128,
                    "column": 55,
                    "event": "note",
                    "message": "(53) following ‘true’ branch (when ‘count < track_size’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 129,
                    "column": 49,
                    "event": "note",
                    "message": "(54) ...to here (55) ‘xmalloc(track_size) + count’ could be NULL: unchecked value from (43)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  127|   \t\t\t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  128|   \t\t\t\tfor (count = 0; count < track_size; count++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  129|-> \t\t\t\t\tif (data[count] != FD_FILL_BYTE) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  130|   \t\t\t\t\t\tif (retries_left) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  131|   \t\t\t\t\t\t\tformat_begin(ctrl);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f209be1974da214d499971a46bf97db2f08fbec7",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 129,
                    "column": 49,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xmalloc(track_size)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 81,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘verify_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘xmalloc’ from ‘verify_disk’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(4) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 89,
                    "column": 16,
                    "event": "note",
                    "message": "(7) returning to ‘verify_disk’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 97,
                    "column": 56,
                    "event": "note",
                    "message": "(8) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 98,
                    "column": 35,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 98,
                    "column": 53,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 100,
                    "column": 25,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 128,
                    "column": 55,
                    "event": "note",
                    "message": "(12) following ‘true’ branch (when ‘count < track_size’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/fdformat.c",
                    "line": 129,
                    "column": 49,
                    "event": "note",
                    "message": "(13) ...to here (14) ‘xmalloc(track_size) + count’ could be NULL: unchecked value from (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  127|   \t\t\t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  128|   \t\t\t\tfor (count = 0; count < track_size; count++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  129|-> \t\t\t\t\tif (data[count] != FD_FILL_BYTE) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  130|   \t\t\t\t\t\tif (retries_left) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  131|   \t\t\t\t\t\t\tformat_begin(ctrl);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b7eea2e9924f23a3db3957980b284958f2d32d4d",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 37,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 277,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xstrdup(*<unknown>)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 798,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 923,
                    "column": 30,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 924,
                    "column": 37,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 933,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 943,
                    "column": 28,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 943,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 948,
                    "column": 30,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 950,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 955,
                    "column": 57,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 955,
                    "column": 37,
                    "event": "note",
                    "message": "(10) calling ‘xstrdup’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 38,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(11) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 33,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(12) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(14) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(15) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 955,
                    "column": 37,
                    "event": "note",
                    "message": "(18) returning to ‘main’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 957,
                    "column": 53,
                    "event": "note",
                    "message": "(19) calling ‘ul_startswith’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 273,
                    "column": 27,
                    "event": "note",
                    "message": "(20) entry to ‘ul_startswith’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 45,
                    "event": "note",
                    "message": "(21) following ‘true’ branch (when ‘prefix’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 30,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/disk-utils/partx.c",
                    "line": 957,
                    "column": 53,
                    "event": "note",
                    "message": "(23) returning to ‘main’ from ‘ul_startswith’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 277,
                    "column": 13,
                    "event": "note",
                    "message": "(24) ‘xstrdup(*<unknown>)’ leaks here; was allocated at (14)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  275|   \tsize_t sz = prefix ? strlen(prefix) : 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  276|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  277|->         if (s && sz && strncmp(s, prefix, sz) == 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  278|                   return s + sz;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  279|   \treturn NULL;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "6c9999b9027da27b5527e8ce2eda1477d5bf6b52",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘argscan’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 293,
                    "column": 28,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘as_argv’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2117,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2153,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘s’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2154,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2154,
                    "column": 17,
                    "event": "note",
                    "message": "(4) calling ‘env_argscan’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 357,
                    "column": 13,
                    "event": "note",
                    "message": "(5) entry to ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 363,
                    "column": 21,
                    "event": "note",
                    "message": "(6) calling ‘xstrdup’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 88,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 86,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(8) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 363,
                    "column": 21,
                    "event": "note",
                    "message": "(12) returning to ‘env_argscan’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 366,
                    "column": 20,
                    "event": "note",
                    "message": "(13) calling ‘xreallocarray’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(14) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(15) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(16) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 366,
                    "column": 20,
                    "event": "note",
                    "message": "(19) returning to ‘env_argscan’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(20) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following ‘false’ branch (when ‘env_argc != size’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 373,
                    "column": 34,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(24) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(26) following ‘false’ branch (when ‘env_argc != size’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 373,
                    "column": 34,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(28) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(30) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 371,
                    "column": 36,
                    "event": "note",
                    "message": "(32) calling ‘xreallocarray’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(33) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(34) state of ‘CONJURED(ret_9 = reallocarray (ptr_5(D), nelems_6(D), size_7(D));, ret_9)’: ‘nonnull’ -> ‘unchecked’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(35) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 26,
                    "event": "note",
                    "message": "(36) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 371,
                    "column": 36,
                    "event": "note",
                    "message": "(38) returning to ‘env_argscan’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 376,
                    "column": 9,
                    "event": "note",
                    "message": "(39) calling ‘argscan’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 271,
                    "column": 13,
                    "event": "note",
                    "message": "(40) entry to ‘argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 290,
                    "column": 27,
                    "event": "note",
                    "message": "(41) following ‘true’ branch (when ‘as_argc > opt’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 293,
                    "column": 28,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 293,
                    "column": 28,
                    "event": "note",
                    "message": "(43) dereference of NULL ‘as_argv + (long unsigned int)opt * 8’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  291|   \t\tint move = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  292|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  293|-> \t\tif (as_argv[opt][0] == '-' && isdigit_string(as_argv[opt] + 1)) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  294|   \t\t\tctl->lines_per_screen =",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  295|   \t\t\t    strtos16_or_err(as_argv[opt], _(\"failed to parse number\"));",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0bb55eddf1a7695ba8a11ce53d7ea21626bce6da",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 316,
                    "column": 21,
                    "event": "warning[-Wanalyzer-null-argument]",
                    "message": "use of NULL ‘as_argv’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2117,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2153,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘s’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2154,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 2154,
                    "column": 17,
                    "event": "note",
                    "message": "(4) calling ‘env_argscan’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 357,
                    "column": 13,
                    "event": "note",
                    "message": "(5) entry to ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 363,
                    "column": 21,
                    "event": "note",
                    "message": "(6) calling ‘xstrdup’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(7) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(8) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 363,
                    "column": 21,
                    "event": "note",
                    "message": "(12) returning to ‘env_argscan’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 366,
                    "column": 20,
                    "event": "note",
                    "message": "(13) calling ‘xreallocarray’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(14) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(15) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(16) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 366,
                    "column": 20,
                    "event": "note",
                    "message": "(19) returning to ‘env_argscan’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(20) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following ‘false’ branch (when ‘env_argc != size’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 373,
                    "column": 34,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(24) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(26) following ‘false’ branch (when ‘env_argc != size’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 373,
                    "column": 34,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(28) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 368,
                    "column": 48,
                    "event": "note",
                    "message": "(30) following ‘true’ branch (when ‘tok’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 369,
                    "column": 20,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 371,
                    "column": 36,
                    "event": "note",
                    "message": "(32) calling ‘xreallocarray’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(33) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 54,
                    "column": 21,
                    "event": "note",
                    "message": "(34) state of ‘CONJURED(ret_9 = reallocarray (ptr_5(D), nelems_6(D), size_7(D));, ret_9)’: ‘nonnull’ -> ‘unchecked’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(35) assuming ‘ret’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 26,
                    "event": "note",
                    "message": "(36) following ‘false’ branch (when ‘nelems == 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 371,
                    "column": 36,
                    "event": "note",
                    "message": "(38) returning to ‘env_argscan’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 376,
                    "column": 9,
                    "event": "note",
                    "message": "(39) calling ‘argscan’ from ‘env_argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 271,
                    "column": 13,
                    "event": "note",
                    "message": "(40) entry to ‘argscan’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 290,
                    "column": 27,
                    "event": "note",
                    "message": "(41) following ‘false’ branch (when ‘as_argc <= opt’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 316,
                    "column": 21,
                    "event": "note",
                    "message": "(43) argument 2 (‘as_argv’) NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/getopt.h",
                    "line": 36,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/text-utils/more.c",
                    "line": 68,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/bits/getopt_ext.h",
                    "line": 66,
                    "column": 12,
                    "event": "note",
                    "message": "argument 2 of ‘getopt_long’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  314|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  315|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  316|-> \twhile ((c = getopt_long(as_argc, as_argv, \"dflcpsun:eVh\", longopts, NULL)) != -1) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  317|   \t\tswitch (c) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  318|   \t\tcase 'd':",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 465,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "766140a6d37b08dedf99609acad784a67900eccc",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'ul_parse_pid_str'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 46,
                    "column": 24,
                    "event": "warning[-Wanalyzer-deref-before-check]",
                    "message": "check of 'end' for NULL after already dereferencing it",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 35,
                    "column": 15,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 36,
                    "column": 24,
                    "event": "note",
                    "message": "(3) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 38,
                    "column": 20,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 40,
                    "column": 13,
                    "event": "note",
                    "message": "(5) pointer 'end' is dereferenced here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 46,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 46,
                    "column": 29,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/pidutils.c",
                    "line": 46,
                    "column": 24,
                    "event": "note",
                    "message": "(8) pointer 'end' is checked for NULL here but it was already dereferenced at (5)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   44|   \t\t*end = '\\0';",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   45|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   46|-> \tif (errno != 0 || ((end && *end != '\\0') || pidstr >= end))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   47|   \t\treturn -EINVAL;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   48|   \treturn 0;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "d197a78b971311d1fcc77a65d2e921f8ab44ae49",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'isdigit_strend'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 33,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'p'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 230,
                    "column": 31,
                    "event": "note",
                    "message": "(1) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 230,
                    "column": 64,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 232,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following 'false' branch (when 'end' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 29,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 29,
                    "event": "note",
                    "message": "(5) following 'true' branch (when 'p > str')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 33,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 234,
                    "column": 33,
                    "event": "note",
                    "message": "(7) dereference of NULL 'p'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  232|   \tif (end)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  233|   \t\t*end = p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  234|-> \treturn p && p > str && !*p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  235|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  236|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "d197a78b971311d1fcc77a65d2e921f8ab44ae49",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'isxdigit_strend'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 33,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'p'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 241,
                    "column": 31,
                    "event": "note",
                    "message": "(1) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 241,
                    "column": 65,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 243,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following 'false' branch (when 'end' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 29,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 29,
                    "event": "note",
                    "message": "(5) following 'true' branch (when 'p > str')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 33,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/strutils.c",
                    "line": 246,
                    "column": 33,
                    "event": "note",
                    "message": "(7) dereference of NULL 'p'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  244|   \t\t*end = p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  245|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  246|-> \treturn p && p > str && !*p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  247|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  248|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "dcb9bd3d69e69e6e6312b7d31ffad7669cf7eeab",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'ul_path_read_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 695,
                    "column": 21,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value '*<unknown>'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 1080,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'ul_path_readf_cpulist'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 1086,
                    "column": 14,
                    "event": "note",
                    "message": "(2) calling 'ul_path_cpuparse' from 'ul_path_readf_cpulist'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 1022,
                    "column": 12,
                    "event": "note",
                    "message": "(3) entry to 'ul_path_cpuparse'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 1030,
                    "column": 15,
                    "event": "note",
                    "message": "(4) region created on heap here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 1031,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following 'false' branch (when 'buf' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 1034,
                    "column": 14,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 1034,
                    "column": 14,
                    "event": "note",
                    "message": "(7) calling 'ul_path_vreadf_buffer' from 'ul_path_cpuparse'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 704,
                    "column": 5,
                    "event": "note",
                    "message": "(8) entry to 'ul_path_vreadf_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 708,
                    "column": 13,
                    "event": "note",
                    "message": "(9) calling 'ul_path_mkpath' from 'ul_path_vreadf_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 247,
                    "column": 20,
                    "event": "note",
                    "message": "(10) entry to 'ul_path_mkpath'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 254,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'false' branch (when 'rc >= 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 260,
                    "column": 24,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 260,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 708,
                    "column": 13,
                    "event": "note",
                    "message": "(15) returning to 'ul_path_vreadf_buffer' from 'ul_path_mkpath'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 710,
                    "column": 28,
                    "event": "note",
                    "message": "(16) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 710,
                    "column": 30,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 710,
                    "column": 30,
                    "event": "note",
                    "message": "(18) calling 'ul_path_read_buffer' from 'ul_path_vreadf_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 686,
                    "column": 5,
                    "event": "note",
                    "message": "(19) entry to 'ul_path_read_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 688,
                    "column": 18,
                    "event": "note",
                    "message": "(20) calling 'ul_path_read' from 'ul_path_read_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 609,
                    "column": 5,
                    "event": "note",
                    "message": "(21) entry to 'ul_path_read'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 614,
                    "column": 14,
                    "event": "note",
                    "message": "(22) calling 'ul_path_open' from 'ul_path_read'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 392,
                    "column": 5,
                    "event": "note",
                    "message": "(23) entry to 'ul_path_open'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 396,
                    "column": 12,
                    "event": "note",
                    "message": "(24) following 'false' branch (when 'path' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 398,
                    "column": 12,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 398,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following 'false' branch (when 'pc' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 403,
                    "column": 27,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 403,
                    "column": 27,
                    "event": "note",
                    "message": "(28) calling 'ul_path_get_dirfd' from 'ul_path_open'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 213,
                    "column": 5,
                    "event": "note",
                    "message": "(29) entry to 'ul_path_get_dirfd'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 24,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 215,
                    "column": 9,
                    "event": "note",
                    "message": "(30) following 'true' branch (when 'pc' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 216,
                    "column": 18,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 216,
                    "column": 9,
                    "event": "note",
                    "message": "(32) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 218,
                    "column": 15,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 403,
                    "column": 27,
                    "event": "note",
                    "message": "(34) returning to 'ul_path_open' from 'ul_path_get_dirfd'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 404,
                    "column": 20,
                    "event": "note",
                    "message": "(35) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 407,
                    "column": 21,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 20,
                    "event": "note",
                    "message": "(37) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 40,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 417,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 614,
                    "column": 14,
                    "event": "note",
                    "message": "(39) returning to 'ul_path_read' from 'ul_path_open'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 615,
                    "column": 12,
                    "event": "note",
                    "message": "(40) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 22,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 616,
                    "column": 25,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 688,
                    "column": 18,
                    "event": "note",
                    "message": "(42) returning to 'ul_path_read_buffer' from 'ul_path_read'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 690,
                    "column": 12,
                    "event": "note",
                    "message": "(43) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 693,
                    "column": 17,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 693,
                    "column": 17,
                    "event": "note",
                    "message": "(45) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 695,
                    "column": 32,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lib/path.c",
                    "line": 695,
                    "column": 21,
                    "event": "note",
                    "message": "(47) use of uninitialized value '*<unknown>' here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  693|   \telse if (rc > 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  694|   \t\t/* Remove trailing newline (usual in sysfs) */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  695|-> \t\tif (*(buf + rc - 1) == '\\n')",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  696|   \t\t\tbuf[--rc] = '\\0';",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  697|   \t\telse",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "3503f5c856d7d66a97a7d47037d738e985539c85",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘process_title_init’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 241,
                    "column": 28,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘environ’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1325,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘initialize’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1347,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘xasprintf’ from ‘initialize’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 116,
                    "column": 5,
                    "event": "note",
                    "message": "(3) entry to ‘xasprintf’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 124,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘ret >= 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 126,
                    "column": 16,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1347,
                    "column": 9,
                    "event": "note",
                    "message": "(6) returning to ‘initialize’ from ‘xasprintf’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1359,
                    "column": 9,
                    "event": "note",
                    "message": "(7) calling ‘process_title_init’ from ‘initialize’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 224,
                    "column": 13,
                    "event": "note",
                    "message": "(8) entry to ‘process_title_init’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 238,
                    "column": 19,
                    "event": "note",
                    "message": "(9) calling ‘xmalloc’ from ‘process_title_init’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(11) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 238,
                    "column": 19,
                    "event": "note",
                    "message": "(14) returning to ‘process_title_init’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 240,
                    "column": 29,
                    "event": "note",
                    "message": "(15) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 241,
                    "column": 24,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 241,
                    "column": 30,
                    "event": "note",
                    "message": "(17) calling ‘xstrdup’ from ‘process_title_init’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(18) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/path.h",
                    "line": 14,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 49,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(19) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 241,
                    "column": 30,
                    "event": "note",
                    "message": "(23) returning to ‘process_title_init’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 241,
                    "column": 28,
                    "event": "note",
                    "message": "(24) ‘environ + (long unsigned int)i * 8’ could be NULL: unchecked value from (11)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  239|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  240|   \tfor (i = 0; envp[i] != NULL; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  241|-> \t\tenviron[i] = xstrdup(envp[i]);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  242|   \tenviron[i] = NULL;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  243|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "598a02d245e1322749c55b660b0ac77bd9c1165f",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 242,
                    "column": 20,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘environ’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1325,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘initialize’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1347,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘xasprintf’ from ‘initialize’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 116,
                    "column": 5,
                    "event": "note",
                    "message": "(3) entry to ‘xasprintf’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 124,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch (when ‘ret >= 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 126,
                    "column": 16,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1347,
                    "column": 9,
                    "event": "note",
                    "message": "(6) returning to ‘initialize’ from ‘xasprintf’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 1359,
                    "column": 9,
                    "event": "note",
                    "message": "(7) calling ‘process_title_init’ from ‘initialize’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 224,
                    "column": 13,
                    "event": "note",
                    "message": "(8) entry to ‘process_title_init’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 238,
                    "column": 19,
                    "event": "note",
                    "message": "(9) calling ‘xmalloc’ from ‘process_title_init’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(10) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(11) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 238,
                    "column": 19,
                    "event": "note",
                    "message": "(14) returning to ‘process_title_init’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 240,
                    "column": 29,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 242,
                    "column": 16,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 242,
                    "column": 20,
                    "event": "note",
                    "message": "(17) ‘environ + (long unsigned int)i * 8’ could be NULL: unchecked value from (11)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  240|   \tfor (i = 0; envp[i] != NULL; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  241|   \t\tenviron[i] = xstrdup(envp[i]);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  242|-> \tenviron[i] = NULL;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  243|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  244|   \tif (i > 0)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 1341,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "e33d3138727aef95d6691893bcc90037f7743d13",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘open_tty’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 457,
                    "column": 17,
                    "event": "warning[-Wanalyzer-fd-double-close]",
                    "message": "double ‘close’ of file descriptor ‘i’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 512,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘init_tty’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 532,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 36,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 533,
                    "column": 58,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 533,
                    "column": 44,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 534,
                    "column": 16,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 534,
                    "column": 74,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 535,
                    "column": 53,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 535,
                    "column": 53,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 551,
                    "column": 13,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 557,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 561,
                    "column": 29,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 564,
                    "column": 61,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 572,
                    "column": 17,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 572,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 579,
                    "column": 9,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 579,
                    "column": 9,
                    "event": "note",
                    "message": "(16) first ‘close’ here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 588,
                    "column": 9,
                    "event": "note",
                    "message": "(17) calling ‘open_tty’ from ‘init_tty’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 436,
                    "column": 13,
                    "event": "note",
                    "message": "(18) entry to ‘open_tty’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 441,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 446,
                    "column": 14,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 446,
                    "column": 14,
                    "event": "note",
                    "message": "(21) when ‘isatty’ succeeds",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 446,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 452,
                    "column": 17,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 456,
                    "column": 23,
                    "event": "note",
                    "message": "(24) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 457,
                    "column": 17,
                    "event": "note",
                    "message": "(25) ...to here (26) second ‘close’ here; first ‘close’ was at (16)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  455|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  456|   \tfor (i = 0; i < fd; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  457|-> \t\tclose(i);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  458|   \tfor (i = 0; i < 3; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  459|   \t\tif (fd != i)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "e35f0770cf09447bdd9933b1f90eb3b36bc44a05",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 460,
                    "column": 25,
                    "event": "warning[-Wanalyzer-fd-use-without-check]",
                    "message": "‘dup2’ on possibly invalid file descriptor ‘i’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 441,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 446,
                    "column": 14,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 446,
                    "column": 14,
                    "event": "note",
                    "message": "(3) when ‘isatty’ succeeds",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 446,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 452,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 456,
                    "column": 23,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 457,
                    "column": 17,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 457,
                    "column": 17,
                    "event": "note",
                    "message": "(8) closed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 456,
                    "column": 23,
                    "event": "note",
                    "message": "(9) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 458,
                    "column": 23,
                    "event": "note",
                    "message": "(11) following ‘true’ branch (when ‘i != 3’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 459,
                    "column": 20,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 459,
                    "column": 20,
                    "event": "note",
                    "message": "(13) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 460,
                    "column": 25,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/login-utils/login.c",
                    "line": 460,
                    "column": 25,
                    "event": "note",
                    "message": "(15) ‘i’ could be invalid",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  458|   \tfor (i = 0; i < 3; i++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  459|   \t\tif (fd != i)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  460|-> \t\t\tdup2(fd, i);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  461|   \tif (fd >= 3)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  462|   \t\tclose(fd);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "CPPCHECK_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "cppcheck",
            "hash_v1": "ac8dacd589ceae1c509313a86678e44d0a2b155d",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/sys-utils/mount.c",
                    "line": 898,
                    "event": "error[legacyUninitvar]",
                    "message": "Uninitialized variable: path",
                    "verbosity_level": 0
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  896|   \t\t\t\tsnprintf(path, sizeof(path), \"/proc/%i/ns/mnt\", pid);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  897|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  898|-> \t\t\tif (mnt_context_set_target_ns(cxt, pid ? path : optarg))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  899|   \t\t\t\terr(MNT_EX_SYSERR, _(\"failed to set target namespace to %s\"), pid ? path : optarg);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  900|   \t\t\tbreak;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "21dc3b8b06eb1d47f33442e300d7dada1190c024",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'update_str'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 163,
                    "column": 9,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of '*m.mnt_fsname'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2002,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2007,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2010,
                    "column": 11,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2011,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch (when 'm' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(6) calling 'mnt_fs_get_source' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 441,
                    "column": 13,
                    "event": "note",
                    "message": "(7) entry to 'mnt_fs_get_source'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 443,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 312,
                    "column": 34,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 447,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'mnt_fs_try_statmount'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(10) returning to 'mnt_fs_to_mntent' from 'mnt_fs_get_source'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(11) calling 'update_str' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 145,
                    "column": 19,
                    "event": "note",
                    "message": "(12) entry to 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 29,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 150,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following 'true' branch (when 'dest' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following 'false' branch (when 'src' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 158,
                    "column": 14,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(17) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(18) when 'realloc' succeeds, moving buffer",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 160,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following 'false' branch (when 'x' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 163,
                    "column": 9,
                    "event": "note",
                    "message": "(21) '*m.mnt_fsname' leaks here; was allocated at (17)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  161|   \t\treturn -ENOMEM;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  162|   \t*dest = x;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  163|-> \tmemcpy(*dest, src, sz);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  164|   \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  165|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "e5721297fd6d039ebdf3532587a95b7f80a03001",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 163,
                    "column": 9,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of '*m.mnt_dir'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2002,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2007,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2010,
                    "column": 11,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2011,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch (when 'm' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(6) calling 'mnt_fs_get_source' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 441,
                    "column": 13,
                    "event": "note",
                    "message": "(7) entry to 'mnt_fs_get_source'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 443,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 312,
                    "column": 34,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 447,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'mnt_fs_try_statmount'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(10) returning to 'mnt_fs_to_mntent' from 'mnt_fs_get_source'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(11) calling 'update_str' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 145,
                    "column": 19,
                    "event": "note",
                    "message": "(12) entry to 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 150,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following 'true' branch (when 'dest' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(15) when 'realloc' succeeds, without moving buffer",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 160,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following 'false' branch (when 'x' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(18) returning to 'mnt_fs_to_mntent' from 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(21) calling 'mnt_fs_get_target' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 623,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to 'mnt_fs_get_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 625,
                    "column": 12,
                    "event": "note",
                    "message": "(23) following 'false' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 312,
                    "column": 34,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 628,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'mnt_fs_try_statmount'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(25) returning to 'mnt_fs_to_mntent' from 'mnt_fs_get_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(26) calling 'update_str' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 145,
                    "column": 19,
                    "event": "note",
                    "message": "(27) entry to 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 150,
                    "column": 9,
                    "event": "note",
                    "message": "(28) following 'true' branch (when 'dest' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(30) following 'false' branch (when 'src' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 158,
                    "column": 14,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(32) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(33) when 'realloc' succeeds, moving buffer",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 160,
                    "column": 12,
                    "event": "note",
                    "message": "(34) following 'false' branch (when 'x' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 163,
                    "column": 9,
                    "event": "note",
                    "message": "(36) '*m.mnt_dir' leaks here; was allocated at (32)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  161|   \t\treturn -ENOMEM;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  162|   \t*dest = x;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  163|-> \tmemcpy(*dest, src, sz);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  164|   \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  165|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "cdd9ae05e8f22e878f237151d19ceebc3fb2c671",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 163,
                    "column": 9,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of '*m.mnt_type'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2002,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2007,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2010,
                    "column": 11,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2011,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch (when 'm' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(6) calling 'mnt_fs_get_source' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 441,
                    "column": 13,
                    "event": "note",
                    "message": "(7) entry to 'mnt_fs_get_source'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 443,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 312,
                    "column": 34,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 447,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'mnt_fs_try_statmount'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(10) returning to 'mnt_fs_to_mntent' from 'mnt_fs_get_source'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(11) calling 'update_str' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 145,
                    "column": 19,
                    "event": "note",
                    "message": "(12) entry to 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 150,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following 'true' branch (when 'dest' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(15) when 'realloc' succeeds, without moving buffer",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 160,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following 'false' branch (when 'x' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 19,
                    "event": "note",
                    "message": "(18) returning to 'mnt_fs_to_mntent' from 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2017,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(21) calling 'mnt_fs_get_target' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 623,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to 'mnt_fs_get_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 625,
                    "column": 12,
                    "event": "note",
                    "message": "(23) following 'false' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 312,
                    "column": 34,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 628,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'mnt_fs_try_statmount'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(25) returning to 'mnt_fs_to_mntent' from 'mnt_fs_get_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(26) calling 'update_str' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 145,
                    "column": 19,
                    "event": "note",
                    "message": "(27) entry to 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 150,
                    "column": 9,
                    "event": "note",
                    "message": "(28) following 'true' branch (when 'dest' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(30) following 'true' branch (when 'src' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 153,
                    "column": 17,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 19,
                    "event": "note",
                    "message": "(32) returning to 'mnt_fs_to_mntent' from 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2019,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2021,
                    "column": 19,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2021,
                    "column": 19,
                    "event": "note",
                    "message": "(35) calling 'mnt_fs_get_fstype' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 818,
                    "column": 13,
                    "event": "note",
                    "message": "(36) entry to 'mnt_fs_get_fstype'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 820,
                    "column": 12,
                    "event": "note",
                    "message": "(37) following 'false' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 312,
                    "column": 34,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 823,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'mnt_fs_try_statmount'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2021,
                    "column": 19,
                    "event": "note",
                    "message": "(39) returning to 'mnt_fs_to_mntent' from 'mnt_fs_get_fstype'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 2021,
                    "column": 19,
                    "event": "note",
                    "message": "(40) calling 'update_str' from 'mnt_fs_to_mntent'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 145,
                    "column": 19,
                    "event": "note",
                    "message": "(41) entry to 'update_str'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 150,
                    "column": 9,
                    "event": "note",
                    "message": "(42) following 'true' branch (when 'dest' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 152,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following 'false' branch (when 'src' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 158,
                    "column": 14,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(46) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 159,
                    "column": 13,
                    "event": "note",
                    "message": "(47) when 'realloc' succeeds, moving buffer",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 160,
                    "column": 12,
                    "event": "note",
                    "message": "(48) following 'false' branch (when 'x' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 162,
                    "column": 15,
                    "event": "note",
                    "message": "(49) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/fs.c",
                    "line": 163,
                    "column": 9,
                    "event": "note",
                    "message": "(50) '*m.mnt_type' leaks here; was allocated at (46)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  161|   \t\treturn -ENOMEM;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  162|   \t*dest = x;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  163|-> \tmemcpy(*dest, src, sz);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  164|   \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  165|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "e0df17a2337b48bcc1c08cb2550e0fc9626d89a0",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'mnt_table_find_target'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1196,
                    "column": 24,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'fs'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1865,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to '__mnt_table_is_fs_mounted'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1882,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1887,
                    "column": 13,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1887,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1892,
                    "column": 21,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1892,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1896,
                    "column": 26,
                    "event": "note",
                    "message": "(8) calling 'mnt_table_get_fs_root' from '__mnt_table_is_fs_mounted'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1763,
                    "column": 19,
                    "event": "note",
                    "message": "(9) entry to 'mnt_table_get_fs_root'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 29,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 52,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1772,
                    "column": 9,
                    "event": "note",
                    "message": "(10) following 'true' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1773,
                    "column": 9,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1773,
                    "column": 9,
                    "event": "note",
                    "message": "(12) following 'true' branch (when 'fsroot' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 32,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 63,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1775,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1777,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 63,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1781,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1784,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1785,
                    "column": 47,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1785,
                    "column": 47,
                    "event": "note",
                    "message": "(18) calling 'mnt_table_find_mountpoint' from 'mnt_table_get_fs_root'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1089,
                    "column": 19,
                    "event": "note",
                    "message": "(19) entry to 'mnt_table_find_mountpoint'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1095,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1097,
                    "column": 43,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1097,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 63,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1100,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1102,
                    "column": 12,
                    "event": "note",
                    "message": "(24) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1105,
                    "column": 15,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1106,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following 'false' branch (when 'mnt' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1113,
                    "column": 22,
                    "event": "note",
                    "message": "(28) calling 'mnt_table_find_target' from 'mnt_table_find_mountpoint'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1143,
                    "column": 19,
                    "event": "note",
                    "message": "(29) entry to 'mnt_table_find_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1146,
                    "column": 27,
                    "event": "note",
                    "message": "(30) 'fs' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1149,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1151,
                    "column": 43,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1151,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 63,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1154,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1158,
                    "column": 15,
                    "event": "note",
                    "message": "(35) calling 'mnt_table_next_fs' from 'mnt_table_find_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 850,
                    "column": 5,
                    "event": "note",
                    "message": "(36) entry to 'mnt_table_next_fs'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 854,
                    "column": 12,
                    "event": "note",
                    "message": "(37) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 856,
                    "column": 12,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 856,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following 'true' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 857,
                    "column": 21,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1158,
                    "column": 15,
                    "event": "note",
                    "message": "(41) returning to 'mnt_table_find_target' from 'mnt_table_next_fs'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1176,
                    "column": 12,
                    "event": "note",
                    "message": "(42) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 63,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1179,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1183,
                    "column": 15,
                    "event": "note",
                    "message": "(44) calling 'mnt_table_next_fs' from 'mnt_table_find_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 850,
                    "column": 5,
                    "event": "note",
                    "message": "(45) entry to 'mnt_table_next_fs'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 854,
                    "column": 12,
                    "event": "note",
                    "message": "(46) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 856,
                    "column": 12,
                    "event": "note",
                    "message": "(47) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 856,
                    "column": 12,
                    "event": "note",
                    "message": "(48) following 'true' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 857,
                    "column": 21,
                    "event": "note",
                    "message": "(49) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1183,
                    "column": 15,
                    "event": "note",
                    "message": "(50) returning to 'mnt_table_find_target' from 'mnt_table_next_fs'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1193,
                    "column": 15,
                    "event": "note",
                    "message": "(51) calling 'mnt_table_next_fs' from 'mnt_table_find_target'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 850,
                    "column": 5,
                    "event": "note",
                    "message": "(52) entry to 'mnt_table_next_fs'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 854,
                    "column": 12,
                    "event": "note",
                    "message": "(53) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 856,
                    "column": 12,
                    "event": "note",
                    "message": "(54) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 856,
                    "column": 12,
                    "event": "note",
                    "message": "(55) following 'true' branch (when 'fs' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 857,
                    "column": 21,
                    "event": "note",
                    "message": "(56) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 866,
                    "column": 20,
                    "event": "note",
                    "message": "(57) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 185,
                    "column": 38,
                    "event": "note",
                    "message": "(58) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 190,
                    "column": 28,
                    "event": "note",
                    "message": "in expansion of macro 'IS_ITER_FORWARD'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 868,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro 'MNT_ITER_INIT'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 869,
                    "column": 20,
                    "event": "note",
                    "message": "(59) following 'false' branch (when 'prev' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(60) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 875,
                    "column": 12,
                    "event": "note",
                    "message": "(61) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 877,
                    "column": 16,
                    "event": "note",
                    "message": "(62) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1193,
                    "column": 15,
                    "event": "note",
                    "message": "(63) returning to 'mnt_table_find_target' from 'mnt_table_next_fs'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1193,
                    "column": 48,
                    "event": "note",
                    "message": "(64) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1196,
                    "column": 24,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1196,
                    "column": 24,
                    "event": "note",
                    "message": "(66) 'fs' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/tab.c",
                    "line": 1196,
                    "column": 24,
                    "event": "note",
                    "message": "(67) dereference of NULL 'fs'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1194|   \t\tchar *p;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1195|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1196|-> \t\tif (!fs->target",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1197|   \t\t    || mnt_fs_is_swaparea(fs)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1198|   \t\t    || mnt_fs_is_kernel(fs)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 416,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "33ddf0cc54b724781a7e98b677713f23939b93b5",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'mnt_free_filesystems.part.0'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 600,
                    "column": 31,
                    "event": "warning[-Wanalyzer-use-after-free]",
                    "message": "use after 'reallocarray' of 'p'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 605,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to 'add_filesystem'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 24,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 609,
                    "column": 9,
                    "event": "note",
                    "message": "(2) following 'true' branch (when 'filesystems' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 610,
                    "column": 9,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 610,
                    "column": 9,
                    "event": "note",
                    "message": "(4) following 'true' branch (when 'name' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 612,
                    "column": 13,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 624,
                    "column": 28,
                    "event": "note",
                    "message": "(6) deallocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 626,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following 'true' branch (when 'x' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 627,
                    "column": 25,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 637,
                    "column": 9,
                    "event": "note",
                    "message": "(9) calling 'mnt_free_filesystems' from 'add_filesystem'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 594,
                    "column": 6,
                    "event": "note",
                    "message": "(10) entry to 'mnt_free_filesystems'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 598,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'false' branch (when 'filesystems' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(13) calling 'mnt_free_filesystems' from 'mnt_free_filesystems'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 594,
                    "column": 6,
                    "event": "note",
                    "message": "(14) entry to 'mnt_free_filesystems'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/utils.c",
                    "line": 600,
                    "column": 31,
                    "event": "note",
                    "message": "(15) use after 'reallocarray' of 'p'; deallocated at (6)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  598|   \tif (!filesystems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  599|   \t\treturn;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  600|-> \tfor (p = filesystems; *p; p++)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  601|   \t\tfree(*p);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  602|   \tfree(filesystems);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "cc23f0642c82a8a0ce06c0671204e8b6ca22b84e",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'hook_prepare_options'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 465,
                    "column": 25,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'idmap'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 379,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to 'hook_prepare_options'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 392,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 395,
                    "column": 15,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 396,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 399,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 400,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 401,
                    "column": 25,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 402,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 405,
                    "column": 14,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 405,
                    "column": 14,
                    "event": "note",
                    "message": "(10) calling 'new_hook_data' from 'hook_prepare_options'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 55,
                    "column": 33,
                    "event": "note",
                    "message": "(11) entry to 'new_hook_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 59,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following 'false' branch (when 'hd' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 31,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 62,
                    "column": 24,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 39,
                    "column": 24,
                    "event": "note",
                    "message": "in definition of macro 'INIT_LIST_HEAD'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 405,
                    "column": 14,
                    "event": "note",
                    "message": "(14) returning to 'hook_prepare_options' from 'new_hook_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 406,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 410,
                    "column": 12,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 410,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 417,
                    "column": 15,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 418,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following 'false' branch (when 'buf' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 431,
                    "column": 20,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 431,
                    "column": 50,
                    "event": "note",
                    "message": "(21) following 'true' branch (when 'tok' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 435,
                    "column": 26,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 437,
                    "column": 21,
                    "event": "note",
                    "message": "(23) calling 'ul_startswith' from 'hook_prepare_options'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 24,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 273,
                    "column": 27,
                    "event": "note",
                    "message": "(24) entry to 'ul_startswith'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 45,
                    "event": "note",
                    "message": "(25) following 'true' branch (when 'prefix' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 30,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 277,
                    "column": 12,
                    "event": "note",
                    "message": "(27) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 277,
                    "column": 24,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 437,
                    "column": 21,
                    "event": "note",
                    "message": "(29) returning to 'hook_prepare_options' from 'ul_startswith'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 437,
                    "column": 20,
                    "event": "note",
                    "message": "(30) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 440,
                    "column": 29,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 462,
                    "column": 20,
                    "event": "note",
                    "message": "(32) following 'false' branch (when 'rc == 3')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 465,
                    "column": 25,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 465,
                    "column": 25,
                    "event": "note",
                    "message": "(34) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 466,
                    "column": 20,
                    "event": "note",
                    "message": "(35) assuming 'idmap' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 466,
                    "column": 20,
                    "event": "note",
                    "message": "(36) following 'false' branch (when 'idmap' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 469,
                    "column": 33,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 431,
                    "column": 50,
                    "event": "note",
                    "message": "(38) following 'true' branch (when 'tok' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 435,
                    "column": 26,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 437,
                    "column": 21,
                    "event": "note",
                    "message": "(40) calling 'ul_startswith' from 'hook_prepare_options'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 273,
                    "column": 27,
                    "event": "note",
                    "message": "(41) entry to 'ul_startswith'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 45,
                    "event": "note",
                    "message": "(42) following 'true' branch (when 'prefix' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 275,
                    "column": 30,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 277,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/strutils.h",
                    "line": 277,
                    "column": 24,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 437,
                    "column": 21,
                    "event": "note",
                    "message": "(46) returning to 'hook_prepare_options' from 'ul_startswith'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 437,
                    "column": 20,
                    "event": "note",
                    "message": "(47) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 440,
                    "column": 29,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 462,
                    "column": 20,
                    "event": "note",
                    "message": "(49) following 'false' branch (when 'rc == 3')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/hook_idmap.c",
                    "line": 465,
                    "column": 25,
                    "event": "note",
                    "message": "(50) ...to here (51) 'idmap' leaks here; was allocated at (34)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  463|   \t\t\tgoto err;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  464|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  465|-> \t\tidmap = calloc(1, sizeof(*idmap));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  466|   \t\tif (!idmap)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  467|   \t\t\tgoto err;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "10198cd5cd8cfb276588805e455503eafdc6c5a2",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'mnt_monitor_next_change'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 444,
                    "column": 20,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL '0'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 425,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'mnt_monitor_next_change'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 432,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 435,
                    "column": 18,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 435,
                    "column": 18,
                    "event": "note",
                    "message": "(4) '*mn.last' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 437,
                    "column": 14,
                    "event": "note",
                    "message": "(5) calling 'get_active' from 'mnt_monitor_next_change'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 397,
                    "column": 30,
                    "event": "note",
                    "message": "(6) entry to 'get_active'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 403,
                    "column": 16,
                    "event": "note",
                    "message": "(7) calling 'monitor_next_entry' from 'get_active'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 136,
                    "column": 12,
                    "event": "note",
                    "message": "(8) entry to 'monitor_next_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/mountP.h",
                    "line": 29,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 38,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 142,
                    "column": 9,
                    "event": "note",
                    "message": "(9) following 'true' branch (when 'mn' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 143,
                    "column": 9,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 143,
                    "column": 9,
                    "event": "note",
                    "message": "(11) following 'true' branch (when 'itr' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 145,
                    "column": 12,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 145,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following 'true' branch (when 'me' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 146,
                    "column": 21,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 146,
                    "column": 21,
                    "event": "note",
                    "message": "(15) 'me' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 403,
                    "column": 16,
                    "event": "note",
                    "message": "(16) returning to 'get_active' from 'monitor_next_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 403,
                    "column": 50,
                    "event": "note",
                    "message": "(17) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 405,
                    "column": 32,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 437,
                    "column": 14,
                    "event": "note",
                    "message": "(19) returning to 'mnt_monitor_next_change' from 'get_active'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 437,
                    "column": 12,
                    "event": "note",
                    "message": "(20) 'me' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 438,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 439,
                    "column": 22,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 439,
                    "column": 22,
                    "event": "note",
                    "message": "(23) calling 'read_epoll_events' from 'mnt_monitor_next_change'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 317,
                    "column": 12,
                    "event": "note",
                    "message": "(24) entry to 'read_epoll_events'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 323,
                    "column": 12,
                    "event": "note",
                    "message": "(25) following 'true' branch (when 'act' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 324,
                    "column": 22,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 439,
                    "column": 22,
                    "event": "note",
                    "message": "(27) returning to 'mnt_monitor_next_change' from 'read_epoll_events'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 440,
                    "column": 20,
                    "event": "note",
                    "message": "(28) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 444,
                    "column": 11,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 444,
                    "column": 11,
                    "event": "note",
                    "message": "(30) 'me' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 445,
                    "column": 18,
                    "event": "note",
                    "message": "(31) '*mn.last' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libmount/src/monitor.c",
                    "line": 444,
                    "column": 20,
                    "event": "note",
                    "message": "(32) dereference of NULL 'me'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  442|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  443|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  444|-> \tme->active = 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  445|   \tmn->last = me;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  446|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 416,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "7a6b26b621bdbbb7ef4faea5dffccbc853bca9eb",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'unref_parttable'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 331,
                    "column": 12,
                    "event": "warning[-Wanalyzer-use-after-free]",
                    "message": "use after 'free' of 'tab'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 586,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to 'partitions_probe'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 599,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 600,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 600,
                    "column": 17,
                    "event": "note",
                    "message": "(4) calling 'partitions_init_data' from 'partitions_probe'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 377,
                    "column": 23,
                    "event": "note",
                    "message": "(5) entry to 'partitions_init_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 381,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 391,
                    "column": 9,
                    "event": "note",
                    "message": "(8) inlined call to 'reset_partlist' from 'partitions_init_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(9) calling 'reset_partlist' from 'partitions_init_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'unref_parttable'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 352,
                    "column": 13,
                    "event": "note",
                    "message": "(10) entry to 'reset_partlist'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 357,
                    "column": 9,
                    "event": "note",
                    "message": "(11) calling 'free_parttables' from 'reset_partlist'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 339,
                    "column": 13,
                    "event": "note",
                    "message": "(12) entry to 'free_parttables'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 341,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(15) calling 'free_parttables' from 'free_parttables'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 339,
                    "column": 13,
                    "event": "note",
                    "message": "(16) entry to 'free_parttables'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 345,
                    "column": 16,
                    "event": "note",
                    "message": "(17) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/blkidP.h",
                    "line": 30,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.h",
                    "line": 4,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 272,
                    "column": 9,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 176,
                    "column": 41,
                    "event": "note",
                    "message": "in expansion of macro 'container_of'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 346,
                    "column": 39,
                    "event": "note",
                    "message": "in expansion of macro 'list_entry'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 348,
                    "column": 17,
                    "event": "note",
                    "message": "(19) calling 'unref_parttable' from 'free_parttables'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 326,
                    "column": 13,
                    "event": "note",
                    "message": "(20) entry to 'unref_parttable'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 328,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following 'false' branch (when 'tab' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 331,
                    "column": 12,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 334,
                    "column": 17,
                    "event": "note",
                    "message": "(23) freed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 348,
                    "column": 17,
                    "event": "note",
                    "message": "(24) returning to 'free_parttables' from 'unref_parttable'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 345,
                    "column": 16,
                    "event": "note",
                    "message": "(25) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 272,
                    "column": 9,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 176,
                    "column": 41,
                    "event": "note",
                    "message": "in expansion of macro 'container_of'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 346,
                    "column": 39,
                    "event": "note",
                    "message": "in expansion of macro 'list_entry'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 348,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling 'unref_parttable' from 'free_parttables'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 326,
                    "column": 13,
                    "event": "note",
                    "message": "(28) entry to 'unref_parttable'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 328,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following 'false' branch (when 'tab' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/partitions/partitions.c",
                    "line": 331,
                    "column": 12,
                    "event": "note",
                    "message": "(30) ...to here (31) use after 'free' of 'tab'; freed at (23)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  329|   \t\treturn;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  330|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  331|-> \ttab->nparts--;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  332|   \tif (tab->nparts <= 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  333|   \t\tlist_del(&tab->t_tabs);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "fb7e8e313a524227288349d315639689da348d01",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'probe_dm_tp'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 118,
                    "column": 16,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor 'dmpipe[0]'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 44,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 46,
                    "column": 14,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 46,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 49,
                    "column": 23,
                    "event": "note",
                    "message": "(5) following 'true' branch (when 'i != 3')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 51,
                    "column": 31,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 57,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following 'false' branch (when 'cmd' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 13,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 13,
                    "event": "note",
                    "message": "(9) opened here as read-write",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 13,
                    "event": "note",
                    "message": "(10) when 'pipe' succeeds",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 64,
                    "column": 17,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 64,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following 'case -1:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 95,
                    "column": 9,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 123,
                    "column": 17,
                    "event": "note",
                    "message": "(15) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 118,
                    "column": 16,
                    "event": "note",
                    "message": "(17) 'dmpipe[0]' leaks here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  116|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  117|   \tfclose(stream);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  118|-> \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  119|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  120|   nothing:",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "30787679c3711462445acac9b317136a5a630153",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 118,
                    "column": 16,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor 'dmpipe[1]'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 44,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 46,
                    "column": 14,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 46,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 49,
                    "column": 23,
                    "event": "note",
                    "message": "(5) following 'true' branch (when 'i != 3')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 51,
                    "column": 31,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 57,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following 'false' branch (when 'cmd' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 13,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 13,
                    "event": "note",
                    "message": "(9) opened here as read-write",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 13,
                    "event": "note",
                    "message": "(10) when 'pipe' succeeds",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 59,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 64,
                    "column": 17,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 64,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following 'case -1:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 95,
                    "column": 9,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 123,
                    "column": 17,
                    "event": "note",
                    "message": "(15) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/dm.c",
                    "line": 118,
                    "column": 16,
                    "event": "note",
                    "message": "(17) 'dmpipe[1]' leaks here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  116|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  117|   \tfclose(stream);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  118|-> \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  119|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  120|   nothing:",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "8a7f12d583fa5ca82821714e6a405374029d2187",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'probe_lvm_tp'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 125,
                    "column": 16,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor 'lvpipe[0]'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 49,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 51,
                    "column": 14,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 51,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 54,
                    "column": 23,
                    "event": "note",
                    "message": "(5) following 'true' branch (when 'i != 3')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 56,
                    "column": 31,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 62,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following 'false' branch (when 'cmd' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 65,
                    "column": 19,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 66,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 13,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 13,
                    "event": "note",
                    "message": "(11) opened here as read-write",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 13,
                    "event": "note",
                    "message": "(12) when 'pipe' succeeds",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 74,
                    "column": 17,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 74,
                    "column": 9,
                    "event": "note",
                    "message": "(15) following 'case -1:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 97,
                    "column": 9,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following 'false' branch (when 'stream' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 131,
                    "column": 24,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 131,
                    "column": 17,
                    "event": "note",
                    "message": "(19) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 133,
                    "column": 19,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 133,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 125,
                    "column": 16,
                    "event": "note",
                    "message": "(23) 'lvpipe[0]' leaks here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  123|   \tfclose(stream);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  124|   \tclose(lvpipe[1]);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  125|-> \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  126|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  127|   nothing:",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 775,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ae2556272138145295200f3105451741a4260ca8",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 125,
                    "column": 16,
                    "event": "warning[-Wanalyzer-fd-leak]",
                    "message": "leak of file descriptor 'lvpipe[1]'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 49,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 51,
                    "column": 14,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 51,
                    "column": 12,
                    "event": "note",
                    "message": "(3) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 54,
                    "column": 23,
                    "event": "note",
                    "message": "(5) following 'true' branch (when 'i != 3')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 56,
                    "column": 31,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 62,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following 'false' branch (when 'cmd' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 65,
                    "column": 19,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 66,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 13,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 13,
                    "event": "note",
                    "message": "(11) opened here as read-write",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 13,
                    "event": "note",
                    "message": "(12) when 'pipe' succeeds",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 69,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 74,
                    "column": 17,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 74,
                    "column": 9,
                    "event": "note",
                    "message": "(15) following 'case -1:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 97,
                    "column": 9,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following 'false' branch (when 'stream' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 131,
                    "column": 24,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 131,
                    "column": 17,
                    "event": "note",
                    "message": "(19) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 133,
                    "column": 19,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 133,
                    "column": 12,
                    "event": "note",
                    "message": "(21) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libblkid/src/topology/lvm.c",
                    "line": 125,
                    "column": 16,
                    "event": "note",
                    "message": "(23) 'lvpipe[1]' leaks here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  123|   \tfclose(stream);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  124|   \tclose(lvpipe[1]);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  125|-> \treturn 0;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  126|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  127|   nothing:",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 416,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "667bdd66499025cc07a28415c46de976f6d6e719",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 53,
                    "column": 19,
                    "event": "warning[-Wanalyzer-use-after-free]",
                    "message": "use after 'free' of 'child'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'scols_line_add_child'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 242,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'scols_line_add_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 244,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 42,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 247,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 248,
                    "column": 9,
                    "event": "note",
                    "message": "(4) calling 'scols_ref_line' from 'scols_line_add_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 60,
                    "column": 6,
                    "event": "note",
                    "message": "(5) entry to 'scols_ref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 62,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'true' branch (when 'ln' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 63,
                    "column": 19,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 248,
                    "column": 9,
                    "event": "note",
                    "message": "(8) returning to 'scols_line_add_child' from 'scols_ref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 249,
                    "column": 9,
                    "event": "note",
                    "message": "(9) calling 'scols_ref_line' from 'scols_line_add_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 60,
                    "column": 6,
                    "event": "note",
                    "message": "(10) entry to 'scols_ref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 62,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'true' branch (when 'ln' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 63,
                    "column": 19,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 249,
                    "column": 9,
                    "event": "note",
                    "message": "(13) returning to 'scols_line_add_child' from 'scols_ref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 252,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 253,
                    "column": 17,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 253,
                    "column": 17,
                    "event": "note",
                    "message": "(16) calling 'scols_line_remove_child' from 'scols_line_add_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 218,
                    "column": 5,
                    "event": "note",
                    "message": "(17) entry to 'scols_line_remove_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 220,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 42,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 223,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 227,
                    "column": 9,
                    "event": "note",
                    "message": "(20) calling 'scols_unref_line' from 'scols_line_remove_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 73,
                    "column": 6,
                    "event": "note",
                    "message": "(21) entry to 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 75,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(24) calling 'scols_unref_line' from 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 73,
                    "column": 6,
                    "event": "note",
                    "message": "(25) entry to 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 81,
                    "column": 17,
                    "event": "note",
                    "message": "(26) calling 'scols_line_free_cells' from 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 94,
                    "column": 6,
                    "event": "note",
                    "message": "(27) entry to 'scols_line_free_cells'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 98,
                    "column": 12,
                    "event": "note",
                    "message": "(28) following 'false' branch (when 'ln' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 98,
                    "column": 23,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 81,
                    "column": 17,
                    "event": "note",
                    "message": "(30) returning to 'scols_unref_line' from 'scols_line_free_cells'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 83,
                    "column": 17,
                    "event": "note",
                    "message": "(31) freed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(32) returning to 'scols_unref_line' from 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 227,
                    "column": 9,
                    "event": "note",
                    "message": "(33) returning to 'scols_line_remove_child' from 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 229,
                    "column": 9,
                    "event": "note",
                    "message": "(34) calling 'scols_unref_line' from 'scols_line_remove_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 73,
                    "column": 6,
                    "event": "note",
                    "message": "(35) entry to 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 75,
                    "column": 12,
                    "event": "note",
                    "message": "(36) following 'true' branch (when 'ln' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 75,
                    "column": 23,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 229,
                    "column": 9,
                    "event": "note",
                    "message": "(38) returning to 'scols_line_remove_child' from 'scols_unref_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 253,
                    "column": 17,
                    "event": "note",
                    "message": "(39) returning to 'scols_line_add_child' from 'scols_line_remove_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/line.c",
                    "line": 256,
                    "column": 9,
                    "event": "note",
                    "message": "(40) inlined call to 'list_add_tail' from 'scols_line_add_child'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(41) inlined call to '__list_add' from 'list_add_tail'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 53,
                    "column": 19,
                    "event": "note",
                    "message": "(42) use after 'free' of 'child'; freed at (31)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   51|   {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   52|   \tnext->prev = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|-> \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|   \tprev->next = add;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b02c8b1eee4d326a8101a2598d7e7ef300960241",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'print_json_data'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 544,
                    "column": 71,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'data'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 1153,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to 'print_tree_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 1166,
                    "column": 14,
                    "event": "note",
                    "message": "(2) calling 'print_line' from 'print_tree_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 874,
                    "column": 12,
                    "event": "note",
                    "message": "(3) entry to 'print_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 14,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 26,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 882,
                    "column": 9,
                    "event": "note",
                    "message": "(4) following 'true' branch (when 'ln' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 42,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 884,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 891,
                    "column": 24,
                    "event": "note",
                    "message": "(6) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 892,
                    "column": 21,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 892,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 895,
                    "column": 78,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 896,
                    "column": 22,
                    "event": "note",
                    "message": "(10) calling '__cursor_to_buffer' from 'print_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 748,
                    "column": 5,
                    "event": "note",
                    "message": "(11) entry to '__cursor_to_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 759,
                    "column": 9,
                    "event": "note",
                    "message": "(12) following 'true' branch (when 'tb' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 761,
                    "column": 9,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 763,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 764,
                    "column": 9,
                    "event": "note",
                    "message": "(16) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 765,
                    "column": 9,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 765,
                    "column": 9,
                    "event": "note",
                    "message": "(18) following 'true' branch (when 'buf' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 766,
                    "column": 18,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 766,
                    "column": 9,
                    "event": "note",
                    "message": "(20) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 768,
                    "column": 9,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 862,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following 'false' branch (when 'cal == 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 42,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 865,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 896,
                    "column": 22,
                    "event": "note",
                    "message": "(24) returning to 'print_line' from '__cursor_to_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 897,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 898,
                    "column": 30,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 898,
                    "column": 30,
                    "event": "note",
                    "message": "(27) calling 'print_data' from 'print_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 586,
                    "column": 12,
                    "event": "note",
                    "message": "(28) entry to 'print_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 596,
                    "column": 9,
                    "event": "note",
                    "message": "(29) following 'true' branch (when 'tb' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 598,
                    "column": 9,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 599,
                    "column": 9,
                    "event": "note",
                    "message": "(31) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 601,
                    "column": 15,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 601,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 611,
                    "column": 19,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 618,
                    "column": 9,
                    "event": "note",
                    "message": "(35) following 'case 3:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 633,
                    "column": 9,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 634,
                    "column": 17,
                    "event": "note",
                    "message": "(37) calling 'print_json_data' from 'print_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 526,
                    "column": 13,
                    "event": "note",
                    "message": "(38) entry to 'print_json_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 531,
                    "column": 9,
                    "event": "note",
                    "message": "(39) following 'case 2:, case 5:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 541,
                    "column": 9,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 544,
                    "column": 20,
                    "event": "note",
                    "message": "(41) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 544,
                    "column": 71,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 544,
                    "column": 71,
                    "event": "note",
                    "message": "(43) 'data' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 544,
                    "column": 71,
                    "event": "note",
                    "message": "(44) dereference of NULL 'data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  542|   \tcase SCOLS_JSON_BOOLEAN_OPTIONAL:",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  543|   \t\t/* name: true|false|null */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  544|-> \t\tif (cl->json_type == SCOLS_JSON_BOOLEAN_OPTIONAL && (!*data || !strcmp(data, \"-\"))) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  545|   \t\t\tul_jsonwrt_value_null(&tb->json, name);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  546|   \t\t} else {",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "2416e9d1fbfa03560eefccba04ac2f3e52c9a371",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 548,
                    "column": 42,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'data'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 1153,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to 'print_tree_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 1166,
                    "column": 14,
                    "event": "note",
                    "message": "(2) calling 'print_line' from 'print_tree_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 874,
                    "column": 12,
                    "event": "note",
                    "message": "(3) entry to 'print_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 882,
                    "column": 9,
                    "event": "note",
                    "message": "(4) following 'true' branch (when 'ln' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 42,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 884,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 891,
                    "column": 24,
                    "event": "note",
                    "message": "(6) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 892,
                    "column": 21,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 892,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 895,
                    "column": 78,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 896,
                    "column": 22,
                    "event": "note",
                    "message": "(10) calling '__cursor_to_buffer' from 'print_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 748,
                    "column": 5,
                    "event": "note",
                    "message": "(11) entry to '__cursor_to_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 759,
                    "column": 9,
                    "event": "note",
                    "message": "(12) following 'true' branch (when 'tb' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 761,
                    "column": 9,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 763,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 764,
                    "column": 9,
                    "event": "note",
                    "message": "(16) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 765,
                    "column": 9,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 765,
                    "column": 9,
                    "event": "note",
                    "message": "(18) following 'true' branch (when 'buf' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 766,
                    "column": 18,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 766,
                    "column": 9,
                    "event": "note",
                    "message": "(20) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 768,
                    "column": 9,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 862,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following 'false' branch (when 'cal == 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 42,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 865,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 896,
                    "column": 22,
                    "event": "note",
                    "message": "(24) returning to 'print_line' from '__cursor_to_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 897,
                    "column": 20,
                    "event": "note",
                    "message": "(25) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 898,
                    "column": 30,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 898,
                    "column": 30,
                    "event": "note",
                    "message": "(27) calling 'print_data' from 'print_line'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 586,
                    "column": 12,
                    "event": "note",
                    "message": "(28) entry to 'print_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 596,
                    "column": 9,
                    "event": "note",
                    "message": "(29) following 'true' branch (when 'tb' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 598,
                    "column": 9,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 599,
                    "column": 9,
                    "event": "note",
                    "message": "(31) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 601,
                    "column": 15,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 601,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 611,
                    "column": 19,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 618,
                    "column": 9,
                    "event": "note",
                    "message": "(35) following 'case 3:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 633,
                    "column": 9,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 634,
                    "column": 17,
                    "event": "note",
                    "message": "(37) calling 'print_json_data' from 'print_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 526,
                    "column": 13,
                    "event": "note",
                    "message": "(38) entry to 'print_json_data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 531,
                    "column": 9,
                    "event": "note",
                    "message": "(39) following 'case 2:, case 5:' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 541,
                    "column": 9,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 544,
                    "column": 20,
                    "event": "note",
                    "message": "(41) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 548,
                    "column": 42,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 548,
                    "column": 42,
                    "event": "note",
                    "message": "(43) 'data' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/print.c",
                    "line": 548,
                    "column": 42,
                    "event": "note",
                    "message": "(44) dereference of NULL 'data'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  546|   \t\t} else {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  547|   \t\t\tul_jsonwrt_value_boolean(&tb->json, name,",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  548|-> \t\t\t\t\t!*data ? 0 :",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  549|   \t\t\t\t\t*data == '0' ? 0 :",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  550|   \t\t\t\t\t*data == 'N' || *data == 'n' ? 0 : 1);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "31f79e8aa5c91ce6c4e73a094036b320a1da0d37",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yyparse'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 393,
                    "column": 21,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'yyptr'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 95,
                    "column": 40,
                    "event": "note",
                    "message": "in definition of macro 'YY_CAST'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 379,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro 'YYMALLOC'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1285,
                    "column": 20,
                    "event": "note",
                    "message": "in expansion of macro 'YYSTACK_ALLOC'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1246,
                    "column": 6,
                    "event": "note",
                    "message": "(1) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1310,
                    "column": 6,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1310,
                    "column": 6,
                    "event": "note",
                    "message": "(3) following 'false' branch (when 'yystate != 15')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1313,
                    "column": 3,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1325,
                    "column": 6,
                    "event": "note",
                    "message": "(5) following 'false' branch (when 'yyn != -8')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1331,
                    "column": 6,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1331,
                    "column": 6,
                    "event": "note",
                    "message": "(7) following 'true' branch (when 'yychar == -2')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1334,
                    "column": 16,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1343,
                    "column": 11,
                    "event": "note",
                    "message": "(9) following 'false' branch (when 'yychar != 256')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 488,
                    "column": 15,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1355,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro 'YYTRANSLATE'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1362,
                    "column": 6,
                    "event": "note",
                    "message": "(11) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1364,
                    "column": 16,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1365,
                    "column": 6,
                    "event": "note",
                    "message": "(13) following 'false' branch (when 'yyn > 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1375,
                    "column": 6,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1375,
                    "column": 6,
                    "event": "note",
                    "message": "(15) following 'false' branch (when 'yyerrstatus == 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1382,
                    "column": 12,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1246,
                    "column": 6,
                    "event": "note",
                    "message": "(17) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1310,
                    "column": 6,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1310,
                    "column": 6,
                    "event": "note",
                    "message": "(19) following 'false' branch (when 'yystate != 15')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1313,
                    "column": 3,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1325,
                    "column": 6,
                    "event": "note",
                    "message": "(21) following 'false' branch (when 'yyn != -8')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1331,
                    "column": 6,
                    "event": "note",
                    "message": "(22) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1331,
                    "column": 6,
                    "event": "note",
                    "message": "(23) following 'true' branch (when 'yychar == -2')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1334,
                    "column": 16,
                    "event": "note",
                    "message": "(24) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1337,
                    "column": 6,
                    "event": "note",
                    "message": "(25) following 'false' branch (when 'yychar > 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1343,
                    "column": 11,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1343,
                    "column": 11,
                    "event": "note",
                    "message": "(27) following 'true' branch (when 'yychar == 256')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1351,
                    "column": 7,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1698,
                    "column": 10,
                    "event": "note",
                    "message": "(29) following 'true' branch (when 'yyn != -8')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1700,
                    "column": 15,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1701,
                    "column": 14,
                    "event": "note",
                    "message": "(31) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1703,
                    "column": 28,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1704,
                    "column": 18,
                    "event": "note",
                    "message": "(33) following 'true' branch (when 'yyn > 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1722,
                    "column": 12,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1275,
                    "column": 10,
                    "event": "note",
                    "message": "(35) following 'false' branch (when 'yystacksize <= 9999')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1277,
                    "column": 19,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 393,
                    "column": 21,
                    "event": "note",
                    "message": "(37) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 95,
                    "column": 40,
                    "event": "note",
                    "message": "in definition of macro 'YY_CAST'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 379,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro 'YYMALLOC'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1285,
                    "column": 20,
                    "event": "note",
                    "message": "in expansion of macro 'YYSTACK_ALLOC'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1286,
                    "column": 12,
                    "event": "note",
                    "message": "(38) assuming 'yyptr' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1286,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following 'false' branch (when 'yyptr' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 453,
                    "column": 7,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 438,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYCOPY'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1288,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYSTACK_RELOCATE'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1291,
                    "column": 12,
                    "event": "note",
                    "message": "(41) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1296,
                    "column": 13,
                    "event": "note",
                    "message": "(42) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1304,
                    "column": 10,
                    "event": "note",
                    "message": "(43) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1310,
                    "column": 6,
                    "event": "note",
                    "message": "(44) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1310,
                    "column": 6,
                    "event": "note",
                    "message": "(45) following 'false' branch (when 'yystate != 15')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1313,
                    "column": 3,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1325,
                    "column": 6,
                    "event": "note",
                    "message": "(47) following 'false' branch (when 'yyn != -8')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1331,
                    "column": 6,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1362,
                    "column": 6,
                    "event": "note",
                    "message": "(49) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1364,
                    "column": 16,
                    "event": "note",
                    "message": "(50) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1365,
                    "column": 6,
                    "event": "note",
                    "message": "(51) following 'false' branch (when 'yyn > 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1375,
                    "column": 6,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1246,
                    "column": 6,
                    "event": "note",
                    "message": "(53) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1252,
                    "column": 34,
                    "event": "note",
                    "message": "(54) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1275,
                    "column": 10,
                    "event": "note",
                    "message": "(55) following 'false' branch (when 'yystacksize <= 9999')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1277,
                    "column": 19,
                    "event": "note",
                    "message": "(56) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 393,
                    "column": 21,
                    "event": "note",
                    "message": "(57) 'yyptr' leaks here; was allocated at (37)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 95,
                    "column": 40,
                    "event": "note",
                    "message": "in definition of macro 'YY_CAST'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 379,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro 'YYMALLOC'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1285,
                    "column": 20,
                    "event": "note",
                    "message": "in expansion of macro 'YYSTACK_ALLOC'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  391|   #  endif",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  392|   #  ifndef YYMALLOC",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  393|-> #   define YYMALLOC malloc",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  394|   #   if ! defined malloc && ! defined EXIT_SUCCESS",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  395|   void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "a856335de3e8f99a041714e39f31194c0e8b17e2",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 453,
                    "column": 7,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value 'yyss'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 438,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYCOPY'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1288,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYSTACK_RELOCATE'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1190,
                    "column": 16,
                    "event": "note",
                    "message": "(1) region created on stack here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1190,
                    "column": 16,
                    "event": "note",
                    "message": "(2) capacity: 200 bytes",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1246,
                    "column": 6,
                    "event": "note",
                    "message": "(3) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1252,
                    "column": 34,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1275,
                    "column": 10,
                    "event": "note",
                    "message": "(5) following 'false' branch (when 'yystacksize <= 9999')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1277,
                    "column": 19,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1286,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following 'false' branch (when 'yyptr' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 453,
                    "column": 7,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 438,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYCOPY'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1288,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYSTACK_RELOCATE'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 453,
                    "column": 7,
                    "event": "note",
                    "message": "(9) use of uninitialized value 'yyss' here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 438,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYCOPY'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-parser.c",
                    "line": 1288,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'YYSTACK_RELOCATE'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  451|   #  if defined __GNUC__ && 1 < __GNUC__",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  452|   #   define YYCOPY(Dst, Src, Count) \\",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  453|->       __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  454|   #  else",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  455|   #   define YYCOPY(Dst, Src, Count)              \\",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "6a8d19116f0bab6c645b548791f262e9f555d4df",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yy_create_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1484,
                    "column": 12,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'yyalloc(64, yyscanner)'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1470,
                    "column": 21,
                    "event": "note",
                    "message": "(1) entry to 'yy_create_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1474,
                    "column": 24,
                    "event": "note",
                    "message": "(2) calling 'yyalloc' from 'yy_create_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 2095,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to 'yyalloc'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 2099,
                    "column": 16,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1474,
                    "column": 24,
                    "event": "note",
                    "message": "(5) returning to 'yy_create_buffer' from 'yyalloc'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1475,
                    "column": 12,
                    "event": "note",
                    "message": "(6) assuming 'yyalloc(64, yyscanner)' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1475,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1478,
                    "column": 17,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1484,
                    "column": 12,
                    "event": "note",
                    "message": "(9) 'yyalloc(64, yyscanner)' leaks here; was allocated at (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1482|   \t * we need to put in 2 end-of-buffer characters.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1483|   \t */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1484|-> \tb->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1485|   \tif ( ! b->yy_ch_buf )",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1486|   \t\tYY_FATAL_ERROR( \"out of dynamic memory in yy_create_buffer()\" );",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yy_init_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1526,
                    "column": 19,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'b'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1405,
                    "column": 10,
                    "event": "note",
                    "message": "(1) entry to 'yyrestart'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1410,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling 'yyensure_buffer_stack' from 'yyrestart'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1628,
                    "column": 13,
                    "event": "note",
                    "message": "(3) entry to 'yyensure_buffer_stack'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1633,
                    "column": 5,
                    "event": "note",
                    "message": "(4) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1653,
                    "column": 9,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1410,
                    "column": 16,
                    "event": "note",
                    "message": "(6) returning to 'yyrestart' from 'yyensure_buffer_stack'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1412,
                    "column": 27,
                    "event": "note",
                    "message": "(7) calling 'yy_create_buffer' from 'yyrestart'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1470,
                    "column": 21,
                    "event": "note",
                    "message": "(8) entry to 'yy_create_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1475,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1478,
                    "column": 17,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1484,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1487,
                    "column": 22,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1489,
                    "column": 2,
                    "event": "note",
                    "message": "(13) calling 'yy_init_buffer' from 'yy_create_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1518,
                    "column": 17,
                    "event": "note",
                    "message": "(14) entry to 'yy_init_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1524,
                    "column": 2,
                    "event": "note",
                    "message": "(15) calling 'yy_flush_buffer' from 'yy_init_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1547,
                    "column": 10,
                    "event": "note",
                    "message": "(16) entry to 'yy_flush_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1550,
                    "column": 5,
                    "event": "note",
                    "message": "(17) following 'false' branch (when 'b' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1553,
                    "column": 16,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1524,
                    "column": 2,
                    "event": "note",
                    "message": "(19) returning to 'yy_init_buffer' from 'yy_flush_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1489,
                    "column": 2,
                    "event": "note",
                    "message": "(20) returning to 'yy_create_buffer' from 'yy_init_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1412,
                    "column": 27,
                    "event": "note",
                    "message": "(21) returning to 'yyrestart' from 'yy_create_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1415,
                    "column": 2,
                    "event": "note",
                    "message": "(22) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1415,
                    "column": 2,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1415,
                    "column": 2,
                    "event": "note",
                    "message": "(24) calling 'yy_init_buffer' from 'yyrestart'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1518,
                    "column": 17,
                    "event": "note",
                    "message": "(25) entry to 'yy_init_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1524,
                    "column": 2,
                    "event": "note",
                    "message": "(26) calling 'yy_flush_buffer' from 'yy_init_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1547,
                    "column": 10,
                    "event": "note",
                    "message": "(27) entry to 'yy_flush_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1550,
                    "column": 5,
                    "event": "note",
                    "message": "(28) following 'true' branch (when 'b' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1524,
                    "column": 2,
                    "event": "note",
                    "message": "(30) returning to 'yy_init_buffer' from 'yy_flush_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1526,
                    "column": 19,
                    "event": "note",
                    "message": "(31) dereference of NULL 'b'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1524|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1525|   \tyy_flush_buffer( b , yyscanner);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1526|-> ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1527|   \tb->yy_input_file = file;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1528|   \tb->yy_fill_buffer = 1;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yy_scan_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1744,
                    "column": 38,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'yyalloc(n,  yyscanner)'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1728,
                    "column": 17,
                    "event": "note",
                    "message": "(1) entry to 'yy_scan_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1737,
                    "column": 24,
                    "event": "note",
                    "message": "(2) calling 'yyalloc' from 'yy_scan_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 2095,
                    "column": 7,
                    "event": "note",
                    "message": "(3) entry to 'yyalloc'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 2099,
                    "column": 16,
                    "event": "note",
                    "message": "(4) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1737,
                    "column": 24,
                    "event": "note",
                    "message": "(5) returning to 'yy_scan_bytes' from 'yyalloc'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1738,
                    "column": 12,
                    "event": "note",
                    "message": "(6) assuming 'yyalloc(n,  yyscanner)' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1738,
                    "column": 12,
                    "event": "note",
                    "message": "(7) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1746,
                    "column": 6,
                    "event": "note",
                    "message": "(9) calling 'yy_scan_buffer' from 'yy_scan_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1678,
                    "column": 17,
                    "event": "note",
                    "message": "(10) entry to 'yy_scan_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1744,
                    "column": 38,
                    "event": "note",
                    "message": "(11) 'yyalloc(n,  yyscanner)' leaks here; was allocated at (4)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1742|   \tfor ( i = 0; i < _yybytes_len; ++i )",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1743|   \t\tbuf[i] = yybytes[i];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1744|-> ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1745|   \tbuf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1746|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "5d41177051179b2c2b68edd82d28e190391278e3",
            "key_event_idx": 3,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 15,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 1,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'merge_and_restore_back_links'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 311,
                    "column": 34,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'list'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 413,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to '__scols_calculate'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 462,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 468,
                    "column": 27,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 496,
                    "column": 22,
                    "event": "note",
                    "message": "(4) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 500,
                    "column": 20,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 500,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following 'true' branch (when 'sorted == 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/smartcolsP.h",
                    "line": 42,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 501,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 502,
                    "column": 25,
                    "event": "note",
                    "message": "(8) inlined call to 'sort_columns' from '__scols_calculate'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/calculate.c",
                    "line": 261,
                    "column": 9,
                    "event": "note",
                    "message": "(9) calling 'list_sort' from '__scols_calculate'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'merge_and_restore_back_links'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 333,
                    "column": 15,
                    "event": "note",
                    "message": "(10) entry to 'list_sort'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 345,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 348,
                    "column": 9,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 375,
                    "column": 9,
                    "event": "note",
                    "message": "(13) calling 'merge_and_restore_back_links' from 'list_sort'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 278,
                    "column": 15,
                    "event": "note",
                    "message": "(14) entry to 'merge_and_restore_back_links'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 287,
                    "column": 18,
                    "event": "note",
                    "message": "(15) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 300,
                    "column": 28,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 300,
                    "column": 28,
                    "event": "note",
                    "message": "(17) following 'false' branch (when 'a' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 300,
                    "column": 20,
                    "event": "note",
                    "message": "(19) 'list' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 309,
                    "column": 18,
                    "event": "note",
                    "message": "(20) 'list' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 311,
                    "column": 21,
                    "event": "note",
                    "message": "(21) 'list' is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 311,
                    "column": 34,
                    "event": "note",
                    "message": "(22) dereference of NULL '*tail.next'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  309|   \t\t(*cmp)(tail->next, tail->next, data);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  310|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  311|-> \t\ttail->next->prev = tail;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  312|   \t\ttail = tail->next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  313|   \t} while (tail->next);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "268d25f0d413d8195bce96407ca9a11d5a3f6735",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yy_create_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1484,
                    "column": 12,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'malloc(64)'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1470,
                    "column": 21,
                    "event": "note",
                    "message": "(1) entry to 'yy_create_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1474,
                    "column": 24,
                    "event": "note",
                    "message": "(2) inlined call to 'yyalloc' from 'yy_create_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 2099,
                    "column": 16,
                    "event": "note",
                    "message": "(3) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yy_create_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1475,
                    "column": 12,
                    "event": "note",
                    "message": "(4) assuming 'malloc(64)' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1475,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1478,
                    "column": 17,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1484,
                    "column": 12,
                    "event": "note",
                    "message": "(7) 'malloc(64)' leaks here; was allocated at (3)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1482|   \t * we need to put in 2 end-of-buffer characters.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1483|   \t */",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1484|-> \tb->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1485|   \tif ( ! b->yy_ch_buf )",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1486|   \t\tYY_FATAL_ERROR( \"out of dynamic memory in yy_create_buffer()\" );",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yy_scan_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1744,
                    "column": 38,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'malloc(n)'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1728,
                    "column": 17,
                    "event": "note",
                    "message": "(1) entry to 'yy_scan_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1737,
                    "column": 24,
                    "event": "note",
                    "message": "(2) inlined call to 'yyalloc' from 'yy_scan_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 2099,
                    "column": 16,
                    "event": "note",
                    "message": "(3) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'yy_scan_buffer'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1738,
                    "column": 12,
                    "event": "note",
                    "message": "(4) assuming 'malloc(n)' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1738,
                    "column": 12,
                    "event": "note",
                    "message": "(5) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1746,
                    "column": 6,
                    "event": "note",
                    "message": "(7) calling 'yy_scan_buffer' from 'yy_scan_bytes'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1678,
                    "column": 17,
                    "event": "note",
                    "message": "(8) entry to 'yy_scan_buffer'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libsmartcols/src/filter-scanner.c",
                    "line": 1744,
                    "column": 38,
                    "event": "note",
                    "message": "(9) 'malloc(n)' leaks here; was allocated at (3)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1742|   \tfor ( i = 0; i < _yybytes_len; ++i )",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1743|   \t\tbuf[i] = yybytes[i];",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1744|-> ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1745|   \tbuf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1746|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "7a503438b1cdbbdf1e7168fbfc06742495db5fe9",
            "key_event_idx": 3,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk.h",
                    "line": 18,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-devtree.c",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-devtree.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘cmp_devices_devno’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-devtree.c",
                    "line": 536,
                    "column": 47,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘a’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 231,
                    "column": 29,
                    "event": "note",
                    "message": "in definition of macro ‘cmp_numbers’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-devtree.c",
                    "line": 541,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘lsblk_devtree_deduplicate_devices’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-devtree.c",
                    "line": 547,
                    "column": 9,
                    "event": "note",
                    "message": "(2) calling ‘list_sort’ from ‘lsblk_devtree_deduplicate_devices’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 333,
                    "column": 15,
                    "event": "note",
                    "message": "(3) entry to ‘list_sort’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 345,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 348,
                    "column": 9,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 350,
                    "column": 26,
                    "event": "note",
                    "message": "(6) ‘0’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 353,
                    "column": 16,
                    "event": "note",
                    "message": "(7) following ‘false’ branch (when ‘list’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 371,
                    "column": 27,
                    "event": "note",
                    "message": "(9) following ‘false’ branch (when ‘lev >= max_lev’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 375,
                    "column": 9,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 375,
                    "column": 9,
                    "event": "note",
                    "message": "(11) ‘list’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 375,
                    "column": 9,
                    "event": "note",
                    "message": "(12) calling ‘merge_and_restore_back_links’ from ‘list_sort’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 278,
                    "column": 15,
                    "event": "note",
                    "message": "(13) entry to ‘merge_and_restore_back_links’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 287,
                    "column": 18,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 300,
                    "column": 28,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 300,
                    "column": 28,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘a’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 300,
                    "column": 20,
                    "event": "note",
                    "message": "(18) ‘list’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 309,
                    "column": 18,
                    "event": "note",
                    "message": "(19) ‘list’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 309,
                    "column": 18,
                    "event": "note",
                    "message": "(20) calling ‘cmp_devices_devno’ from ‘merge_and_restore_back_links’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-devtree.c",
                    "line": 530,
                    "column": 12,
                    "event": "note",
                    "message": "(21) entry to ‘cmp_devices_devno’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-devtree.c",
                    "line": 536,
                    "column": 47,
                    "event": "note",
                    "message": "(22) dereference of NULL ‘a’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 231,
                    "column": 29,
                    "event": "note",
                    "message": "in definition of macro ‘cmp_numbers’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  534|   \t\t\t    *bx = list_entry(b, struct lsblk_device, ls_devices);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  535|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  536|-> \treturn cmp_numbers(makedev(ax->maj, ax->min),",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  537|   \t\t\t   makedev(bx->maj, bx->min));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  538|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "266ce7340cbe185f743ed93d2159be20a3e67d3f",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘lookup.part.0’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 207,
                    "column": 16,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘*prop.label’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 392,
                    "column": 23,
                    "event": "note",
                    "message": "(1) entry to ‘lsblk_device_get_properties’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 398,
                    "column": 23,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘i != 4’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 401,
                    "column": 30,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 401,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 3:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 410,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 411,
                    "column": 28,
                    "event": "note",
                    "message": "(6) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 412,
                    "column": 40,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 412,
                    "column": 40,
                    "event": "note",
                    "message": "(8) calling ‘get_properties_by_file’ from ‘lsblk_device_get_properties’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 212,
                    "column": 30,
                    "event": "note",
                    "message": "(9) entry to ‘get_properties_by_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 8,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 220,
                    "column": 9,
                    "event": "note",
                    "message": "(10) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 222,
                    "column": 13,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 222,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk.h",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 16,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk.h",
                    "line": 30,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro ‘__UL_DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 225,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘DBG’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 233,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 235,
                    "column": 41,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 235,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 237,
                    "column": 40,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 237,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 240,
                    "column": 39,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 241,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 244,
                    "column": 14,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 245,
                    "column": 12,
                    "event": "note",
                    "message": "(22) following ‘false’ branch (when ‘prop’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 248,
                    "column": 44,
                    "event": "note",
                    "message": "(24) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 250,
                    "column": 21,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 250,
                    "column": 21,
                    "event": "note",
                    "message": "(26) inlined call to ‘lookup’ from ‘get_properties_by_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 189,
                    "column": 18,
                    "event": "note",
                    "message": "(27) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(28) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 250,
                    "column": 21,
                    "event": "note",
                    "message": "(29) inlined call to ‘lookup’ from ‘get_properties_by_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(30) calling ‘lookup’ from ‘get_properties_by_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘lookup.part.0’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 183,
                    "column": 12,
                    "event": "note",
                    "message": "(31) entry to ‘lookup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 193,
                    "column": 12,
                    "event": "note",
                    "message": "(32) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 196,
                    "column": 11,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 197,
                    "column": 12,
                    "event": "note",
                    "message": "(34) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 199,
                    "column": 10,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 200,
                    "column": 12,
                    "event": "note",
                    "message": "(36) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 207,
                    "column": 18,
                    "event": "note",
                    "message": "(38) calling ‘xstrdup’ from ‘lookup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 10,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(39) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(40) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(42) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(43) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 207,
                    "column": 18,
                    "event": "note",
                    "message": "(46) returning to ‘lookup’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/lsblk-properties.c",
                    "line": 207,
                    "column": 16,
                    "event": "note",
                    "message": "(47) ‘*prop.label’ leaks here; was allocated at (42)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  205|   \t\t*p = '\\0';",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  206|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  207|-> \t*value = xstrdup(v);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  208|   \treturn 1;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  209|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ff44032afd5bb9627bcdf9a08ea770039e8d0c03",
            "key_event_idx": 2,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 67,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_arguments’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 24)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 629,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 642,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘parse_arguments’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 352,
                    "column": 15,
                    "event": "note",
                    "message": "(3) entry to ‘parse_arguments’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 359,
                    "column": 32,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘argc > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 360,
                    "column": 21,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 361,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 363,
                    "column": 22,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 363,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 367,
                    "column": 22,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 367,
                    "column": 20,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 370,
                    "column": 22,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 370,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 372,
                    "column": 22,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 372,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 376,
                    "column": 22,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 376,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 380,
                    "column": 22,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 380,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 403,
                    "column": 22,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 403,
                    "column": 20,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 417,
                    "column": 22,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 417,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 421,
                    "column": 22,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 421,
                    "column": 20,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 432,
                    "column": 22,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 432,
                    "column": 20,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 440,
                    "column": 22,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 440,
                    "column": 20,
                    "event": "note",
                    "message": "(28) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 444,
                    "column": 22,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 444,
                    "column": 20,
                    "event": "note",
                    "message": "(30) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 454,
                    "column": 22,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 454,
                    "column": 20,
                    "event": "note",
                    "message": "(32) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 467,
                    "column": 22,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 467,
                    "column": 20,
                    "event": "note",
                    "message": "(34) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 480,
                    "column": 22,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 480,
                    "column": 20,
                    "event": "note",
                    "message": "(36) following ‘true’ branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 483,
                    "column": 38,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 484,
                    "column": 28,
                    "event": "note",
                    "message": "(38) following ‘false’ branch (when ‘argc != 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 487,
                    "column": 29,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 488,
                    "column": 32,
                    "event": "note",
                    "message": "(40) calling ‘xcalloc’ from ‘parse_arguments’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(41) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(42) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(43) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 488,
                    "column": 32,
                    "event": "note",
                    "message": "(46) returning to ‘parse_arguments’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 13,
                    "event": "note",
                    "message": "(47) ‘xcalloc(1, 24)’ leaks here; was allocated at (42)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   66|   \tvoid *ret = calloc(nelems, size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   67|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   68|-> \tif (!ret && size && nelems)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   69|   \t\terr(XALLOC_EXIT_CODE, \"cannot allocate %zu bytes\", size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   70|   \treturn ret;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "3ed302a8d7ace908edcbc7394f21d3e01d5fc255",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xcalloc(1, 24)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_arguments’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 629,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 642,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘parse_arguments’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 352,
                    "column": 15,
                    "event": "note",
                    "message": "(3) entry to ‘parse_arguments’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 359,
                    "column": 32,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘argc > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 360,
                    "column": 21,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 361,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 363,
                    "column": 22,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 363,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 367,
                    "column": 22,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 367,
                    "column": 20,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 370,
                    "column": 22,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 370,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 372,
                    "column": 22,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 372,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 376,
                    "column": 22,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 376,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 380,
                    "column": 22,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 380,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 403,
                    "column": 22,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 403,
                    "column": 20,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 417,
                    "column": 22,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 417,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 421,
                    "column": 22,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 421,
                    "column": 20,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 432,
                    "column": 22,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 432,
                    "column": 20,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 440,
                    "column": 22,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 440,
                    "column": 20,
                    "event": "note",
                    "message": "(28) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 444,
                    "column": 22,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 444,
                    "column": 20,
                    "event": "note",
                    "message": "(30) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 454,
                    "column": 22,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 454,
                    "column": 20,
                    "event": "note",
                    "message": "(32) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 467,
                    "column": 22,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 467,
                    "column": 20,
                    "event": "note",
                    "message": "(34) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 480,
                    "column": 22,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 480,
                    "column": 20,
                    "event": "note",
                    "message": "(36) following ‘true’ branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 483,
                    "column": 38,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 484,
                    "column": 28,
                    "event": "note",
                    "message": "(38) following ‘false’ branch (when ‘argc != 1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 487,
                    "column": 29,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 488,
                    "column": 32,
                    "event": "note",
                    "message": "(40) calling ‘xcalloc’ from ‘parse_arguments’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(41) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(42) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(43) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 488,
                    "column": 32,
                    "event": "note",
                    "message": "(46) returning to ‘parse_arguments’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 493,
                    "column": 28,
                    "event": "note",
                    "message": "(47) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 495,
                    "column": 25,
                    "event": "note",
                    "message": "(48) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 495,
                    "column": 25,
                    "event": "note",
                    "message": "(49) inlined call to ‘list_add_tail’ from ‘parse_arguments’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(50) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(51) ‘xcalloc(1, 24)’ leaks here; was allocated at (42)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f42afc8aa666f3f329cfd3cd782aee9827b2ee22",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_arguments’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 405,
                    "column": 30,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘0’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 629,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 642,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘parse_arguments’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 352,
                    "column": 15,
                    "event": "note",
                    "message": "(3) entry to ‘parse_arguments’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 359,
                    "column": 32,
                    "event": "note",
                    "message": "(4) following ‘true’ branch (when ‘argc > 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 360,
                    "column": 21,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 361,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 363,
                    "column": 22,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 363,
                    "column": 20,
                    "event": "note",
                    "message": "(8) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 367,
                    "column": 22,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 367,
                    "column": 20,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 370,
                    "column": 22,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 370,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 372,
                    "column": 22,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 372,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following ‘false’ branch (when the strings are non-equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 376,
                    "column": 22,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 376,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 380,
                    "column": 22,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 380,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 403,
                    "column": 22,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/ctype.h",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 48,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 404,
                    "column": 35,
                    "event": "note",
                    "message": "(20) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/kill.c",
                    "line": 405,
                    "column": 30,
                    "event": "note",
                    "message": "(21) dereference of NULL ‘strchr(arg, 61)’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  403|   \t\tif (!strncmp(arg, \"--list=\", 7) || !strncmp(arg, \"-l=\", 3)) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  404|   \t\t\tchar *p = strchr(arg, '=') + 1;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  405|-> \t\t\tif (p[0] == '0' && p[1] == 'x') {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  406|   \t\t\t\tuint64_t sigmask;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  407|   \t\t\t\tif (ul_strtou64(p + 2, &sigmask, 16) < 0)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b927c4234882ee6a913b1d1e9fb656376951c550",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘issuefile_read_stream.part.0’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1795,
                    "column": 25,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘*ie.output’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1784,
                    "column": 12,
                    "event": "note",
                    "message": "(1) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1785,
                    "column": 24,
                    "event": "note",
                    "message": "(2) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1788,
                    "column": 30,
                    "event": "note",
                    "message": "(3) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1791,
                    "column": 31,
                    "event": "note",
                    "message": "(4) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1795,
                    "column": 25,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1795,
                    "column": 25,
                    "event": "note",
                    "message": "(8) argument 2 (‘*ie.output’) from (3) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 14,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 616,
                    "column": 12,
                    "event": "note",
                    "message": "argument 2 of ‘putc’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1793|   \t\t\toutput_special_char(ie, fgetc(f), op, tp, f);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1794|   \t\telse",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1795|-> \t\t\tputc(c, ie->output);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1796|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1797|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "36f3af79c5f32030de62408bddcf54c31cc71b4c",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘dump_iface_all’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2735,
                    "column": 25,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘*ie.output’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1774,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1784,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1785,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1788,
                    "column": 30,
                    "event": "note",
                    "message": "(4) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1791,
                    "column": 31,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 49,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 25,
                    "event": "note",
                    "message": "(9) calling ‘output_special_char’ from ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2785,
                    "column": 13,
                    "event": "note",
                    "message": "(10) entry to ‘output_special_char’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2793,
                    "column": 9,
                    "event": "note",
                    "message": "(11) following ‘case 65:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2982,
                    "column": 9,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/netlink.h",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/netaddrq.h",
                    "line": 17,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 51,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(13) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/netaddrq.h",
                    "line": 62,
                    "column": 46,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2987,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each_netaddrq_iface’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2991,
                    "column": 25,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2991,
                    "column": 25,
                    "event": "note",
                    "message": "(15) calling ‘dump_iface_all’ from ‘output_special_char’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2723,
                    "column": 13,
                    "event": "note",
                    "message": "(16) entry to ‘dump_iface_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2733,
                    "column": 20,
                    "event": "note",
                    "message": "(17) following ‘true’ branch (when ‘first != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2735,
                    "column": 25,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2735,
                    "column": 25,
                    "event": "note",
                    "message": "(19) argument 1 (‘*ie.output’) from (4) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘fprintf’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2733|   \t\tif (first)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2734|   \t\t{",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2735|-> \t\t\tfprintf(ie->output, \"%s: \", ifaceq->ifname);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2736|   \t\t\tfirst = false;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2737|   \t\t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "36f3af79c5f32030de62408bddcf54c31cc71b4c",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2747,
                    "column": 25,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘*ie.output’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1774,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1784,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1785,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1788,
                    "column": 30,
                    "event": "note",
                    "message": "(4) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1791,
                    "column": 31,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 49,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 25,
                    "event": "note",
                    "message": "(9) calling ‘output_special_char’ from ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2785,
                    "column": 13,
                    "event": "note",
                    "message": "(10) entry to ‘output_special_char’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2793,
                    "column": 9,
                    "event": "note",
                    "message": "(11) following ‘case 65:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2982,
                    "column": 9,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(13) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/netaddrq.h",
                    "line": 62,
                    "column": 46,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2987,
                    "column": 17,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each_netaddrq_iface’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2991,
                    "column": 25,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2991,
                    "column": 25,
                    "event": "note",
                    "message": "(15) calling ‘dump_iface_all’ from ‘output_special_char’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2723,
                    "column": 13,
                    "event": "note",
                    "message": "(16) entry to ‘dump_iface_all’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2730,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 18,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2742,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2745,
                    "column": 20,
                    "event": "note",
                    "message": "(19) following ‘true’ branch (when ‘first != 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2747,
                    "column": 25,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2747,
                    "column": 25,
                    "event": "note",
                    "message": "(21) argument 1 (‘*ie.output’) from (4) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "argument 1 of ‘fprintf’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2745|   \t\tif (first)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2746|   \t\t{",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2747|-> \t\t\tfprintf(ie->output, \"%s: \", ifaceq->ifname);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2748|   \t\t\tfirst = false;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2749|   \t\t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "754853cc8949441e19131d0c7f63ba230bc2302f",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘output_special_char’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2806,
                    "column": 25,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘*ie.output’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1774,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1784,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1785,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1788,
                    "column": 30,
                    "event": "note",
                    "message": "(4) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1791,
                    "column": 31,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 49,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 25,
                    "event": "note",
                    "message": "(9) calling ‘output_special_char’ from ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2785,
                    "column": 13,
                    "event": "note",
                    "message": "(10) entry to ‘output_special_char’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2793,
                    "column": 9,
                    "event": "note",
                    "message": "(11) following ‘case 101:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2794,
                    "column": 9,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2798,
                    "column": 20,
                    "event": "note",
                    "message": "(13) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2806,
                    "column": 41,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2806,
                    "column": 25,
                    "event": "note",
                    "message": "(15) argument 2 (‘*ie.output’) from (4) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "<built-in>",
                    "line": 0,
                    "event": "note",
                    "message": "argument 2 of ‘__builtin_fputc’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2804|   \t\t\t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2805|   \t\t} else",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2806|-> \t\t\tfputs(\"\\033\", ie->output);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2807|   \t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2808|   \t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "920bdabf5047fa7f3aa9bcf7950f5cd09b7e6448",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2881,
                    "column": 17,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘*ie.output’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1774,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1784,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1785,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1788,
                    "column": 30,
                    "event": "note",
                    "message": "(4) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1791,
                    "column": 31,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 49,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 25,
                    "event": "note",
                    "message": "(9) calling ‘output_special_char’ from ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2785,
                    "column": 13,
                    "event": "note",
                    "message": "(10) entry to ‘output_special_char’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2793,
                    "column": 9,
                    "event": "note",
                    "message": "(11) following ‘case 108:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2880,
                    "column": 9,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2881,
                    "column": 17,
                    "event": "note",
                    "message": "(13) argument 2 (‘*ie.output’) from (4) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "<built-in>",
                    "line": 0,
                    "event": "note",
                    "message": "argument 2 of ‘__builtin_fputs’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2879|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2880|   \tcase 'l':",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2881|-> \t\tfprintf (ie->output, \"%s\", op->tty);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2882|   \t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2883|   \tcase 'b':",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 688,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "b927c4234882ee6a913b1d1e9fb656376951c550",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2997,
                    "column": 17,
                    "event": "warning[-Wanalyzer-possible-null-argument]",
                    "message": "use of possibly-NULL ‘*ie.output’ where non-null expected",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1774,
                    "column": 12,
                    "event": "note",
                    "message": "(1) entry to ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1784,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1785,
                    "column": 24,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1788,
                    "column": 30,
                    "event": "note",
                    "message": "(4) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1791,
                    "column": 31,
                    "event": "note",
                    "message": "(5) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1792,
                    "column": 20,
                    "event": "note",
                    "message": "(7) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 49,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 1793,
                    "column": 25,
                    "event": "note",
                    "message": "(9) calling ‘output_special_char’ from ‘issuefile_read_stream’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2785,
                    "column": 13,
                    "event": "note",
                    "message": "(10) entry to ‘output_special_char’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2793,
                    "column": 9,
                    "event": "note",
                    "message": "(11) following ‘default:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2996,
                    "column": 9,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/term-utils/agetty.c",
                    "line": 2997,
                    "column": 17,
                    "event": "note",
                    "message": "(13) argument 2 (‘*ie.output’) from (4) could be NULL where non-null expected",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 616,
                    "column": 12,
                    "event": "note",
                    "message": "argument 2 of ‘putc’ must be non-null",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2995|   #endif",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2996|   \tdefault:",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2997|-> \t\tputc(c, ie->output);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2998|   \t\tbreak;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2999|   \t}",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "168537ea1434a817926205417414db679e1290fd",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘new_counter_spec(optarg)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2561,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2615,
                    "column": 86,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 67:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2661,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2662,
                    "column": 50,
                    "event": "note",
                    "message": "(6) calling ‘new_counter_spec’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2323,
                    "column": 29,
                    "event": "note",
                    "message": "(7) entry to ‘new_counter_spec’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2328,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2332,
                    "column": 12,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2332,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/bits/libc-header-start.h",
                    "line": 33,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/stdio.h",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 25,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2337,
                    "column": 15,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2337,
                    "column": 15,
                    "event": "note",
                    "message": "(12) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2338,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following ‘false’ branch (when ‘sep’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2342,
                    "column": 16,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2342,
                    "column": 12,
                    "event": "note",
                    "message": "(15) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2348,
                    "column": 14,
                    "event": "note",
                    "message": "(16) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2350,
                    "column": 13,
                    "event": "note",
                    "message": "(17) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2350,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2355,
                    "column": 16,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2355,
                    "column": 16,
                    "event": "note",
                    "message": "(20) calling ‘xmalloc’ from ‘new_counter_spec’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 41,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 59,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(21) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(22) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(23) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2355,
                    "column": 16,
                    "event": "note",
                    "message": "(26) returning to ‘new_counter_spec’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2662,
                    "column": 50,
                    "event": "note",
                    "message": "(27) returning to ‘main’ from ‘new_counter_spec’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2663,
                    "column": 25,
                    "event": "note",
                    "message": "(28) inlined call to ‘list_add_tail’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(29) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(30) ‘new_counter_spec(optarg)’ leaks here; was allocated at (22)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "695812fb052cc2e6364dd9685daf6d5488400e0d",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘new_nodev(minor,  filesystem)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_nodev’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1989,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘new_proc’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 835,
                    "column": 21,
                    "event": "note",
                    "message": "(3) entry to ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(8) returning to ‘new_proc’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 38,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘leader’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(11) returning to ‘read_process’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(12) calling ‘xstrdup’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 48,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(18) returning to ‘read_process’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2003,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2021,
                    "column": 13,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘collect_execve_file’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1088,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(23) calling ‘collect_outofbox_files’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(24) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(28) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(29) calling ‘new_readlink_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 760,
                    "column": 21,
                    "event": "note",
                    "message": "(30) entry to ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(31) calling ‘xcalloc’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(32) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(35) returning to ‘new_readlink_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(36) returning to ‘collect_file_symlink’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(37) calling ‘file_init_content’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 816,
                    "column": 13,
                    "event": "note",
                    "message": "(38) entry to ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 818,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 819,
                    "column": 17,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(41) returning to ‘collect_file_symlink’ from ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 923,
                    "column": 12,
                    "event": "note",
                    "message": "(42) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 228,
                    "column": 38,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 13,
                    "event": "note",
                    "message": "in expansion of macro ‘is_association’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 51,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(46) calling ‘find_mnt_ns’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1258,
                    "column": 30,
                    "event": "note",
                    "message": "(47) entry to ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1263,
                    "column": 12,
                    "event": "note",
                    "message": "(48) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1264,
                    "column": 24,
                    "event": "note",
                    "message": "(49) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(50) returning to ‘collect_file_symlink’ from ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 928,
                    "column": 20,
                    "event": "note",
                    "message": "(51) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(53) returning to ‘collect_outofbox_files’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(54) following ‘false’ branch (when ‘i >= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1086,
                    "column": 1,
                    "event": "note",
                    "message": "(55) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(56) returning to ‘collect_execve_file’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(57) returning to ‘read_process’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2028,
                    "column": 12,
                    "event": "note",
                    "message": "(58) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 47,
                    "event": "note",
                    "message": "(59) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 17,
                    "event": "note",
                    "message": "(60) calling ‘collect_fs_files’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1099,
                    "column": 13,
                    "event": "note",
                    "message": "(61) entry to ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1107,
                    "column": 9,
                    "event": "note",
                    "message": "(62) calling ‘collect_outofbox_files’ from ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(63) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(64) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(66) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(67) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(68) calling ‘new_readlink_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 760,
                    "column": 21,
                    "event": "note",
                    "message": "(69) entry to ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(70) calling ‘xcalloc’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(71) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(72) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(73) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(74) returning to ‘new_readlink_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(75) returning to ‘collect_file_symlink’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(76) calling ‘file_init_content’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 816,
                    "column": 13,
                    "event": "note",
                    "message": "(77) entry to ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 818,
                    "column": 12,
                    "event": "note",
                    "message": "(78) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 819,
                    "column": 17,
                    "event": "note",
                    "message": "(79) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(80) returning to ‘collect_file_symlink’ from ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 923,
                    "column": 12,
                    "event": "note",
                    "message": "(81) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 228,
                    "column": 38,
                    "event": "note",
                    "message": "(82) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 13,
                    "event": "note",
                    "message": "in expansion of macro ‘is_association’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 12,
                    "event": "note",
                    "message": "(83) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 51,
                    "event": "note",
                    "message": "(84) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(85) calling ‘find_mnt_ns’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1258,
                    "column": 30,
                    "event": "note",
                    "message": "(86) entry to ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1263,
                    "column": 12,
                    "event": "note",
                    "message": "(87) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1264,
                    "column": 24,
                    "event": "note",
                    "message": "(88) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(89) returning to ‘collect_file_symlink’ from ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 928,
                    "column": 20,
                    "event": "note",
                    "message": "(90) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(91) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(92) returning to ‘collect_outofbox_files’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(93) following ‘false’ branch (when ‘i >= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1086,
                    "column": 1,
                    "event": "note",
                    "message": "(94) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1107,
                    "column": 9,
                    "event": "note",
                    "message": "(95) returning to ‘collect_fs_files’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 17,
                    "event": "note",
                    "message": "(96) returning to ‘read_process’ from ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2050,
                    "column": 12,
                    "event": "note",
                    "message": "(97) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2056,
                    "column": 17,
                    "event": "note",
                    "message": "(98) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2058,
                    "column": 20,
                    "event": "note",
                    "message": "(99) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2060,
                    "column": 33,
                    "event": "note",
                    "message": "(100) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2062,
                    "column": 25,
                    "event": "note",
                    "message": "(101) calling ‘read_mountinfo_in_mntns’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1413,
                    "column": 13,
                    "event": "note",
                    "message": "(102) entry to ‘read_mountinfo_in_mntns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1416,
                    "column": 12,
                    "event": "note",
                    "message": "(103) following ‘false’ branch (when ‘mntns_fd < 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(104) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1421,
                    "column": 9,
                    "event": "note",
                    "message": "(105) calling ‘read_mountinfo’ from ‘read_mountinfo_in_mntns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1374,
                    "column": 13,
                    "event": "note",
                    "message": "(106) entry to ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1380,
                    "column": 16,
                    "event": "note",
                    "message": "(107) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1386,
                    "column": 20,
                    "event": "note",
                    "message": "(108) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1386,
                    "column": 19,
                    "event": "note",
                    "message": "(109) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1393,
                    "column": 20,
                    "event": "note",
                    "message": "(110) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1393,
                    "column": 19,
                    "event": "note",
                    "message": "(111) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1402,
                    "column": 21,
                    "event": "note",
                    "message": "(112) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1403,
                    "column": 17,
                    "event": "note",
                    "message": "(113) calling ‘process_mountinfo_entry’ from ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1355,
                    "column": 13,
                    "event": "note",
                    "message": "(114) entry to ‘process_mountinfo_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1368,
                    "column": 12,
                    "event": "note",
                    "message": "(115) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1371,
                    "column": 9,
                    "event": "note",
                    "message": "(116) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1371,
                    "column": 9,
                    "event": "note",
                    "message": "(117) calling ‘add_nodev’ from ‘process_mountinfo_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1295,
                    "column": 6,
                    "event": "note",
                    "message": "(118) entry to ‘add_nodev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1297,
                    "column": 31,
                    "event": "note",
                    "message": "(119) calling ‘new_nodev’ from ‘add_nodev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1278,
                    "column": 22,
                    "event": "note",
                    "message": "(120) entry to ‘new_nodev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1280,
                    "column": 31,
                    "event": "note",
                    "message": "(121) calling ‘xcalloc’ from ‘new_nodev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(122) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(123) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(124) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(125) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(126) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1280,
                    "column": 31,
                    "event": "note",
                    "message": "(127) returning to ‘new_nodev’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1284,
                    "column": 29,
                    "event": "note",
                    "message": "(128) calling ‘xstrdup’ from ‘new_nodev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(129) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(130) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(131) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(132) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(133) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1284,
                    "column": 29,
                    "event": "note",
                    "message": "(134) returning to ‘new_nodev’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1297,
                    "column": 31,
                    "event": "note",
                    "message": "(135) returning to ‘add_nodev’ from ‘new_nodev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1300,
                    "column": 9,
                    "event": "note",
                    "message": "(136) inlined call to ‘list_add_tail’ from ‘add_nodev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(137) inlined call to ‘__list_add’ from ‘list_add_tail’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(138) ‘new_nodev(minor,  filesystem)’ leaks here; was allocated at (123)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "25f816d06fb9378dff084d51e42009e5b6251e48",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘new_file’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 746,
                    "column": 21,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xcalloc(1, *class.size)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1989,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘new_proc’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 835,
                    "column": 21,
                    "event": "note",
                    "message": "(3) entry to ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(8) returning to ‘new_proc’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 38,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘leader’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(11) returning to ‘read_process’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(12) calling ‘xstrdup’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(18) returning to ‘read_process’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2003,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2021,
                    "column": 13,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘collect_execve_file’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1088,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(23) calling ‘collect_outofbox_files’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(24) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(28) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 894,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 182,
                    "column": 26,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 900,
                    "column": 26,
                    "event": "note",
                    "message": "in expansion of macro ‘list_last_entry’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 905,
                    "column": 19,
                    "event": "note",
                    "message": "(31) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 908,
                    "column": 50,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 908,
                    "column": 50,
                    "event": "note",
                    "message": "(33) calling ‘stat2class’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 699,
                    "column": 33,
                    "event": "note",
                    "message": "(34) entry to ‘stat2class’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 703,
                    "column": 9,
                    "event": "note",
                    "message": "(35) following ‘true’ branch (when ‘sb’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 705,
                    "column": 19,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 908,
                    "column": 50,
                    "event": "note",
                    "message": "(37) returning to ‘collect_file_symlink’ from ‘stat2class’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 918,
                    "column": 21,
                    "event": "note",
                    "message": "(38) calling ‘new_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 739,
                    "column": 21,
                    "event": "note",
                    "message": "(39) entry to ‘new_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 744,
                    "column": 9,
                    "event": "note",
                    "message": "(40) following ‘true’ branch (when ‘class’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 745,
                    "column": 16,
                    "event": "note",
                    "message": "(41) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 745,
                    "column": 16,
                    "event": "note",
                    "message": "(42) calling ‘xcalloc’ from ‘new_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(43) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(44) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(45) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(46) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 745,
                    "column": 16,
                    "event": "note",
                    "message": "(47) returning to ‘new_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 746,
                    "column": 21,
                    "event": "note",
                    "message": "(48) ‘xcalloc(1, *class.size)’ could be NULL: unchecked value from (44)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  744|   \tassert(class);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  745|   \tfile = xcalloc(1, class->size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  746|-> \tfile->class = class;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  747|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  748|   \tfile->proc = proc;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "1ee2e040ff69c4be02b23febfb76c4e8dab5c968",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘new_readlink_error_file’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 765,
                    "column": 21,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xcalloc(1, readlink_error_class.size)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1989,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘new_proc’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 835,
                    "column": 21,
                    "event": "note",
                    "message": "(3) entry to ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(8) returning to ‘new_proc’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 38,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘leader’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(11) returning to ‘read_process’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(12) calling ‘xstrdup’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(18) returning to ‘read_process’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2003,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2021,
                    "column": 13,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘collect_execve_file’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1088,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(23) calling ‘collect_outofbox_files’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(24) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(28) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 894,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 19,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 51,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(31) calling ‘new_readlink_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 760,
                    "column": 21,
                    "event": "note",
                    "message": "(32) entry to ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(33) calling ‘xcalloc’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(34) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(35) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(36) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(37) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(38) returning to ‘new_readlink_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 765,
                    "column": 21,
                    "event": "note",
                    "message": "(39) ‘xcalloc(1, readlink_error_class.size)’ could be NULL: unchecked value from (35)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  763|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  764|   \tfile = xcalloc(1, readlink_error_class.size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  765|-> \tfile->class = &readlink_error_class;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  766|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  767|   \tfile->proc = proc;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "128ae98d81f0855e9af147091f4b6a4ad4811e64",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘new_stat_error_file’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 785,
                    "column": 21,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xcalloc(1, stat_error_class.size)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1989,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘new_proc’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 835,
                    "column": 21,
                    "event": "note",
                    "message": "(3) entry to ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(8) returning to ‘new_proc’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 38,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘leader’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(11) returning to ‘read_process’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(12) calling ‘xstrdup’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(18) returning to ‘read_process’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2003,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2021,
                    "column": 13,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘collect_execve_file’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1088,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(23) calling ‘collect_outofbox_files’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(24) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(28) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 894,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 182,
                    "column": 26,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 900,
                    "column": 26,
                    "event": "note",
                    "message": "in expansion of macro ‘list_last_entry’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 905,
                    "column": 19,
                    "event": "note",
                    "message": "(31) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 906,
                    "column": 52,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 906,
                    "column": 21,
                    "event": "note",
                    "message": "(33) calling ‘new_stat_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 780,
                    "column": 21,
                    "event": "note",
                    "message": "(34) entry to ‘new_stat_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 784,
                    "column": 16,
                    "event": "note",
                    "message": "(35) calling ‘xcalloc’ from ‘new_stat_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(36) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(37) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(38) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(39) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 784,
                    "column": 16,
                    "event": "note",
                    "message": "(40) returning to ‘new_stat_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 785,
                    "column": 21,
                    "event": "note",
                    "message": "(41) ‘xcalloc(1, stat_error_class.size)’ could be NULL: unchecked value from (37)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  783|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  784|   \tfile = xcalloc(1, stat_error_class.size);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  785|-> \tfile->class = &stat_error_class;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  786|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  787|   \tfile->proc = proc;",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "46491af9cdcb034cc10ec7e1bb2cf25cf343f58e",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘copy_file’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 805,
                    "column": 20,
                    "event": "warning[-Wanalyzer-possible-null-dereference]",
                    "message": "dereference of possibly-NULL ‘xcalloc(1, *old_9(D)->class.size)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1989,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘new_proc’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 835,
                    "column": 21,
                    "event": "note",
                    "message": "(3) entry to ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(8) returning to ‘new_proc’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 38,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘leader’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(11) returning to ‘read_process’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(12) calling ‘xstrdup’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(18) returning to ‘read_process’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2003,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2021,
                    "column": 13,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘collect_execve_file’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1088,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(23) calling ‘collect_outofbox_files’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(24) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(28) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 894,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 182,
                    "column": 26,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 900,
                    "column": 26,
                    "event": "note",
                    "message": "in expansion of macro ‘list_last_entry’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 182,
                    "column": 17,
                    "event": "note",
                    "message": "(31) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 900,
                    "column": 26,
                    "event": "note",
                    "message": "in expansion of macro ‘list_last_entry’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 901,
                    "column": 27,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 901,
                    "column": 18,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 902,
                    "column": 25,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 902,
                    "column": 18,
                    "event": "note",
                    "message": "(35) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 903,
                    "column": 21,
                    "event": "note",
                    "message": "(36) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 903,
                    "column": 21,
                    "event": "note",
                    "message": "(37) calling ‘copy_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 800,
                    "column": 21,
                    "event": "note",
                    "message": "(38) entry to ‘copy_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 802,
                    "column": 29,
                    "event": "note",
                    "message": "(39) calling ‘xcalloc’ from ‘copy_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(40) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 66,
                    "column": 21,
                    "event": "note",
                    "message": "(41) this call could return NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(42) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 802,
                    "column": 29,
                    "event": "note",
                    "message": "(44) returning to ‘copy_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 805,
                    "column": 20,
                    "event": "note",
                    "message": "(45) ‘xcalloc(1, *old_9(D)->class.size)’ could be NULL: unchecked value from (41)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  803|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  804|   \tINIT_LIST_HEAD(&file->files);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  805|-> \tfile->proc = old->proc;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  806|   \tlist_add_tail(&file->files, &old->proc->files);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  807|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "c6854c9856d651e31a2e3a691dbee5aca4879b33",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘reset_cooked_bdev’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1158,
                    "column": 1,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘xstrdup(filesystem)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1989,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘new_proc’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 835,
                    "column": 21,
                    "event": "note",
                    "message": "(3) entry to ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(8) returning to ‘new_proc’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 38,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘leader’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(11) returning to ‘read_process’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(12) calling ‘xstrdup’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(18) returning to ‘read_process’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2003,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2021,
                    "column": 13,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘collect_execve_file’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1088,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(23) calling ‘collect_outofbox_files’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(24) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(28) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(29) calling ‘new_readlink_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 760,
                    "column": 21,
                    "event": "note",
                    "message": "(30) entry to ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(31) calling ‘xcalloc’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(32) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(35) returning to ‘new_readlink_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(36) returning to ‘collect_file_symlink’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(37) calling ‘file_init_content’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 816,
                    "column": 13,
                    "event": "note",
                    "message": "(38) entry to ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 818,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 819,
                    "column": 17,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(41) returning to ‘collect_file_symlink’ from ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 923,
                    "column": 12,
                    "event": "note",
                    "message": "(42) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 228,
                    "column": 38,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 13,
                    "event": "note",
                    "message": "in expansion of macro ‘is_association’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 51,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(46) calling ‘find_mnt_ns’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1258,
                    "column": 30,
                    "event": "note",
                    "message": "(47) entry to ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1263,
                    "column": 12,
                    "event": "note",
                    "message": "(48) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1264,
                    "column": 24,
                    "event": "note",
                    "message": "(49) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(50) returning to ‘collect_file_symlink’ from ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 928,
                    "column": 20,
                    "event": "note",
                    "message": "(51) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(53) returning to ‘collect_outofbox_files’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(54) following ‘false’ branch (when ‘i >= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1086,
                    "column": 1,
                    "event": "note",
                    "message": "(55) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(56) returning to ‘collect_execve_file’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(57) returning to ‘read_process’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2028,
                    "column": 12,
                    "event": "note",
                    "message": "(58) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 47,
                    "event": "note",
                    "message": "(59) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 17,
                    "event": "note",
                    "message": "(60) calling ‘collect_fs_files’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1099,
                    "column": 13,
                    "event": "note",
                    "message": "(61) entry to ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1107,
                    "column": 9,
                    "event": "note",
                    "message": "(62) calling ‘collect_outofbox_files’ from ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(63) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(64) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(66) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(67) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(68) calling ‘new_readlink_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 760,
                    "column": 21,
                    "event": "note",
                    "message": "(69) entry to ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(70) calling ‘xcalloc’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(71) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(72) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(73) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(74) returning to ‘new_readlink_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(75) returning to ‘collect_file_symlink’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(76) calling ‘file_init_content’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 816,
                    "column": 13,
                    "event": "note",
                    "message": "(77) entry to ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 818,
                    "column": 12,
                    "event": "note",
                    "message": "(78) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 819,
                    "column": 17,
                    "event": "note",
                    "message": "(79) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(80) returning to ‘collect_file_symlink’ from ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 923,
                    "column": 12,
                    "event": "note",
                    "message": "(81) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 228,
                    "column": 38,
                    "event": "note",
                    "message": "(82) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 13,
                    "event": "note",
                    "message": "in expansion of macro ‘is_association’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 12,
                    "event": "note",
                    "message": "(83) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 51,
                    "event": "note",
                    "message": "(84) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(85) calling ‘find_mnt_ns’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1258,
                    "column": 30,
                    "event": "note",
                    "message": "(86) entry to ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1263,
                    "column": 12,
                    "event": "note",
                    "message": "(87) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1264,
                    "column": 24,
                    "event": "note",
                    "message": "(88) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(89) returning to ‘collect_file_symlink’ from ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 928,
                    "column": 20,
                    "event": "note",
                    "message": "(90) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(91) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(92) returning to ‘collect_outofbox_files’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(93) following ‘false’ branch (when ‘i >= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1086,
                    "column": 1,
                    "event": "note",
                    "message": "(94) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1107,
                    "column": 9,
                    "event": "note",
                    "message": "(95) returning to ‘collect_fs_files’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 17,
                    "event": "note",
                    "message": "(96) returning to ‘read_process’ from ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2050,
                    "column": 12,
                    "event": "note",
                    "message": "(97) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2056,
                    "column": 17,
                    "event": "note",
                    "message": "(98) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2058,
                    "column": 20,
                    "event": "note",
                    "message": "(99) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2060,
                    "column": 33,
                    "event": "note",
                    "message": "(100) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2060,
                    "column": 42,
                    "event": "note",
                    "message": "(101) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2062,
                    "column": 25,
                    "event": "note",
                    "message": "(102) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2062,
                    "column": 25,
                    "event": "note",
                    "message": "(103) calling ‘read_mountinfo_in_mntns’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1413,
                    "column": 13,
                    "event": "note",
                    "message": "(104) entry to ‘read_mountinfo_in_mntns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1416,
                    "column": 12,
                    "event": "note",
                    "message": "(105) following ‘false’ branch (when ‘mntns_fd < 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(106) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1421,
                    "column": 9,
                    "event": "note",
                    "message": "(107) calling ‘read_mountinfo’ from ‘read_mountinfo_in_mntns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1374,
                    "column": 13,
                    "event": "note",
                    "message": "(108) entry to ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1380,
                    "column": 16,
                    "event": "note",
                    "message": "(109) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1386,
                    "column": 20,
                    "event": "note",
                    "message": "(110) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1386,
                    "column": 19,
                    "event": "note",
                    "message": "(111) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1393,
                    "column": 20,
                    "event": "note",
                    "message": "(112) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1393,
                    "column": 19,
                    "event": "note",
                    "message": "(113) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1402,
                    "column": 21,
                    "event": "note",
                    "message": "(114) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1403,
                    "column": 17,
                    "event": "note",
                    "message": "(115) calling ‘process_mountinfo_entry’ from ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1355,
                    "column": 13,
                    "event": "note",
                    "message": "(116) entry to ‘process_mountinfo_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1363,
                    "column": 25,
                    "event": "note",
                    "message": "(117) calling ‘add_cooked_bdev’ from ‘process_mountinfo_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1184,
                    "column": 13,
                    "event": "note",
                    "message": "(118) entry to ‘add_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1197,
                    "column": 16,
                    "event": "note",
                    "message": "(119) calling ‘new_cooked_bdev’ from ‘add_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1160,
                    "column": 28,
                    "event": "note",
                    "message": "(120) entry to ‘new_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1162,
                    "column": 36,
                    "event": "note",
                    "message": "(121) calling ‘xmalloc’ from ‘new_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(122) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(123) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(124) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1162,
                    "column": 36,
                    "event": "note",
                    "message": "(125) returning to ‘new_cooked_bdev’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1169,
                    "column": 17,
                    "event": "note",
                    "message": "(126) calling ‘xasprintf’ from ‘new_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 116,
                    "column": 5,
                    "event": "note",
                    "message": "(127) entry to ‘xasprintf’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 124,
                    "column": 12,
                    "event": "note",
                    "message": "(128) following ‘false’ branch (when ‘ret >= 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 126,
                    "column": 16,
                    "event": "note",
                    "message": "(129) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1169,
                    "column": 17,
                    "event": "note",
                    "message": "(130) returning to ‘new_cooked_bdev’ from ‘xasprintf’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1197,
                    "column": 16,
                    "event": "note",
                    "message": "(131) returning to ‘add_cooked_bdev’ from ‘new_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1363,
                    "column": 25,
                    "event": "note",
                    "message": "(132) returning to ‘process_mountinfo_entry’ from ‘add_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1403,
                    "column": 17,
                    "event": "note",
                    "message": "(133) returning to ‘read_mountinfo’ from ‘process_mountinfo_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1380,
                    "column": 16,
                    "event": "note",
                    "message": "(134) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1386,
                    "column": 20,
                    "event": "note",
                    "message": "(135) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1386,
                    "column": 19,
                    "event": "note",
                    "message": "(136) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1393,
                    "column": 20,
                    "event": "note",
                    "message": "(137) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1393,
                    "column": 19,
                    "event": "note",
                    "message": "(138) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1402,
                    "column": 21,
                    "event": "note",
                    "message": "(139) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1403,
                    "column": 17,
                    "event": "note",
                    "message": "(140) calling ‘process_mountinfo_entry’ from ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1355,
                    "column": 13,
                    "event": "note",
                    "message": "(141) entry to ‘process_mountinfo_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1360,
                    "column": 12,
                    "event": "note",
                    "message": "(142) following ‘true’ branch (when ‘mnt_ns’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1362,
                    "column": 21,
                    "event": "note",
                    "message": "(143) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1362,
                    "column": 20,
                    "event": "note",
                    "message": "(144) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 30,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1363,
                    "column": 60,
                    "event": "note",
                    "message": "(145) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1363,
                    "column": 25,
                    "event": "note",
                    "message": "(146) calling ‘add_cooked_bdev’ from ‘process_mountinfo_entry’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1184,
                    "column": 13,
                    "event": "note",
                    "message": "(147) entry to ‘add_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(148) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1189,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1191,
                    "column": 25,
                    "event": "note",
                    "message": "(149) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1191,
                    "column": 20,
                    "event": "note",
                    "message": "(150) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1192,
                    "column": 25,
                    "event": "note",
                    "message": "(151) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1192,
                    "column": 25,
                    "event": "note",
                    "message": "(152) calling ‘reset_cooked_bdev’ from ‘add_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1153,
                    "column": 13,
                    "event": "note",
                    "message": "(153) entry to ‘reset_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1157,
                    "column": 28,
                    "event": "note",
                    "message": "(154) calling ‘xstrdup’ from ‘reset_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(155) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(156) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(157) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(158) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(159) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(160) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(161) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1157,
                    "column": 28,
                    "event": "note",
                    "message": "(162) returning to ‘reset_cooked_bdev’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1158,
                    "column": 1,
                    "event": "note",
                    "message": "(163) ‘xstrdup(filesystem)’ leaks here; was allocated at (158)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1156|   \tfree(bdev->filesystem);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1157|   \tbdev->filesystem = xstrdup(filesystem);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1158|-> }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1159|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1160|   static struct cooked_bdev *new_cooked_bdev(dev_t cooked, dev_t raw, const char *filesystem)",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 416,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "117d11bfe4953951eb3c69e2e125aa8e7a609b36",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_nodevs_from_cooked_bdevs’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1349,
                    "column": 31,
                    "event": "warning[-Wanalyzer-use-after-free]",
                    "message": "use after ‘free’ of ‘n’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1989,
                    "column": 13,
                    "event": "note",
                    "message": "(1) entry to ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(2) calling ‘new_proc’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 835,
                    "column": 21,
                    "event": "note",
                    "message": "(3) entry to ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(4) calling ‘xcalloc’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(5) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 837,
                    "column": 29,
                    "event": "note",
                    "message": "(8) returning to ‘new_proc’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 38,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘leader’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 840,
                    "column": 22,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1998,
                    "column": 16,
                    "event": "note",
                    "message": "(11) returning to ‘read_process’ from ‘new_proc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(12) calling ‘xstrdup’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 88,
                    "column": 7,
                    "event": "note",
                    "message": "(13) entry to ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 92,
                    "column": 9,
                    "event": "note",
                    "message": "(14) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 93,
                    "column": 15,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 94,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 96,
                    "column": 16,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2000,
                    "column": 40,
                    "event": "note",
                    "message": "(18) returning to ‘read_process’ from ‘xstrdup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2003,
                    "column": 12,
                    "event": "note",
                    "message": "(19) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2021,
                    "column": 13,
                    "event": "note",
                    "message": "(20) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(21) calling ‘collect_execve_file’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1088,
                    "column": 13,
                    "event": "note",
                    "message": "(22) entry to ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(23) calling ‘collect_outofbox_files’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(24) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(25) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(26) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(27) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(28) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(29) calling ‘new_readlink_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 760,
                    "column": 21,
                    "event": "note",
                    "message": "(30) entry to ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(31) calling ‘xcalloc’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(32) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(33) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(34) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(35) returning to ‘new_readlink_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(36) returning to ‘collect_file_symlink’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(37) calling ‘file_init_content’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 816,
                    "column": 13,
                    "event": "note",
                    "message": "(38) entry to ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 818,
                    "column": 12,
                    "event": "note",
                    "message": "(39) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 819,
                    "column": 17,
                    "event": "note",
                    "message": "(40) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(41) returning to ‘collect_file_symlink’ from ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 923,
                    "column": 12,
                    "event": "note",
                    "message": "(42) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 228,
                    "column": 38,
                    "event": "note",
                    "message": "(43) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 13,
                    "event": "note",
                    "message": "in expansion of macro ‘is_association’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 12,
                    "event": "note",
                    "message": "(44) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 51,
                    "event": "note",
                    "message": "(45) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(46) calling ‘find_mnt_ns’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1258,
                    "column": 30,
                    "event": "note",
                    "message": "(47) entry to ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1263,
                    "column": 12,
                    "event": "note",
                    "message": "(48) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1264,
                    "column": 24,
                    "event": "note",
                    "message": "(49) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(50) returning to ‘collect_file_symlink’ from ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 928,
                    "column": 20,
                    "event": "note",
                    "message": "(51) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(52) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(53) returning to ‘collect_outofbox_files’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(54) following ‘false’ branch (when ‘i >= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1086,
                    "column": 1,
                    "event": "note",
                    "message": "(55) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1095,
                    "column": 9,
                    "event": "note",
                    "message": "(56) returning to ‘collect_execve_file’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2026,
                    "column": 9,
                    "event": "note",
                    "message": "(57) returning to ‘read_process’ from ‘collect_execve_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2028,
                    "column": 12,
                    "event": "note",
                    "message": "(58) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 47,
                    "event": "note",
                    "message": "(59) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 17,
                    "event": "note",
                    "message": "(60) calling ‘collect_fs_files’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1099,
                    "column": 13,
                    "event": "note",
                    "message": "(61) entry to ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1107,
                    "column": 9,
                    "event": "note",
                    "message": "(62) calling ‘collect_outofbox_files’ from ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1074,
                    "column": 13,
                    "event": "note",
                    "message": "(63) entry to ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(64) following ‘true’ branch (when ‘i < count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(65) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(66) calling ‘collect_file_symlink’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 884,
                    "column": 21,
                    "event": "note",
                    "message": "(67) entry to ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(68) calling ‘new_readlink_error_file’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 760,
                    "column": 21,
                    "event": "note",
                    "message": "(69) entry to ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(70) calling ‘xcalloc’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 64,
                    "column": 7,
                    "event": "note",
                    "message": "(71) entry to ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 68,
                    "column": 12,
                    "event": "note",
                    "message": "(72) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 70,
                    "column": 16,
                    "event": "note",
                    "message": "(73) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 764,
                    "column": 16,
                    "event": "note",
                    "message": "(74) returning to ‘new_readlink_error_file’ from ‘xcalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 895,
                    "column": 21,
                    "event": "note",
                    "message": "(75) returning to ‘collect_file_symlink’ from ‘new_readlink_error_file’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(76) calling ‘file_init_content’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 816,
                    "column": 13,
                    "event": "note",
                    "message": "(77) entry to ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 818,
                    "column": 12,
                    "event": "note",
                    "message": "(78) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 819,
                    "column": 17,
                    "event": "note",
                    "message": "(79) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 921,
                    "column": 9,
                    "event": "note",
                    "message": "(80) returning to ‘collect_file_symlink’ from ‘file_init_content’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 923,
                    "column": 12,
                    "event": "note",
                    "message": "(81) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.h",
                    "line": 228,
                    "column": 38,
                    "event": "note",
                    "message": "(82) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 13,
                    "event": "note",
                    "message": "in expansion of macro ‘is_association’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 926,
                    "column": 12,
                    "event": "note",
                    "message": "(83) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 51,
                    "event": "note",
                    "message": "(84) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(85) calling ‘find_mnt_ns’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1258,
                    "column": 30,
                    "event": "note",
                    "message": "(86) entry to ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1263,
                    "column": 12,
                    "event": "note",
                    "message": "(87) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1264,
                    "column": 24,
                    "event": "note",
                    "message": "(88) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 927,
                    "column": 32,
                    "event": "note",
                    "message": "(89) returning to ‘collect_file_symlink’ from ‘find_mnt_ns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 928,
                    "column": 20,
                    "event": "note",
                    "message": "(90) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(91) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1084,
                    "column": 17,
                    "event": "note",
                    "message": "(92) returning to ‘collect_outofbox_files’ from ‘collect_file_symlink’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1083,
                    "column": 23,
                    "event": "note",
                    "message": "(93) following ‘false’ branch (when ‘i >= count’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1086,
                    "column": 1,
                    "event": "note",
                    "message": "(94) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1107,
                    "column": 9,
                    "event": "note",
                    "message": "(95) returning to ‘collect_fs_files’ from ‘collect_outofbox_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2030,
                    "column": 17,
                    "event": "note",
                    "message": "(96) returning to ‘read_process’ from ‘collect_fs_files’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2050,
                    "column": 12,
                    "event": "note",
                    "message": "(97) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2056,
                    "column": 17,
                    "event": "note",
                    "message": "(98) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2058,
                    "column": 20,
                    "event": "note",
                    "message": "(99) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2060,
                    "column": 33,
                    "event": "note",
                    "message": "(100) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2060,
                    "column": 42,
                    "event": "note",
                    "message": "(101) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2062,
                    "column": 25,
                    "event": "note",
                    "message": "(102) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2062,
                    "column": 25,
                    "event": "note",
                    "message": "(103) calling ‘read_mountinfo_in_mntns’ from ‘read_process’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1413,
                    "column": 13,
                    "event": "note",
                    "message": "(104) entry to ‘read_mountinfo_in_mntns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1416,
                    "column": 12,
                    "event": "note",
                    "message": "(105) following ‘false’ branch (when ‘mntns_fd < 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(106) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1421,
                    "column": 9,
                    "event": "note",
                    "message": "(107) calling ‘read_mountinfo’ from ‘read_mountinfo_in_mntns’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1374,
                    "column": 13,
                    "event": "note",
                    "message": "(108) entry to ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1380,
                    "column": 16,
                    "event": "note",
                    "message": "(109) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1407,
                    "column": 12,
                    "event": "note",
                    "message": "(110) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1407,
                    "column": 12,
                    "event": "note",
                    "message": "(111) following ‘true’ branch (when ‘mnt_ns’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1408,
                    "column": 17,
                    "event": "note",
                    "message": "(112) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1408,
                    "column": 17,
                    "event": "note",
                    "message": "(113) calling ‘dedup_cooked_bdevs’ from ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1201,
                    "column": 13,
                    "event": "note",
                    "message": "(114) entry to ‘dedup_cooked_bdevs’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 208,
                    "column": 40,
                    "event": "note",
                    "message": "(115) state of ‘INIT_VAL((*SUB(SUB(CONJURED(_39 = ul_path_fopen (pc_4(D), \"r\", \"mountinfo\");, HEAP_ALLOCATED_REGION(1343)), CAST_REG(‘struct proc’, HEAP_ALLOCATED_REGION(1343))), CAST_REG(‘struct proc’, HEAP_ALLOCATED_REGION(1343)).mnt_ns)).cooked_bdevs.next)’: ‘start’ -> ‘assumed-non-null’ (NULL origin)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1205,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each_safe’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 208,
                    "column": 57,
                    "event": "note",
                    "message": "(116) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1205,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each_safe’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1208,
                    "column": 25,
                    "event": "note",
                    "message": "(117) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1208,
                    "column": 20,
                    "event": "note",
                    "message": "(118) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1209,
                    "column": 25,
                    "event": "note",
                    "message": "(119) inlined call to ‘list_del’ from ‘dedup_cooked_bdevs’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 107,
                    "column": 9,
                    "event": "note",
                    "message": "(120) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘add_nodevs_from_cooked_bdevs’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1210,
                    "column": 25,
                    "event": "note",
                    "message": "(121) calling ‘free_cooked_bdev’ from ‘dedup_cooked_bdevs’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1177,
                    "column": 13,
                    "event": "note",
                    "message": "(122) entry to ‘free_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1179,
                    "column": 12,
                    "event": "note",
                    "message": "(123) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1181,
                    "column": 9,
                    "event": "note",
                    "message": "(124) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1181,
                    "column": 9,
                    "event": "note",
                    "message": "(125) freed here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1210,
                    "column": 25,
                    "event": "note",
                    "message": "(126) returning to ‘dedup_cooked_bdevs’ from ‘free_cooked_bdev’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1408,
                    "column": 17,
                    "event": "note",
                    "message": "(127) returning to ‘read_mountinfo’ from ‘dedup_cooked_bdevs’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1409,
                    "column": 17,
                    "event": "note",
                    "message": "(128) calling ‘add_nodevs_from_cooked_bdevs’ from ‘read_mountinfo’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1343,
                    "column": 13,
                    "event": "note",
                    "message": "(129) entry to ‘add_nodevs_from_cooked_bdevs’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 190,
                    "column": 38,
                    "event": "note",
                    "message": "(130) following ‘true’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1346,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro ‘list_for_each’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 1349,
                    "column": 31,
                    "event": "note",
                    "message": "(131) ...to here (132) use after ‘free’ of ‘n’; freed at (125)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1347|   \t\tstruct cooked_bdev *bdev = list_entry(n, struct cooked_bdev,",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1348|   \t\t\t\t\t\t      cooked_bdevs);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1349|-> \t\tif (major(bdev->cooked) == 0",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1350|   \t\t    && get_nodev_filesystem(minor(bdev->cooked)) == NULL)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 1351|   \t\t\tadd_nodev(minor(bdev->cooked), bdev->filesystem);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "37e1bdb5bbda3b0cba53b4bfcbf778350b53bb29",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_pids’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2135,
                    "column": 13,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘outarg’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2561,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2566,
                    "column": 16,
                    "event": "note",
                    "message": "(2) ‘filter_expr’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2615,
                    "column": 86,
                    "event": "note",
                    "message": "(3) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(5) following ‘case 112:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2635,
                    "column": 17,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2636,
                    "column": 25,
                    "event": "note",
                    "message": "(7) calling ‘parse_pids’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2111,
                    "column": 13,
                    "event": "note",
                    "message": "(8) entry to ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2114,
                    "column": 15,
                    "event": "note",
                    "message": "(9) ‘next’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2116,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2119,
                    "column": 9,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2121,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2123,
                    "column": 18,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2123,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2125,
                    "column": 12,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2125,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch (when ‘v >= 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2128,
                    "column": 10,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2129,
                    "column": 17,
                    "event": "note",
                    "message": "(18) calling ‘xreallocarray’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(19) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2129,
                    "column": 17,
                    "event": "note",
                    "message": "(22) returning to ‘parse_pids’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2135,
                    "column": 13,
                    "event": "note",
                    "message": "(23) dereference of NULL ‘<unknown>’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2133|   \t       && (isspace((unsigned char)*next) || *next == ','))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2134|   \t\tnext++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2135|-> \tif (*next != '\\0')",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2136|   \t\tparse_pids(next, pids, count);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2137|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ce3a2f3bb5de9b710531929ebbcf177c73509b23",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2135,
                    "column": 13,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL ‘0’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2561,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2566,
                    "column": 16,
                    "event": "note",
                    "message": "(2) ‘filter_expr’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2615,
                    "column": 86,
                    "event": "note",
                    "message": "(3) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(4) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(5) following ‘case 111:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2620,
                    "column": 17,
                    "event": "note",
                    "message": "(6) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2615,
                    "column": 86,
                    "event": "note",
                    "message": "(7) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(8) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2616,
                    "column": 17,
                    "event": "note",
                    "message": "(9) following ‘case 112:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2635,
                    "column": 17,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2636,
                    "column": 25,
                    "event": "note",
                    "message": "(11) calling ‘parse_pids’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2111,
                    "column": 13,
                    "event": "note",
                    "message": "(12) entry to ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2114,
                    "column": 15,
                    "event": "note",
                    "message": "(13) ‘next’ is NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2116,
                    "column": 12,
                    "event": "note",
                    "message": "(14) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2119,
                    "column": 9,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2121,
                    "column": 12,
                    "event": "note",
                    "message": "(16) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2123,
                    "column": 18,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2123,
                    "column": 12,
                    "event": "note",
                    "message": "(18) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2125,
                    "column": 12,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2125,
                    "column": 12,
                    "event": "note",
                    "message": "(20) following ‘false’ branch (when ‘v >= 0’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2128,
                    "column": 10,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2129,
                    "column": 17,
                    "event": "note",
                    "message": "(22) calling ‘xreallocarray’ from ‘parse_pids’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 52,
                    "column": 7,
                    "event": "note",
                    "message": "(23) entry to ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 56,
                    "column": 12,
                    "event": "note",
                    "message": "(24) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 58,
                    "column": 16,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2129,
                    "column": 17,
                    "event": "note",
                    "message": "(26) returning to ‘parse_pids’ from ‘xreallocarray’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/lsfd-cmd/lsfd.c",
                    "line": 2135,
                    "column": 13,
                    "event": "note",
                    "message": "(27) dereference of NULL ‘<unknown>’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2133|   \t       && (isspace((unsigned char)*next) || *next == ','))",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2134|   \t\tnext++;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2135|-> \tif (*next != '\\0')",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2136|   \t\tparse_pids(next, pids, count);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": " 2137|   }",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 476,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "dace7d75da593da5f6035f26de1e971af84ef905",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "warning[-Wanalyzer-null-dereference]",
                    "message": "dereference of NULL 'cxt'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'fdisk_set_wipe_area'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 57,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to 'fdisk_set_wipe_area'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 64,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 67,
                    "column": 14,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 67,
                    "column": 14,
                    "event": "note",
                    "message": "(4) calling 'fdisk_get_wipe_area' from 'fdisk_set_wipe_area'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 16,
                    "column": 27,
                    "event": "note",
                    "message": "(5) entry to 'fdisk_get_wipe_area'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 23,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'true' branch (when 'cxt' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 67,
                    "column": 14,
                    "event": "note",
                    "message": "(8) returning to 'fdisk_set_wipe_area' from 'fdisk_get_wipe_area'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 70,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following 'false' branch (when 'enable != 0')...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 83,
                    "column": 12,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 83,
                    "column": 12,
                    "event": "note",
                    "message": "(11) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 86,
                    "column": 14,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 87,
                    "column": 12,
                    "event": "note",
                    "message": "(13) following 'false' branch (when 'wp' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/fdiskP.h",
                    "line": 26,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/debug.h",
                    "line": 64,
                    "column": 30,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/fdiskP.h",
                    "line": 48,
                    "column": 25,
                    "event": "note",
                    "message": "in expansion of macro '__UL_DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 90,
                    "column": 9,
                    "event": "note",
                    "message": "in expansion of macro 'DBG'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/libfdisk/src/wipe.c",
                    "line": 96,
                    "column": 9,
                    "event": "note",
                    "message": "(15) inlined call to 'list_add_tail' from 'fdisk_set_wipe_area'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 81,
                    "column": 9,
                    "event": "note",
                    "message": "(16) dereference of NULL 'cxt'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   79|   _INLINE_ void list_add_tail(struct list_head *add, struct list_head *head)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   80|   {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   81|-> \t__list_add(add, head->prev, head);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   82|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   83|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ff84110a9fe78135d9a8fd3f0cf1d6417c7555fd",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'll2_update_login_time'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 365,
                    "column": 24,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'tty'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 354,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(4) calling 'read_entry' from 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(5) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'false' branch (when 'll_time' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 166,
                    "column": 28,
                    "event": "note",
                    "message": "(18) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 45,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 45,
                    "event": "note",
                    "message": "(20) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(21) assuming 'tty' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(22) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(24) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 174,
                    "column": 28,
                    "event": "note",
                    "message": "(26) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 47,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 36,
                    "event": "note",
                    "message": "(28) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 177,
                    "column": 41,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(30) returning to 'll2_update_login_time' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 368,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 369,
                    "column": 17,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 365,
                    "column": 24,
                    "event": "note",
                    "message": "(33) 'tty' leaks here; was allocated at (20)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  363|   \tretval = open_database_rw(context , &db, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  364|   \tif (retval != 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  365|-> \t\treturn retval;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  366|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  367|   \tretval = read_entry(db, user, 0, &tty, &rhost, &pam_service, error);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "7c513f7fba8e7e4b7af2cfbc70b6752a4d2ae542",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 365,
                    "column": 24,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'rhost'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 354,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(4) calling 'read_entry' from 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(5) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'false' branch (when 'll_time' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 166,
                    "column": 28,
                    "event": "note",
                    "message": "(18) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 45,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(20) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 174,
                    "column": 28,
                    "event": "note",
                    "message": "(24) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 47,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 47,
                    "event": "note",
                    "message": "(26) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 36,
                    "event": "note",
                    "message": "(27) assuming 'rhost' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 36,
                    "event": "note",
                    "message": "(28) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(30) following 'true' branch (when 'pam_service' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 181,
                    "column": 30,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 182,
                    "column": 28,
                    "event": "note",
                    "message": "(32) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 53,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 36,
                    "event": "note",
                    "message": "(34) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 185,
                    "column": 41,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(36) returning to 'll2_update_login_time' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 368,
                    "column": 12,
                    "event": "note",
                    "message": "(37) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 369,
                    "column": 17,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 365,
                    "column": 24,
                    "event": "note",
                    "message": "(39) 'rhost' leaks here; was allocated at (26)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  363|   \tretval = open_database_rw(context , &db, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  364|   \tif (retval != 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  365|-> \t\treturn retval;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  366|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  367|   \tretval = read_entry(db, user, 0, &tty, &rhost, &pam_service, error);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ce87081f1138619d131330d219ab7715e8b5ca3f",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 373,
                    "column": 18,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value 'rhost'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 354,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 360,
                    "column": 15,
                    "event": "note",
                    "message": "(2) region created on stack here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 360,
                    "column": 15,
                    "event": "note",
                    "message": "(3) capacity: 8 bytes",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(6) calling 'read_entry' from 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(7) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'false' branch (when 'll_time' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(20) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following 'true' branch (when 'pam_service' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 181,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 182,
                    "column": 28,
                    "event": "note",
                    "message": "(24) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 53,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 36,
                    "event": "note",
                    "message": "(26) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(28) returning to 'll2_update_login_time' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 368,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 373,
                    "column": 18,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 373,
                    "column": 18,
                    "event": "note",
                    "message": "(31) use of uninitialized value 'rhost' here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  371|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  372|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  373|-> \tretval = write_entry(db, user, ll_time, tty, rhost, pam_service, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  374|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  375|   \tsqlite3_close(db);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "93d73009097d56255060dfc5b292fe36cb1daabc",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 373,
                    "column": 18,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value 'pam_service'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 354,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 361,
                    "column": 15,
                    "event": "note",
                    "message": "(2) region created on stack here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 361,
                    "column": 15,
                    "event": "note",
                    "message": "(3) capacity: 8 bytes",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 364,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(6) calling 'read_entry' from 'll2_update_login_time'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(7) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'false' branch (when 'll_time' is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(20) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(24) following 'true' branch (when 'pam_service' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 181,
                    "column": 30,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 203,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 206,
                    "column": 16,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 367,
                    "column": 18,
                    "event": "note",
                    "message": "(28) returning to 'll2_update_login_time' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 368,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 373,
                    "column": 18,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 373,
                    "column": 18,
                    "event": "note",
                    "message": "(31) use of uninitialized value 'pam_service' here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  371|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  372|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  373|-> \tretval = write_entry(db, user, ll_time, tty, rhost, pam_service, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  374|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  375|   \tsqlite3_close(db);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "ff84110a9fe78135d9a8fd3f0cf1d6417c7555fd",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function 'll2_rename_user'",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 527,
                    "column": 24,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'tty'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 515,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 526,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(4) calling 'read_entry' from 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(5) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'true' branch (when 'll_time' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 162,
                    "column": 36,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 166,
                    "column": 28,
                    "event": "note",
                    "message": "(18) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 45,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 45,
                    "event": "note",
                    "message": "(20) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(21) assuming 'tty' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(22) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(24) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 174,
                    "column": 28,
                    "event": "note",
                    "message": "(26) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 47,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 36,
                    "event": "note",
                    "message": "(28) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 177,
                    "column": 41,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(30) returning to 'll2_rename_user' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 530,
                    "column": 12,
                    "event": "note",
                    "message": "(31) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 531,
                    "column": 17,
                    "event": "note",
                    "message": "(32) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 527,
                    "column": 24,
                    "event": "note",
                    "message": "(33) 'tty' leaks here; was allocated at (20)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  525|   \tretval = open_database_rw(context, &db, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  526|   \tif (retval != 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  527|-> \t\treturn retval;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  528|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  529|   \tretval = read_entry(db, user, &ll_time, &tty, &rhost, &pam_service, error);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "7c513f7fba8e7e4b7af2cfbc70b6752a4d2ae542",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 527,
                    "column": 24,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of 'rhost'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 515,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 526,
                    "column": 12,
                    "event": "note",
                    "message": "(2) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(4) calling 'read_entry' from 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(5) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(6) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(7) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(12) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'true' branch (when 'll_time' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 162,
                    "column": 36,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 166,
                    "column": 28,
                    "event": "note",
                    "message": "(18) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 45,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(20) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 174,
                    "column": 28,
                    "event": "note",
                    "message": "(24) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 47,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 47,
                    "event": "note",
                    "message": "(26) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 36,
                    "event": "note",
                    "message": "(27) assuming 'rhost' is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 175,
                    "column": 36,
                    "event": "note",
                    "message": "(28) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(29) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(30) following 'true' branch (when 'pam_service' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 181,
                    "column": 30,
                    "event": "note",
                    "message": "(31) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 182,
                    "column": 28,
                    "event": "note",
                    "message": "(32) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 53,
                    "event": "note",
                    "message": "(33) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 36,
                    "event": "note",
                    "message": "(34) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 185,
                    "column": 41,
                    "event": "note",
                    "message": "(35) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(36) returning to 'll2_rename_user' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 530,
                    "column": 12,
                    "event": "note",
                    "message": "(37) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 531,
                    "column": 17,
                    "event": "note",
                    "message": "(38) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 527,
                    "column": 24,
                    "event": "note",
                    "message": "(39) 'rhost' leaks here; was allocated at (26)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  525|   \tretval = open_database_rw(context, &db, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  526|   \tif (retval != 0)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  527|-> \t\treturn retval;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  528|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  529|   \tretval = read_entry(db, user, &ll_time, &tty, &rhost, &pam_service, error);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "3449894a195980b69ff0eab601112cb14d82e455",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 535,
                    "column": 18,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value 'rhost'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 515,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 521,
                    "column": 15,
                    "event": "note",
                    "message": "(2) region created on stack here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 521,
                    "column": 15,
                    "event": "note",
                    "message": "(3) capacity: 8 bytes",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 526,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(6) calling 'read_entry' from 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(7) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'true' branch (when 'll_time' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 162,
                    "column": 36,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(20) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following 'true' branch (when 'pam_service' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 181,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 182,
                    "column": 28,
                    "event": "note",
                    "message": "(24) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 53,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 183,
                    "column": 36,
                    "event": "note",
                    "message": "(26) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "cc1",
                    "line": 0,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(28) returning to 'll2_rename_user' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 530,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 535,
                    "column": 18,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 535,
                    "column": 18,
                    "event": "note",
                    "message": "(31) use of uninitialized value 'rhost' here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  533|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  534|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  535|-> \tretval = write_entry(db, newname, ll_time, tty, rhost, pam_service, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  536|   \tif (retval != 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  537|   \t\tsqlite3_close(db);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 457,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "a6a9af7c9b61bee2a2cca2266bec21c2d0b9e775",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 535,
                    "column": 18,
                    "event": "warning[-Wanalyzer-use-of-uninitialized-value]",
                    "message": "use of uninitialized value 'pam_service'",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 515,
                    "column": 1,
                    "event": "note",
                    "message": "(1) entry to 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 522,
                    "column": 15,
                    "event": "note",
                    "message": "(2) region created on stack here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 522,
                    "column": 15,
                    "event": "note",
                    "message": "(3) capacity: 8 bytes",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 526,
                    "column": 12,
                    "event": "note",
                    "message": "(4) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(6) calling 'read_entry' from 'll2_rename_user'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 121,
                    "column": 1,
                    "event": "note",
                    "message": "(7) entry to 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 129,
                    "column": 12,
                    "event": "note",
                    "message": "(8) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 13,
                    "event": "note",
                    "message": "(9) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 138,
                    "column": 12,
                    "event": "note",
                    "message": "(10) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 147,
                    "column": 20,
                    "event": "note",
                    "message": "(11) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 149,
                    "column": 12,
                    "event": "note",
                    "message": "(12) following 'true' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 150,
                    "column": 46,
                    "event": "note",
                    "message": "(13) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 153,
                    "column": 20,
                    "event": "note",
                    "message": "(14) following 'false' branch (when the strings are equal)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(15) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 161,
                    "column": 20,
                    "event": "note",
                    "message": "(16) following 'true' branch (when 'll_time' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 162,
                    "column": 36,
                    "event": "note",
                    "message": "(17) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 164,
                    "column": 20,
                    "event": "note",
                    "message": "(18) following 'true' branch (when 'tty' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 165,
                    "column": 30,
                    "event": "note",
                    "message": "(19) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 167,
                    "column": 36,
                    "event": "note",
                    "message": "(20) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 172,
                    "column": 20,
                    "event": "note",
                    "message": "(22) following 'true' branch (when 'rhost' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 173,
                    "column": 30,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 180,
                    "column": 20,
                    "event": "note",
                    "message": "(24) following 'true' branch (when 'pam_service' is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 181,
                    "column": 30,
                    "event": "note",
                    "message": "(25) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 203,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 206,
                    "column": 16,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 529,
                    "column": 18,
                    "event": "note",
                    "message": "(28) returning to 'll2_rename_user' from 'read_entry'",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 530,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following 'false' branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 535,
                    "column": 18,
                    "event": "note",
                    "message": "(30) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/liblastlog2/src/lastlog2.c",
                    "line": 535,
                    "column": 18,
                    "event": "note",
                    "message": "(31) use of uninitialized value 'pam_service' here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  533|   \t}",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  534|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  535|-> \tretval = write_entry(db, newname, ll_time, tty, rhost, pam_service, error);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  536|   \tif (retval != 0) {",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  537|   \t\tsqlite3_close(db);",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "d2a160156f081076e7aaa030f3acb214c8b9274b",
            "key_event_idx": 0,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘parse_block(optarg, 25, & ioctls, 1)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 157,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 185,
                    "column": 79,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 186,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 186,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 105:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 194,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 195,
                    "column": 35,
                    "event": "note",
                    "message": "(6) calling ‘parse_block’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 106,
                    "column": 31,
                    "event": "note",
                    "message": "(7) entry to ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/usr/include/features.h",
                    "line": 540,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/usr/include/getopt.h",
                    "line": 24,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 20,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 115,
                    "column": 17,
                    "event": "note",
                    "message": "(8) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 116,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch (when ‘colon’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 136,
                    "column": 9,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 136,
                    "column": 23,
                    "event": "note",
                    "message": "(11) following ‘true’ branch (when ‘i < n_entities’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 137,
                    "column": 42,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 147,
                    "column": 19,
                    "event": "note",
                    "message": "(13) calling ‘xmalloc’ from ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 34,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(14) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(15) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(16) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 147,
                    "column": 19,
                    "event": "note",
                    "message": "(19) returning to ‘parse_block’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 195,
                    "column": 35,
                    "event": "note",
                    "message": "(20) returning to ‘main’ from ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 196,
                    "column": 25,
                    "event": "note",
                    "message": "(21) inlined call to ‘list_add’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 68,
                    "column": 9,
                    "event": "note",
                    "message": "(22) inlined call to ‘__list_add’ from ‘list_add’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/list.h",
                    "line": 55,
                    "column": 20,
                    "event": "note",
                    "message": "(23) ‘parse_block(optarg, 25, & ioctls, 1)’ leaks here; was allocated at (15)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   53|   \tadd->next = next;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   54|   \tadd->prev = prev;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   55|-> \tprev->next = add;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   56|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "   57|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "f10cabfe06498a873d525fddcc6fc3d2af5cabd2",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘parse_block’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 154,
                    "column": 16,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘name’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 157,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 185,
                    "column": 79,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 186,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 186,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 115:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 187,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 188,
                    "column": 35,
                    "event": "note",
                    "message": "(6) calling ‘parse_block’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 106,
                    "column": 31,
                    "event": "note",
                    "message": "(7) entry to ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 115,
                    "column": 17,
                    "event": "note",
                    "message": "(8) when ‘strchr’ returns non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 116,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘true’ branch (when ‘colon’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 117,
                    "column": 42,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 117,
                    "column": 24,
                    "event": "note",
                    "message": "(11) calling ‘xstrndup’ from ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 102,
                    "column": 7,
                    "event": "note",
                    "message": "(12) entry to ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/c.h",
                    "line": 23,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 28,
                    "event": "included_from",
                    "message": "Included from here.",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 106,
                    "column": 9,
                    "event": "note",
                    "message": "(13) following ‘true’ branch (when ‘str’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 107,
                    "column": 15,
                    "event": "note",
                    "message": "(14) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 107,
                    "column": 15,
                    "event": "note",
                    "message": "(15) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 108,
                    "column": 12,
                    "event": "note",
                    "message": "(16) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 108,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch (when ‘ret’ is non-NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 110,
                    "column": 16,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 117,
                    "column": 24,
                    "event": "note",
                    "message": "(19) returning to ‘parse_block’ from ‘xstrndup’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 121,
                    "column": 31,
                    "event": "note",
                    "message": "(20) following ‘true’ branch (when ‘i != 134’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 122,
                    "column": 57,
                    "event": "note",
                    "message": "(21) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 136,
                    "column": 23,
                    "event": "note",
                    "message": "(22) following ‘true’ branch (when ‘i < n_entities’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 137,
                    "column": 42,
                    "event": "note",
                    "message": "(23) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 147,
                    "column": 19,
                    "event": "note",
                    "message": "(24) calling ‘xmalloc’ from ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(25) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(26) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(27) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 147,
                    "column": 19,
                    "event": "note",
                    "message": "(28) returning to ‘parse_block’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 151,
                    "column": 12,
                    "event": "note",
                    "message": "(29) following ‘false’ branch (when ‘name == s’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 154,
                    "column": 16,
                    "event": "note",
                    "message": "(30) ...to here (31) ‘name’ leaks here; was allocated at (15)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  152|   \t\tfree((char *)name);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  153|   ",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  154|-> \treturn blocked;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  155|   }",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  156|   ",
                    "verbosity_level": 1
                }
            ]
        },
        {
            "checker": "GCC_ANALYZER_WARNING",
            "cwe": 401,
            "language": "c/c++",
            "tool": "gcc-analyzer",
            "hash_v1": "0282fad8c71dce1a75818b05f7fa6de5a759e865",
            "key_event_idx": 1,
            "events": [
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 0,
                    "event": "scope_hint",
                    "message": "In function ‘main’",
                    "verbosity_level": 1
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 190,
                    "column": 28,
                    "event": "warning[-Wanalyzer-malloc-leak]",
                    "message": "leak of ‘parse_block(optarg, 38, & syscalls, 383)’",
                    "verbosity_level": 0
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 157,
                    "column": 5,
                    "event": "note",
                    "message": "(1) entry to ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 185,
                    "column": 79,
                    "event": "note",
                    "message": "(2) following ‘true’ branch (when ‘c != -1’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 186,
                    "column": 17,
                    "event": "note",
                    "message": "(3) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 186,
                    "column": 17,
                    "event": "note",
                    "message": "(4) following ‘case 115:’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 187,
                    "column": 17,
                    "event": "note",
                    "message": "(5) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 188,
                    "column": 35,
                    "event": "note",
                    "message": "(6) calling ‘parse_block’ from ‘main’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 106,
                    "column": 31,
                    "event": "note",
                    "message": "(7) entry to ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 115,
                    "column": 17,
                    "event": "note",
                    "message": "(8) when ‘strchr’ returns NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 116,
                    "column": 12,
                    "event": "note",
                    "message": "(9) following ‘false’ branch (when ‘colon’ is NULL)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 136,
                    "column": 9,
                    "event": "note",
                    "message": "(10) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 136,
                    "column": 23,
                    "event": "note",
                    "message": "(11) following ‘true’ branch (when ‘i < n_entities’)...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 137,
                    "column": 42,
                    "event": "note",
                    "message": "(12) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 147,
                    "column": 19,
                    "event": "note",
                    "message": "(13) calling ‘xmalloc’ from ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 28,
                    "column": 7,
                    "event": "note",
                    "message": "(14) entry to ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 30,
                    "column": 21,
                    "event": "note",
                    "message": "(15) allocated here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(16) assuming ‘ret’ is non-NULL",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 32,
                    "column": 12,
                    "event": "note",
                    "message": "(17) following ‘false’ branch...",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/include/xalloc.h",
                    "line": 34,
                    "column": 16,
                    "event": "note",
                    "message": "(18) ...to here",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 147,
                    "column": 19,
                    "event": "note",
                    "message": "(19) returning to ‘parse_block’ from ‘xmalloc’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 188,
                    "column": 35,
                    "event": "note",
                    "message": "(20) returning to ‘main’ from ‘parse_block’",
                    "verbosity_level": 2
                },
                {
                    "file_name": "/builddir/build/BUILD/util-linux-2.42.start-build/util-linux-2.42.start/misc-utils/enosys.c",
                    "line": 190,
                    "column": 28,
                    "event": "note",
                    "message": "(21) ‘parse_block(optarg, 38, & syscalls, 383)’ leaks here; was allocated at (15)",
                    "verbosity_level": 2
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  188|   \t\t\tblocked = parse_block(optarg, ENOSYS, syscalls, ARRAY_SIZE(syscalls));",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  189|   \t\t\tlist_add(&blocked->head, &blocked_syscalls);",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  190|-> \t\t\tif (blocked->number == __NR_execve)",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  191|   \t\t\t\tblocking_execve = true;",
                    "verbosity_level": 1
                },
                {
                    "file_name": "",
                    "line": 0,
                    "event": "#",
                    "message": "  192|   ",
                    "verbosity_level": 1
                }
            ]
        }
    ]
}
